@@ -28,14 +28,14 @@ class Mailer {
     protected $partid    = '';
     protected $sendparam = null;
 
-    /** @var EmailAddressValidator */
-    protected $validator = null;
     protected $allowhtml = true;
 
+    protected $replacements = array('text'=> array(), 'html' => array());
+
     /**
      * Constructor
      *
-     * Initializes the boundary strings and part counters
+     * Initializes the boundary strings, part counters and token replacements
      */
     public function __construct() {
         global $conf;
@@ -54,6 +54,9 @@ class Mailer {
         $this->allowhtml = (bool)$conf['htmlmail'];
 
         // add some default headers for mailfiltering FS#2247
+        if(!empty($conf['mailreturnpath'])) {
+            $this->setHeader('Return-Path', $conf['mailreturnpath']);
+        }
         $this->setHeader('X-Mailer', 'DokuWiki');
         $this->setHeader('X-DokuWiki-User', $INPUT->server->str('REMOTE_USER'));
         $this->setHeader('X-DokuWiki-Title', $conf['title']);
@@ -61,6 +64,8 @@ class Mailer {
         $this->setHeader('X-Auto-Response-Suppress', 'OOF');
         $this->setHeader('List-Id', $conf['title'].' <'.$listid.'>');
         $this->setHeader('Date', date('r'), false);
+
+        $this->prepareTokenReplacements();
     }
 
     /**
@@ -174,22 +179,18 @@ class Mailer {
      * Set the text and HTML body and apply replacements
      *
      * This function applies a whole bunch of default replacements in addition
-     * to the ones specidifed as parameters
+     * to the ones specified as parameters
      *
      * If you pass the HTML part or HTML replacements yourself you have to make
      * sure you encode all HTML special chars correctly
      *
      * @param string $text     plain text body
      * @param array  $textrep  replacements to apply on the text part
-     * @param array  $htmlrep  replacements to apply on the HTML part, leave null to use $textrep
+     * @param array  $htmlrep  replacements to apply on the HTML part, null to use $textrep (with urls wrapped in <a> tags)
      * @param string $html     the HTML body, leave null to create it from $text
      * @param bool   $wrap     wrap the HTML in the default header/Footer
      */
     public function setBody($text, $textrep = null, $htmlrep = null, $html = null, $wrap = true) {
-        global $INFO;
-        global $conf;
-        /* @var Input $INPUT */
-        global $INPUT;
 
         $htmlrep = (array)$htmlrep;
         $textrep = (array)$textrep;
@@ -198,15 +199,20 @@ class Mailer {
         if(is_null($html)) {
             $html = $text;
             $html = hsc($html);
-            $html = preg_replace('/^-----*$/m', '<hr >', $html);
+            $html = preg_replace('/^----+$/m', '<hr >', $html);
             $html = nl2br($html);
         }
         if($wrap) {
             $wrap = rawLocale('mailwrap', 'html');
             $html = preg_replace('/\n-- <br \/>.*$/s', '', $html); //strip signature
+            $html = str_replace('@EMAILSIGNATURE@', '', $html); //strip @EMAILSIGNATURE@
             $html = str_replace('@HTMLBODY@', $html, $wrap);
         }
 
+        if(strpos($text, '@EMAILSIGNATURE@') === false) {
+            $text .= '@EMAILSIGNATURE@';
+        }
+
         // copy over all replacements missing for HTML (autolink URLs)
         foreach($textrep as $key => $value) {
             if(isset($htmlrep[$key])) continue;
@@ -223,34 +229,9 @@ class Mailer {
             array($this, 'autoembed_cb'), $html
         );
 
-        // prepare default replacements
-        $ip   = clientIP();
-        $cip  = gethostsbyaddrs($ip);
-        $trep = array(
-            'DATE'        => dformat(),
-            'BROWSER'     => $INPUT->server->str('HTTP_USER_AGENT'),
-            'IPADDRESS'   => $ip,
-            'HOSTNAME'    => $cip,
-            'TITLE'       => $conf['title'],
-            'DOKUWIKIURL' => DOKU_URL,
-            'USER'        => $INPUT->server->str('REMOTE_USER'),
-            'NAME'        => $INFO['userinfo']['name'],
-            'MAIL'        => $INFO['userinfo']['mail'],
-        );
-        $trep = array_merge($trep, (array)$textrep);
-        $hrep = array(
-            'DATE'        => '<i>'.hsc(dformat()).'</i>',
-            'BROWSER'     => hsc($INPUT->server->str('HTTP_USER_AGENT')),
-            'IPADDRESS'   => '<code>'.hsc($ip).'</code>',
-            'HOSTNAME'    => '<code>'.hsc($cip).'</code>',
-            'TITLE'       => hsc($conf['title']),
-            'DOKUWIKIURL' => '<a href="'.DOKU_URL.'">'.DOKU_URL.'</a>',
-            'USER'        => hsc($INPUT->server->str('REMOTE_USER')),
-            'NAME'        => hsc($INFO['userinfo']['name']),
-            'MAIL'        => '<a href="mailto:"'.hsc($INFO['userinfo']['mail']).'">'.
-                hsc($INFO['userinfo']['mail']).'</a>',
-        );
-        $hrep = array_merge($hrep, (array)$htmlrep);
+        // add default token replacements
+        $trep = array_merge($this->replacements['text'], (array)$textrep);
+        $hrep = array_merge($this->replacements['html'], (array)$htmlrep);
 
         // Apply replacements
         foreach($trep as $key => $substitution) {
@@ -353,9 +334,6 @@ class Mailer {
      * @return false|string  the prepared header (can contain multiple lines)
      */
     public function cleanAddress($addresses) {
-        // No named recipients for To: in Windows (see FS#652)
-        $names = (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') ? false : true;
-
         $headers = '';
         if(!is_array($addresses)){
             $addresses = explode(',', $addresses);
@@ -379,21 +357,17 @@ class Mailer {
 
             // FIXME: is there a way to encode the localpart of a emailaddress?
             if(!utf8_isASCII($addr)) {
-                msg(htmlspecialchars("E-Mail address <$addr> is not ASCII"), -1);
+                msg(hsc("E-Mail address <$addr> is not ASCII"), -1);
                 continue;
             }
 
-            if(is_null($this->validator)) {
-                $this->validator                      = new EmailAddressValidator();
-                $this->validator->allowLocalAddresses = true;
-            }
-            if(!$this->validator->check_email_address($addr)) {
-                msg(htmlspecialchars("E-Mail address <$addr> is not valid"), -1);
+            if(!mail_isvalid($addr)) {
+                msg(hsc("E-Mail address <$addr> is not valid"), -1);
                 continue;
             }
 
             // text was given
-            if(!empty($text) && $names) {
+            if(!empty($text) && !isWindows()) { // No named recipients for To: in Windows (see FS#652)
                 // add address quotes
                 $addr = "<$addr>";
 
@@ -615,6 +589,66 @@ class Mailer {
         return $headers.MAILHEADER_EOL.$body;
     }
 
+    /**
+     * Prepare default token replacement strings
+     *
+     * Populates the '$replacements' property.
+     * Should be called by the class constructor
+     */
+    protected function prepareTokenReplacements() {
+        global $INFO;
+        global $conf;
+        /* @var Input $INPUT */
+        global $INPUT;
+        global $lang;
+
+        $ip   = clientIP();
+        $cip  = gethostsbyaddrs($ip);
+
+        $this->replacements['text'] = array(
+            'DATE' => dformat(),
+            'BROWSER' => $INPUT->server->str('HTTP_USER_AGENT'),
+            'IPADDRESS' => $ip,
+            'HOSTNAME' => $cip,
+            'TITLE' => $conf['title'],
+            'DOKUWIKIURL' => DOKU_URL,
+            'USER' => $INPUT->server->str('REMOTE_USER'),
+            'NAME' => $INFO['userinfo']['name'],
+            'MAIL' => $INFO['userinfo']['mail']
+        );
+        $signature = str_replace('@DOKUWIKIURL@', $this->replacements['text']['DOKUWIKIURL'], $lang['email_signature_text']);
+        $this->replacements['text']['EMAILSIGNATURE'] = "\n-- \n" . $signature . "\n";
+
+        $this->replacements['html'] = array(
+            'DATE' => '<i>' . hsc(dformat()) . '</i>',
+            'BROWSER' => hsc($INPUT->server->str('HTTP_USER_AGENT')),
+            'IPADDRESS' => '<code>' . hsc($ip) . '</code>',
+            'HOSTNAME' => '<code>' . hsc($cip) . '</code>',
+            'TITLE' => hsc($conf['title']),
+            'DOKUWIKIURL' => '<a href="' . DOKU_URL . '">' . DOKU_URL . '</a>',
+            'USER' => hsc($INPUT->server->str('REMOTE_USER')),
+            'NAME' => hsc($INFO['userinfo']['name']),
+            'MAIL' => '<a href="mailto:"' . hsc($INFO['userinfo']['mail']) . '">' .
+                hsc($INFO['userinfo']['mail']) . '</a>'
+        );
+        $signature = $lang['email_signature_text'];
+        if(!empty($lang['email_signature_html'])) {
+            $signature = $lang['email_signature_html'];
+        }
+        $signature = str_replace(
+            array(
+                '@DOKUWIKIURL@',
+                "\n"
+            ),
+            array(
+                $this->replacements['html']['DOKUWIKIURL'],
+                '<br />'
+            ),
+            $signature
+        );
+        $this->replacements['html']['EMAILSIGNATURE'] = $signature;
+    }
+
     /**
      * Send the mail
      *
