@@ -1,10 +1,16 @@
 <?php
+
 /**
- * catalan language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
  * @author Carles Bellver <carles.bellver@cent.uji.es>
  * @author Carles Bellver <carles.bellver@gmail.com>
+ * @author daniel@6temes.cat
+ * @author Eduard Díaz <edudiaz@scopia.es>
+ * @author controlonline.net <controlonline.net@gmail.com>
+ * @author Pauet <pauet@gmx.com>
+ * @author Àngel Pérez Beroy <aperezberoy@gmail.com>
+ * @author David Surroca <david.tb303@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -27,7 +33,7 @@ $lang['btn_revs']              = 'Revisions anteriors';
 $lang['btn_recent']            = 'Canvis recents';
 $lang['btn_upload']            = 'Penja';
 $lang['btn_cancel']            = 'Cancel·la';
-$lang['btn_index']             = 'Índex';
+$lang['btn_index']             = 'Mapa del lloc';
 $lang['btn_secedit']           = 'Edita';
 $lang['btn_login']             = 'Entra';
 $lang['btn_logout']            = 'Surt';
@@ -36,17 +42,21 @@ $lang['btn_update']            = 'Actualitza';
 $lang['btn_delete']            = 'Suprimeix';
 $lang['btn_back']              = 'Enrere';
 $lang['btn_backlink']          = 'Què hi enllaça';
-$lang['btn_backtomedia']       = 'Torna a la selecció de fitxers';
 $lang['btn_subscribe']         = 'Subscripció a canvis d\'aquesta pàgina';
-$lang['btn_unsubscribe']       = 'Cancel·la subscripció a pàgina';
 $lang['btn_profile']           = 'Actualització del perfil';
 $lang['btn_reset']             = 'Reinicia';
+$lang['btn_resendpwd']         = 'Estableix una nova contrasenya';
 $lang['btn_draft']             = 'Edita esborrany';
 $lang['btn_recover']           = 'Recupera esborrany';
 $lang['btn_draftdel']          = 'Suprimeix esborrany';
 $lang['btn_revert']            = 'Restaura';
 $lang['btn_register']          = 'Registra\'m';
-$lang['loggedinas']            = 'Heu entrat com';
+$lang['btn_apply']             = 'Aplica';
+$lang['btn_media']             = 'Mànager Multimèdia';
+$lang['btn_deleteuser']        = 'Esborrar compte';
+$lang['btn_img_backto']        = 'Torna a %s';
+$lang['btn_mediaManager']      = 'Veure a multimèdia mànager ';
+$lang['loggedinas']            = 'Heu entrat com:';
 $lang['user']                  = 'Nom d\'usuari';
 $lang['pass']                  = 'Contrasenya';
 $lang['newpass']               = 'Nova contrasenya';
@@ -57,6 +67,7 @@ $lang['fullname']              = 'Nom complet';
 $lang['email']                 = 'Correu electrònic';
 $lang['profile']               = 'Perfil d\'usuari';
 $lang['badlogin']              = 'Nom d\'usuari o contrasenya incorrectes.';
+$lang['badpassconfirm']        = 'Contrasenya incorrecta';
 $lang['minoredit']             = 'Canvis menors';
 $lang['draftdate']             = 'L\'esborrany s\'ha desat automàticament';
 $lang['nosecedit']             = 'Mentrestant la pàgina ha estat modificada. La informació de seccions estava obsoleta i ha calgut carregar la pàgina sencera.';
@@ -64,6 +75,7 @@ $lang['regmissing']            = 'Heu d\'omplir tots els camps.';
 $lang['reguexists']            = 'Ja existeix un altre usuari amb aquest nom.';
 $lang['regsuccess']            = 'S\'ha creat l\'usuari. La contrasenya s\'ha enviat per correu.';
 $lang['regsuccess2']           = 'S\'ha creat l\'usuari.';
+$lang['regfail']               = 'L\'usuari no pot ser creat';
 $lang['regmailfail']           = 'Sembla que un error ha impedit enviar la contrasenya per correu. Contacteu amb l\'administrador.';
 $lang['regbadmail']            = 'L\'adreça de correu que heu donat no sembla vàlida. Si creieu que això és un error, contacu amb l\'administrador.';
 $lang['regbadpass']            = 'Les dues contrasenyes no són iguals. Torneu a intentar-ho.';
@@ -73,8 +85,15 @@ $lang['profna']                = 'Aquest wiki no permet modificar el perfil';
 $lang['profnochange']          = 'No heu introduït cap canvi.';
 $lang['profnoempty']           = 'No es pot deixar en blanc el nom o l\'adreça de correu.';
 $lang['profchanged']           = 'El perfil d\'usuari s\'ha actualitzat correctament.';
+$lang['profnodelete']          = 'Aquesta wiki no permet esborrar usuaris';
+$lang['profdeleteuser']        = 'Esborrar compte';
+$lang['profdeleted']           = 'El vostre compte ha sigut esborrat d\'aquest compte';
+$lang['profconfdelete']        = 'Vull esmorrar el meu compte d\'aquesta wiki. </br> Aquesta acció no pot desfer-se.';
+$lang['profconfdeletemissing'] = 'Confirmació no acceptada';
+$lang['proffail']              = 'Perfil d\'usuari no actialitzat';
 $lang['pwdforget']             = 'Heu oblidat la contrasenya? Podeu obtenir-ne una de nova.';
 $lang['resendna']              = 'Aquest wiki no permet tornar a enviar la contrasenya.';
+$lang['resendpwd']             = 'Estableix una nova contrasenya per';
 $lang['resendpwdmissing']      = 'Heu d\'emplenar tots els camps.';
 $lang['resendpwdnouser']       = 'No s\'ha pogut trobar aquest usuari a la base de dades.';
 $lang['resendpwdbadauth']      = 'Aquest codi d\'autenticació no és vàlid. Assegureu-vos d\'utilitzar l\'enllaç de confirmació complet.';
@@ -84,17 +103,58 @@ $lang['license']               = 'Excepte on es digui una altra cosa, el conting
 $lang['licenseok']             = 'Nota. En editar aquesta pàgina esteu acceptant que el vostre contingut estigui subjecte a la llicència següent:';
 $lang['searchmedia']           = 'Cerca pel nom de fitxer';
 $lang['searchmedia_in']        = 'Cerca en: %s';
-$lang['txt_upload']            = 'Trieu el fitxer que voleu penjar';
-$lang['txt_filename']          = 'Introduïu el nom wiki (opcional)';
+$lang['txt_upload']            = 'Trieu el fitxer que voleu penjar:';
+$lang['txt_filename']          = 'Introduïu el nom wiki (opcional):';
 $lang['txt_overwrt']           = 'Sobreescriu el fitxer actual';
+$lang['maxuploadsize']         = 'Puja com a màxim %s per arxiu.';
 $lang['lockedby']              = 'Actualment blocat per:';
 $lang['lockexpire']            = 'Venciment del blocatge:';
-$lang['js']['willexpire']            = 'El blocatge per a editar aquesta pàgina venç d\'aquí a un minut.\nUtilitzeu la visualització prèvia per reiniciar el rellotge i evitar conflictes.';
-$lang['js']['notsavedyet']     = "Heu fet canvis que es perdran si no els deseu.\nVoleu continuar?";
+$lang['js']['willexpire']      = 'El blocatge per a editar aquesta pàgina venç d\'aquí a un minut.\nUtilitzeu la visualització prèvia per reiniciar el rellotge i evitar conflictes.';
+$lang['js']['notsavedyet']     = 'Heu fet canvis que es perdran si no els deseu.
+Voleu continuar?';
+$lang['js']['searchmedia']     = 'Cerca fitxers';
+$lang['js']['keepopen']        = 'Manté la finestra oberta';
+$lang['js']['hidedetails']     = 'Oculta detalls';
+$lang['js']['mediatitle']      = 'Propietats de l\'enllaç';
+$lang['js']['mediadisplay']    = 'Tipus d\'enllaç';
+$lang['js']['mediaalign']      = 'Alineació';
+$lang['js']['mediasize']       = 'Mida de la imatge';
+$lang['js']['mediatarget']     = 'Destí de l\'enllaç';
+$lang['js']['mediaclose']      = 'Tanca';
+$lang['js']['mediainsert']     = 'Inserta';
+$lang['js']['mediadisplayimg'] = 'Mostra la imatge';
+$lang['js']['mediadisplaylnk'] = 'Mostra només l\'enllaç';
+$lang['js']['mediasmall']      = 'Versió petita';
+$lang['js']['mediamedium']     = 'Versió mitjana';
+$lang['js']['medialarge']      = 'Versió gran';
+$lang['js']['mediaoriginal']   = 'Versió original';
+$lang['js']['medialnk']        = 'Enllaç a la pàgina de detalls';
+$lang['js']['mediadirect']     = 'Enllaç directe a l\'original';
+$lang['js']['medianolnk']      = 'No hi ha enllaç';
+$lang['js']['medianolink']     = 'No enllacis la imatge';
+$lang['js']['medialeft']       = 'Alinea la imatge a l\'esquerra.';
+$lang['js']['mediaright']      = 'Alinea la imatge a la dreta.';
+$lang['js']['mediacenter']     = 'Alinea la imatge al mig.';
+$lang['js']['medianoalign']    = 'No facis servir alineació.';
+$lang['js']['nosmblinks']      = 'Els enllaços amb recursos compartits de Windows només funcionen amb el Microsoft Internet Explorer.
+Si voleu podeu copiar i enganxar l\'enllaç.';
+$lang['js']['linkwiz']         = 'Auxiliar d\'enllaços';
+$lang['js']['linkto']          = 'Enllaça a:';
+$lang['js']['del_confirm']     = 'Suprimiu aquesta entrada?';
+$lang['js']['restore_confirm'] = 'Vols realment restaurar aquesta versió?';
+$lang['js']['media_diff']      = 'Veure les diferències:';
+$lang['js']['media_diff_both'] = 'Un al costat de l\'altre';
+$lang['js']['media_diff_opacity'] = 'Resalta';
+$lang['js']['media_diff_portions'] = 'Llisca';
+$lang['js']['media_select']    = 'Escull els arxius';
+$lang['js']['media_upload_btn'] = 'Pujar';
+$lang['js']['media_done_btn']  = 'Fet';
+$lang['js']['media_drop']      = 'Arrossega aquí els arxius a pujar';
+$lang['js']['media_cancel']    = 'esborra';
+$lang['js']['media_overwrt']   = 'Sobreescriu els arxius existents';
 $lang['rssfailed']             = 'S\'ha produït un error en recollir aquesta alimentació: ';
 $lang['nothingfound']          = 'No s\'ha trobat res.';
 $lang['mediaselect']           = 'Selecció de fitxers';
-$lang['fileupload']            = 'Càrrega de fitxers';
 $lang['uploadsucc']            = 'S\'ha penjat el fitxer';
 $lang['uploadfail']            = 'No es pot penjar el fitxer. Potser no teniu prou permisos?';
 $lang['uploadwrong']           = 'No es pot penjar el fitxer. Aquesta extensió està prohibida.';
@@ -108,14 +168,7 @@ $lang['deletefail']            = 'No s\'ha pogut suprimir el fitxer "%s". Compro
 $lang['mediainuse']            = 'No s\'ha pogut suprimir el fitxer "%s". Encara s\'està utilitzant.';
 $lang['namespaces']            = 'Espais';
 $lang['mediafiles']            = 'Fitxers disponibles en';
-$lang['js']['searchmedia']     = 'Cerca fitxers';
-$lang['js']['keepopen']        = 'Manté la finestra oberta';
-$lang['js']['hidedetails']     = 'Oculta detalls';
-$lang['js']['nosmblinks']      = 'Els enllaços amb recursos compartits de Windows només funcionen amb el Microsoft Internet Explorer.
-Si voleu podeu copiar i enganxar l\'enllaç.';
-$lang['js']['linkwiz']         = 'Auxiliar d\'enllaços';
-$lang['js']['linkto']          = 'Enllaça a:';
-$lang['js']['del_confirm']     = 'Suprimiu aquesta entrada?';
+$lang['accessdenied']          = 'No teniu permís per a veure aquesta pàgina.';
 $lang['mediausage']            = 'Utilitzeu la sintaxi següent per referir-vos a aquest enllaç:';
 $lang['mediaview']             = 'Mostra el fitxer original';
 $lang['mediaroot']             = 'arrel';
@@ -131,22 +184,42 @@ $lang['current']               = 'actual';
 $lang['yours']                 = 'La vostra versió';
 $lang['diff']                  = 'Mostra diferències amb la versió actual';
 $lang['diff2']                 = 'Mostra diferències entre les revisions seleccionades';
+$lang['difflink']              = 'Enllaç a la visualització de la comparació';
+$lang['diff_type']             = 'Veieu les diferències:';
+$lang['diff_inline']           = 'En línia';
+$lang['diff_side']             = 'Un al costat de l\'altre';
+$lang['diffprevrev']           = 'Revisió prèvia';
+$lang['diffnextrev']           = 'Següent revisió';
+$lang['difflastrev']           = 'Ultima revisió';
+$lang['diffbothprevrev']       = 'Ambdós costats versió prèvia';
+$lang['diffbothnextrev']       = 'Ambdós costats nova versio';
 $lang['line']                  = 'Línia';
-$lang['breadcrumb']            = 'Camí';
-$lang['youarehere']            = 'Sou aquí';
-$lang['lastmod']               = 'Darrera modificació';
+$lang['breadcrumb']            = 'Camí:';
+$lang['youarehere']            = 'Sou aquí:';
+$lang['lastmod']               = 'Darrera modificació:';
 $lang['by']                    = 'per';
 $lang['deleted']               = 'suprimit';
 $lang['created']               = 'creat';
-$lang['restored']              = 's\'ha restaurat una versió anterior';
+$lang['restored']              = 's\'ha restaurat una versió anterior %s';
 $lang['external_edit']         = 'edició externa';
 $lang['summary']               = 'Resum d\'edició';
 $lang['noflash']               = 'Per a visualitzar aquest contingut necessiteu el <a href="http://www.adobe.com/products/flashplayer/">connector d\'Adobe Flash</a>.';
 $lang['download']              = 'Baixa el fragment';
+$lang['tools']                 = 'Eines';
+$lang['user_tools']            = 'Eines de l\'usuari';
+$lang['site_tools']            = 'Eines del lloc';
+$lang['page_tools']            = 'Eines de la pàgina';
+$lang['skip_to_content']       = 'salta al contingut';
+$lang['sidebar']               = 'Barra lateral';
 $lang['mail_newpage']          = 'pàgina afegida:';
 $lang['mail_changed']          = 'pàgina modificada:';
+$lang['mail_subscribe_list']   = 'pagines canviades a l0espai de noms:';
 $lang['mail_new_user']         = 'nou usuari:';
 $lang['mail_upload']           = 'fitxer penjat:';
+$lang['changes_type']          = 'Veure els canvis de';
+$lang['pages_changes']         = 'Pàgines';
+$lang['media_changes']         = 'Arxius gràfics';
+$lang['both_changes']          = 'Pàgines i arxius gràfics';
 $lang['qb_bold']               = 'Negreta';
 $lang['qb_italic']             = 'Cursiva';
 $lang['qb_underl']             = 'Subratllat';
@@ -172,27 +245,37 @@ $lang['qb_sig']                = 'Insereix signatura';
 $lang['qb_smileys']            = 'Emoticones';
 $lang['qb_chars']              = 'Caràcters especials';
 $lang['upperns']               = 'Salta a l\'espai superior';
-$lang['admin_register']        = 'Afegeix nou usuari';
 $lang['metaedit']              = 'Edita metadades';
 $lang['metasaveerr']           = 'No s\'han pogut escriure les metadades';
 $lang['metasaveok']            = 'S\'han desat les metadades';
-$lang['img_backto']            = 'Torna a';
-$lang['img_title']             = 'Títol';
-$lang['img_caption']           = 'Peu d\'imatge';
-$lang['img_date']              = 'Data';
-$lang['img_fname']             = 'Nom de fitxer';
-$lang['img_fsize']             = 'Mida';
-$lang['img_artist']            = 'Fotògraf';
-$lang['img_copyr']             = 'Copyright';
-$lang['img_format']            = 'Format';
-$lang['img_camera']            = 'Càmera';
-$lang['img_keywords']          = 'Paraules clau';
-$lang['subscribe_success']     = 'S\'ha afegit %s a la llista de subscripcions de %s';
-$lang['subscribe_error']       = 'S\'ha produït un error en afegir %s a la llista de subscripcions de %s';
-$lang['subscribe_noaddress']   = 'No hi ha cap adreça de correu associada al vostre nom d\'usuari. No se us ha pogut afegir a la llista de subscripcions.';
-$lang['unsubscribe_success']   = '%s ha estat suprimit de la llista de subscripcions de %s';
-$lang['unsubscribe_error']     = 'S\'ha produït un error en suprimir %s de la llista de subscripcions de %s';
-$lang['authmodfailed']         = 'La configuració de l\'autenticació d\'usuaris és errònia. Informeu els administradors del wiki.';
+$lang['img_title']             = 'Títol:';
+$lang['img_caption']           = 'Peu d\'imatge:';
+$lang['img_date']              = 'Data:';
+$lang['img_fname']             = 'Nom de fitxer:';
+$lang['img_fsize']             = 'Mida:';
+$lang['img_artist']            = 'Fotògraf:';
+$lang['img_copyr']             = 'Copyright:';
+$lang['img_format']            = 'Format:';
+$lang['img_camera']            = 'Càmera:';
+$lang['img_keywords']          = 'Paraules clau:';
+$lang['img_width']             = 'Ample:';
+$lang['img_height']            = 'Alçada:';
+$lang['subscr_subscribe_success'] = 'S\'ha afegit %s a la llista de subscripcions per %s';
+$lang['subscr_subscribe_error'] = 'Hi ha hagut un error a l\'afegir %s a la llista per %s';
+$lang['subscr_subscribe_noaddress'] = 'No hi ha cap adreça associada pel vostre nom d\'usuari, no podeu ser afegit a la llista de subscripcions';
+$lang['subscr_unsubscribe_success'] = 'S\'ha esborrat %s de la llista de subscripcions per %s';
+$lang['subscr_unsubscribe_error'] = 'Hi ha hagut un error a l\'esborrar %s de la llista de subscripcions per %s';
+$lang['subscr_already_subscribed'] = '%s ja està subscrit a %s';
+$lang['subscr_not_subscribed'] = '%s no està subscrit a %s';
+$lang['subscr_m_not_subscribed'] = 'En aquests moments no esteu subscrit a l\'actual pàgina o espai';
+$lang['subscr_m_new_header']   = 'Afegeix subcripció';
+$lang['subscr_m_current_header'] = 'Subscripcions actuals';
+$lang['subscr_m_unsubscribe']  = 'Donar-se de baixa';
+$lang['subscr_m_subscribe']    = 'Donar-se d\'alta';
+$lang['subscr_m_receive']      = 'Rebre';
+$lang['subscr_style_every']    = 'Envia\'m un correu electrònic per a cada canvi';
+$lang['subscr_style_digest']   = 'Envia\'m un correu electrònic amb un resum dels canvis per a cada pàgina (cada %.2f dies)';
+$lang['subscr_style_list']     = 'llistat de pàgines canviades des de l\'últim correu electrònic  (cada %.2f dies)';
 $lang['authtempfail']          = 'L\'autenticació d\'usuaris no està disponible temporalment. Si aquesta situació persisteix, si us plau informeu els administradors del wiki.';
 $lang['i_chooselang']          = 'Trieu l\'idioma';
 $lang['i_installer']           = 'Instal·lador de DokuWiki';
@@ -203,18 +286,24 @@ $lang['i_problems']            = 'L\'instal·lador ha trobat alguns problemes, q
 $lang['i_modified']            = 'Per raons de seguretat aquesta seqüència només funciona amb una instal·lació nova i no modificada de Dokuwiki. Hauríeu de tornar a baixar el paquet i/o descomprimir-lo o consultar les <a href="http://dokuwiki.org/install">instruccions d\'instal·lació de Dokuwiki</a> completes';
 $lang['i_funcna']              = 'La funció PHP <code>%s</code> no està disponible. Potser el vostre proveïdor de serveis l\'ha inhabilitada per alguna raó';
 $lang['i_phpver']              = 'La vostra versió de PHP <code>%s</code> és inferior a la requerida <code>%s</code>. Necessiteu actualitzar la vostra instal·lació de PHP.';
+$lang['i_mbfuncoverload']      = 'mbstring.func_overload cal que sigui deshabilitada en php.ini perquè funcioni DokuWiki';
 $lang['i_permfail']            = 'DokuWiki no pot escriure <code>%s</code>. Heu d\'arreglar els permisos d\'aquest directori';
 $lang['i_confexists']          = '<code>%s</code> ja existeix';
 $lang['i_writeerr']            = 'No es pot crear <code>%s</code>. Comproveu els permisos del directori i/o del fitxer i creeu el fitxer manualment.';
 $lang['i_badhash']             = 'dokuwiki.php no reconegut o modificat (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - valor il·legal o buit';
-$lang['i_success']             = 'La configuració s\'ha acabat amb èxit. Ara podeu suprimir el fitxer install.php. Aneu al vostre nou <a href="doku.php">DokuWiki</a>.';
-$lang['i_failure']             = 'S\'han produït alguns errors en escriure els fitxers de configuració. Potser caldrà que els arregleu manualment abans d\'utilitzar el vostre nou <a href="doku.php">DokuWiki</a>.';
+$lang['i_success']             = 'La configuració s\'ha acabat amb èxit. Ara podeu suprimir el fitxer install.php. Aneu al <a href="doku.php?id=wiki:welcome">vostre nou DokuWiki</a>.';
+$lang['i_failure']             = 'S\'han produït alguns errors en escriure els fitxers de configuració. Potser caldrà que els arregleu manualment abans d\'utilitzar el <a href="doku.php?id=wiki:welcome">vostre nou DokuWiki</a>.';
 $lang['i_policy']              = 'Política ACL inicial';
 $lang['i_pol0']                = 'Wiki obert (tothom pot llegir, escriure i penjar fitxers)';
 $lang['i_pol1']                = 'Wiki públic (tothom pot llegir, els usuaris registrats poden escriure i penjar fitxers)';
 $lang['i_pol2']                = 'Wiki tancat (només els usuaris registrats poden llegir, escriure i penjar fitxers)';
+$lang['i_allowreg']            = 'Permet d\'autoinscripció d\'usuaris';
 $lang['i_retry']               = 'Reintenta';
+$lang['i_license']             = 'Escolliu el tipus de llicència que voleu fer servir per al vostre contingut:';
+$lang['i_license_none']        = 'No mostrar cap informació sobre llicencies';
+$lang['i_pop_field']           = 'Si us plau, ajuda\'ns a millorar la DokuWiki';
+$lang['i_pop_label']           = 'Una vegada al mes, enviar anònimament dades als programadors de la DokuWiki';
 $lang['recent_global']         = 'Esteu veient els canvis recents de l\'espai <strong>%s</strong>. També podeu veure els <a href="%s">canvis recents de tot el wiki</a>.';
 $lang['years']                 = 'fa %d anys';
 $lang['months']                = 'fa %d mesos';
@@ -223,3 +312,36 @@ $lang['days']                  = 'fa %d dies';
 $lang['hours']                 = 'fa %d hores';
 $lang['minutes']               = 'fa %d minuts';
 $lang['seconds']               = 'fa %d segons';
+$lang['wordblock']             = 'El vostre canvi no s\'ha guardat perquè conté text blocat (spam)';
+$lang['media_uploadtab']       = 'Puja';
+$lang['media_searchtab']       = 'Busca';
+$lang['media_file']            = 'Fitxer';
+$lang['media_viewtab']         = 'Mostra';
+$lang['media_edittab']         = 'Edita';
+$lang['media_historytab']      = 'Històric';
+$lang['media_list_thumbs']     = 'Miniatura';
+$lang['media_list_rows']       = 'Files';
+$lang['media_sort_name']       = 'Nom';
+$lang['media_sort_date']       = 'Data';
+$lang['media_namespaces']      = 'Escolliu l\'espai';
+$lang['media_files']           = 'Arxius a %s';
+$lang['media_upload']          = 'Puja a %s';
+$lang['media_search']          = 'Busca a %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s a %s';
+$lang['media_edit']            = 'Edita %s';
+$lang['media_history']         = 'Històric de %s';
+$lang['media_meta_edited']     = 'metadata editada';
+$lang['media_perm_read']       = 'No teniu permisos suficients per a llegir arxius.';
+$lang['media_perm_upload']     = 'No teniu permisos suficients per a pujar arxius';
+$lang['media_update']          = 'Puja la nova versió';
+$lang['media_restore']         = 'Restaura aquesta versió';
+$lang['media_acl_warning']     = 'Aquesta llista pot no estar completa per restriccions ACL i per llistes ocultes';
+$lang['currentns']             = 'Espai de noms actual';
+$lang['searchresult']          = 'Resultats cerca';
+$lang['plainhtml']             = 'HTML pla';
+$lang['wikimarkup']            = 'Wiki Marcatge';
+$lang['page_nonexist_rev']     = 'Pàgina no existeix a %s. Aixó es conseqüencia d\'haver-la creada a <a href="%s">%s</a>.';
+$lang['unable_to_parse_date']  = 'Impossible de esbrinar el paràmetre "%s".';
+$lang['email_signature_text']  = 'Aquest mail ha estat generat per DokuWiki a
+@DOKUWIKIURL@';
