@@ -1,8 +1,10 @@
 <?php
+
 /**
- * danish language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
+ * @author Kenneth Schack Banner <kescba@gmail.com>
+ * @author Jon Theil Nielsen <jontheil@gmail.com>
  * @author koeppe <koeppe@kazur.dk>
  * @author Jon Bendtsen <bendtsen@diku.dk>
  * @author Lars Næsbye Christensen <larsnaesbye@stud.ku.dk>
@@ -11,9 +13,13 @@
  * @author Harith <haj@berlingske.dk>
  * @author Daniel Ejsing-Duun <dokuwiki@zilvador.dk>
  * @author Erik Bjørn Pedersen <erik.pedersen@shaw.ca>
- * @author rasmus@kinnerup.com
- * @author Michael Pedersen subben@gmail.com
+ * @author rasmus <rasmus@kinnerup.com>
  * @author Mikael Lyngvig <mikael@lyngvig.org>
+ * @author Soren Birk <soer9648@hotmail.com>
+ * @author Jens Hyllegaard <jens.hyllegaard@gmail.com>
+ * @author soer9648 <soer9648@eucl.dk>
+ * @author Søren Birk <sbi@eucl.dk>
+ * @author Jacob Palm <mail@jacobpalm.dk>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -45,7 +51,6 @@ $lang['btn_update']            = 'Opdatér';
 $lang['btn_delete']            = 'Slet';
 $lang['btn_back']              = 'Tilbage';
 $lang['btn_backlink']          = 'Henvisninger bagud';
-$lang['btn_backtomedia']       = 'Tilbage til valg af mediefil';
 $lang['btn_subscribe']         = 'Abonnér på ændringer';
 $lang['btn_profile']           = 'Opdatér profil';
 $lang['btn_reset']             = 'Nulstil';
@@ -53,11 +58,14 @@ $lang['btn_resendpwd']         = 'Vælg ny adgangskode';
 $lang['btn_draft']             = 'Redigér kladde';
 $lang['btn_recover']           = 'Gendan kladde';
 $lang['btn_draftdel']          = 'Slet kladde';
-$lang['btn_revert']            = 'Reetablér';
+$lang['btn_revert']            = 'Gendan';
 $lang['btn_register']          = 'Registrér';
 $lang['btn_apply']             = 'Anvend';
 $lang['btn_media']             = 'Media Manager';
-$lang['loggedinas']            = 'Logget ind som';
+$lang['btn_deleteuser']        = 'Fjern Min Konto';
+$lang['btn_img_backto']        = 'Tilbage til %s';
+$lang['btn_mediaManager']      = 'Vis i Media Manager';
+$lang['loggedinas']            = 'Logget ind som:';
 $lang['user']                  = 'Brugernavn';
 $lang['pass']                  = 'Adgangskode';
 $lang['newpass']               = 'Ny adgangskode';
@@ -68,6 +76,7 @@ $lang['fullname']              = 'Fulde navn';
 $lang['email']                 = 'E-mail';
 $lang['profile']               = 'Brugerprofil';
 $lang['badlogin']              = 'Brugernavn eller adgangskode var forkert.';
+$lang['badpassconfirm']        = 'Adgangkode var desværre forkert';
 $lang['minoredit']             = 'Mindre ændringer';
 $lang['draftdate']             = 'Kladde automatisk gemt d.';
 $lang['nosecedit']             = 'Siden blev ændret i mellemtiden, sektions information var for gammel, hentede hele siden i stedet.';
@@ -75,103 +84,109 @@ $lang['regmissing']            = 'Du skal udfylde alle felter.';
 $lang['reguexists']            = 'Dette brugernavn er allerede i brug.';
 $lang['regsuccess']            = 'Du er nu oprettet som bruger. Dit adgangskode bliver sendt til dig i en e-mail.';
 $lang['regsuccess2']           = 'Du er nu oprettet som bruger.';
+$lang['regfail']               = 'Brugeren kunne ikke oprettes.';
 $lang['regmailfail']           = 'Dit adgangskode blev ikke sendt. Kontakt venligst administratoren.';
 $lang['regbadmail']            = 'E-mail-adressen er ugyldig. Kontakt venligst administratoren, hvis du mener dette er en fejl.';
 $lang['regbadpass']            = 'De to adgangskoder er ikke ens, vær venlig at prøve igen.';
-$lang['regpwmail']             = 'Dit DokuWiki password';
+$lang['regpwmail']             = 'Dit adgangskode til DokuWiki';
 $lang['reghere']               = 'Opret en DokuWiki-konto her';
 $lang['profna']                = 'Denne wiki understøtter ikke ændring af profiler';
 $lang['profnochange']          = 'Ingen ændringer, intet modificeret.';
 $lang['profnoempty']           = 'Tomt navn eller e-mail adresse er ikke tilladt.';
 $lang['profchanged']           = 'Brugerprofil opdateret korrekt.';
-$lang['pwdforget']             = 'Har du glemt dit adgangskode? Få et nyt';
-$lang['resendna']              = 'Denne wiki understøtter ikke udsendelse af nyt adgangskode.';
-$lang['resendpwd']             = 'Vælg ny adgangskode for';
+$lang['profnodelete']          = 'Denne wiki understøtter ikke sletning af brugere';
+$lang['profdeleteuser']        = 'Slet konto';
+$lang['profdeleted']           = 'Din brugerkonto er blevet slettet fra denne wiki';
+$lang['profconfdelete']        = 'Jeg ønsker at slette min konto fra denne wiki. <br/> Denne handling kan ikke fortrydes.';
+$lang['proffail']              = 'Brugerprofilen blev ikke opdateret.';
+$lang['pwdforget']             = 'Har du glemt dit adgangskode? Få en ny';
+$lang['resendna']              = 'Denne wiki understøtter ikke udsendelse af ny adgangskode.';
+$lang['resendpwd']             = 'Vælg en ny adgangskode for';
 $lang['resendpwdmissing']      = 'Du skal udfylde alle felter.';
 $lang['resendpwdnouser']       = 'Vi kan ikke finde denne bruger i vores database.';
 $lang['resendpwdbadauth']      = 'Beklager, denne autoriseringskode er ikke gyldig. Kontroller venligst at du benyttede det fulde link til bekræftelse.';
-$lang['resendpwdconfirm']      = 'Et henvisning med bekræftelse er blevet sendt med email.';
-$lang['resendpwdsuccess']      = 'Dit nye adgangskode er blevet sendt med e-mail.';
-$lang['license']               = 'Med mindre andet angivet, vil indhold på denne wiki blive frigjort under følgende licens:';
-$lang['licenseok']             = 'Note: ved at ændre denne side, acceptere du at dit indhold bliver frigivet under følgende licens:';
+$lang['resendpwdconfirm']      = 'En e-mail med et link til bekræftelse er blevet sendt.';
+$lang['resendpwdsuccess']      = 'Din nye adgangskode er blevet sendt med e-mail.';
+$lang['license']               = 'Med mindre andet angivet, vil indhold på denne wiki blive udgivet under følgende licens:';
+$lang['licenseok']             = 'Bemærk - ved at redigere denne side, accepterer du at dit indhold bliver frigivet under følgende licens:';
 $lang['searchmedia']           = 'Søg filnavn';
 $lang['searchmedia_in']        = 'Søg i %s';
-$lang['txt_upload']            = 'Vælg den fil der skal overføres';
-$lang['txt_filename']          = 'Indtast wikinavn (valgfrit)';
+$lang['txt_upload']            = 'Vælg den fil der skal overføres:';
+$lang['txt_filename']          = 'Indtast wikinavn (valgfrit):';
 $lang['txt_overwrt']           = 'Overskriv eksisterende fil';
 $lang['maxuploadsize']         = 'Upload max. %s pr. fil.';
-$lang['lockedby']              = 'Midlertidig låst af';
-$lang['lockexpire']            = 'Lås udløber kl.';
+$lang['lockedby']              = 'Midlertidig låst af:';
+$lang['lockexpire']            = 'Lås udløber kl:.';
 $lang['js']['willexpire']      = 'Din lås på dette dokument udløber om et minut.\nTryk på Forhåndsvisning-knappen for at undgå konflikter.';
-$lang['js']['notsavedyet']     = 'Ugemte ændringer vil blive mistet
+$lang['js']['notsavedyet']     = 'Ugemte ændringer vil blive mistet.
 Fortsæt alligevel?';
 $lang['js']['searchmedia']     = 'Søg efter filer';
 $lang['js']['keepopen']        = 'Hold vindue åbent ved valg';
 $lang['js']['hidedetails']     = 'Skjul detaljer';
 $lang['js']['mediatitle']      = 'Link indstillinger';
 $lang['js']['mediadisplay']    = 'Link type';
-$lang['js']['mediaalign']      = 'Juster';
+$lang['js']['mediaalign']      = 'Justering';
 $lang['js']['mediasize']       = 'Billede størrelse';
-$lang['js']['mediatarget']     = 'Link mål';
+$lang['js']['mediatarget']     = 'Link destination';
 $lang['js']['mediaclose']      = 'Luk';
 $lang['js']['mediainsert']     = 'Indsæt';
 $lang['js']['mediadisplayimg'] = 'Vis billedet';
 $lang['js']['mediadisplaylnk'] = 'Vis kun linket';
 $lang['js']['mediasmall']      = 'Lille version';
-$lang['js']['mediamedium']     = 'Medium version';
+$lang['js']['mediamedium']     = 'Mellem version';
 $lang['js']['medialarge']      = 'Stor version';
 $lang['js']['mediaoriginal']   = 'Original version';
 $lang['js']['medialnk']        = 'Link til detajle side';
 $lang['js']['mediadirect']     = 'Direkte link til originalen';
 $lang['js']['medianolnk']      = 'Intet link';
-$lang['js']['medianolink']     = 'Link ikke billedet';
+$lang['js']['medianolink']     = 'Link ikke til billedet';
 $lang['js']['medialeft']       = 'Juster billedet til venstre';
 $lang['js']['mediaright']      = 'Juster billedet til højre';
 $lang['js']['mediacenter']     = 'Centreret';
 $lang['js']['medianoalign']    = 'Brug ingen justering';
 $lang['js']['nosmblinks']      = 'Henvisninger til Windows shares virker kun i Microsoft Internet Explorer.
 Du kan stadig kopiere og indsætte linket.';
-$lang['js']['linkwiz']         = 'guiden til henvisninger';
-$lang['js']['linkto']          = 'Henvise til:';
+$lang['js']['linkwiz']         = 'Guiden til henvisninger';
+$lang['js']['linkto']          = 'Henvis til:';
 $lang['js']['del_confirm']     = 'Slet valgte post(er)?';
-$lang['js']['restore_confirm'] = 'Vil du virkeligt genskabe denne version?';
+$lang['js']['restore_confirm'] = 'Er du sikker på at du vil genskabe denne version?';
 $lang['js']['media_diff']      = 'Vis forskelle:';
 $lang['js']['media_diff_both'] = 'Side ved Side';
-$lang['js']['media_diff_opacity'] = 'Skin-igennem';
+$lang['js']['media_diff_opacity'] = 'Skin igennem';
+$lang['js']['media_diff_portions'] = 'Skub';
 $lang['js']['media_select']    = 'Vælg filer...';
-$lang['js']['media_upload_btn'] = 'Upload';
+$lang['js']['media_upload_btn'] = 'Overfør';
 $lang['js']['media_done_btn']  = 'Færdig';
-$lang['js']['media_drop']      = 'Drop filer her for at uploade';
+$lang['js']['media_drop']      = 'Træk filer hertil for at overføre';
 $lang['js']['media_cancel']    = 'fjern';
 $lang['js']['media_overwrt']   = 'Overskriv eksisterende filer';
-$lang['rssfailed']             = 'Der opstod en fejl ved indhentning af: ';
+$lang['rssfailed']             = 'Der opstod en fejl ved hentning af dette feed: ';
 $lang['nothingfound']          = 'Søgningen gav intet resultat.';
 $lang['mediaselect']           = 'Vælg mediefil';
-$lang['fileupload']            = 'Overføre mediefil';
-$lang['uploadsucc']            = 'Overførelse var en succes';
-$lang['uploadfail']            = 'Overførelse fejlede. Der er muligvis problemer med rettighederne.';
-$lang['uploadwrong']           = 'Overførelse afvist. Filtypen er ikke tilladt.';
+$lang['uploadsucc']            = 'Overførels blev fuldført';
+$lang['uploadfail']            = 'Overførslen fejlede. Der er muligvis problemer med rettighederne.';
+$lang['uploadwrong']           = 'Overførslen blev afvist. Filtypen er ikke tilladt.';
 $lang['uploadexist']           = 'Filen eksisterer allerede.';
-$lang['uploadbadcontent']      = 'Overføret indhold tilsvaret ikke til %s fil-endelsen.';
+$lang['uploadbadcontent']      = 'Det overført indhold svarer ikke til %s fil-endelsen.';
 $lang['uploadspam']            = 'Overførelsen blev blokeret af spam sortlisten.';
 $lang['uploadxss']             = 'Overførelsen blev blokeret på grund af mulig skadeligt indhold.';
-$lang['uploadsize']            = 'Den overføret fil var for stor (max. %s)';
+$lang['uploadsize']            = 'Den overførte fil var for stor (maksimal størrelse %s)';
 $lang['deletesucc']            = 'Filen "%s" er blevet slettet.';
-$lang['deletefail']            = '"%s" kunne ikke slettes - check rettighederne.';
-$lang['mediainuse']            = 'Filen "%s" er ikke slettet - den er stadig i brug.';
+$lang['deletefail']            = '"%s" kunne ikke slettes - kontroller rettighederne.';
+$lang['mediainuse']            = 'Filen "%s" kan ikke slettes - den er stadig i brug.';
 $lang['namespaces']            = 'Navnerum';
 $lang['mediafiles']            = 'Tilgængelige filer i';
-$lang['accessdenied']          = 'Du har ikke tilladelse til at se denne side';
+$lang['accessdenied']          = 'Du har ikke tilladelse til at se denne side.';
 $lang['mediausage']            = 'Brug den følgende syntaks til at henvise til denne fil:';
 $lang['mediaview']             = 'Vis oprindelig fil';
 $lang['mediaroot']             = 'rod';
 $lang['mediaupload']           = 'Overføre en fil til det nuværende navnerum her. For at oprette under-navnerum, tilføj dem til "Overføre som" filnavnet, adskilt af kolontegn.';
-$lang['mediaextchange']        = 'Filudvidelse ændret fra .%s til .%s!';
+$lang['mediaextchange']        = 'Filtype ændret fra .%s til .%s!';
 $lang['reference']             = 'Henvisning til';
 $lang['ref_inuse']             = 'Filen kan ikke slettes, da den stadig er i brug på følgende sider:';
-$lang['ref_hidden']            = 'Nogle henvisninger er i dokumenter du ikke har læserettigheder til';
+$lang['ref_hidden']            = 'Nogle henvisninger er på sider du ikke har læserettigheder til';
 $lang['hits']                  = 'Besøg';
-$lang['quickhits']             = 'Tilsvarende dokumentnavne';
+$lang['quickhits']             = 'Tilsvarende sidenavne';
 $lang['toc']                   = 'Indholdsfortegnelse';
 $lang['current']               = 'nuværende';
 $lang['yours']                 = 'Din version';
@@ -180,33 +195,39 @@ $lang['diff2']                 = 'Vis forskelle i forhold til de valgte revision
 $lang['difflink']              = 'Link til denne sammenlinings vising';
 $lang['diff_type']             = 'Vis forskelle:';
 $lang['diff_inline']           = 'Indeni';
-$lang['diff_side']             = 'Side ved Side';
+$lang['diff_side']             = 'Side ved side';
+$lang['diffprevrev']           = 'Forrige revision';
+$lang['diffnextrev']           = 'Næste revision';
+$lang['difflastrev']           = 'Sidste revision';
+$lang['diffbothprevrev']       = 'Begge sider forrige revision';
+$lang['diffbothnextrev']       = 'Begge sider næste revision';
 $lang['line']                  = 'Linje';
-$lang['breadcrumb']            = 'Sti';
-$lang['youarehere']            = 'Du er her';
-$lang['lastmod']               = 'Sidst ændret';
+$lang['breadcrumb']            = 'Sti:';
+$lang['youarehere']            = 'Du er her:';
+$lang['lastmod']               = 'Sidst ændret:';
 $lang['by']                    = 'af';
 $lang['deleted']               = 'slettet';
 $lang['created']               = 'oprettet';
-$lang['restored']              = 'gammel udgave reetableret (%s)';
+$lang['restored']              = 'gammel udgave gendannet (%s)';
 $lang['external_edit']         = 'ekstern redigering';
-$lang['summary']               = 'Redigerings resumé';
-$lang['noflash']               = 'Den <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> er nødvendig til at vise denne indehold.';
-$lang['download']              = 'Hente kodestykke';
+$lang['summary']               = 'Resumé af ændrigner';
+$lang['noflash']               = 'Du skal installere <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Player</a> for at kunne se dette indhold.';
+$lang['download']              = 'Hent kodestykke';
 $lang['tools']                 = 'Værktøjer';
 $lang['user_tools']            = 'Brugerværktøjer';
 $lang['site_tools']            = 'Webstedsværktøjer';
 $lang['page_tools']            = 'Sideværktøjer';
 $lang['skip_to_content']       = 'hop til indhold';
-$lang['mail_newpage']          = 'dokument tilføjet:';
-$lang['mail_changed']          = 'dokument ændret:';
-$lang['mail_subscribe_list']   = 'sider ændret i navnerum';
+$lang['sidebar']               = 'Sidebjælke';
+$lang['mail_newpage']          = 'side tilføjet:';
+$lang['mail_changed']          = 'side ændret:';
+$lang['mail_subscribe_list']   = 'sider ændret i navnerum:';
 $lang['mail_new_user']         = 'Ny bruger';
-$lang['mail_upload']           = 'fil overføret:';
+$lang['mail_upload']           = 'fil overført:';
 $lang['changes_type']          = 'Vis ændringer af';
 $lang['pages_changes']         = 'Sider';
-$lang['media_changes']         = 'Media filer';
-$lang['both_changes']          = 'Både sider og media filer';
+$lang['media_changes']         = 'Mediefiler';
+$lang['both_changes']          = 'Både sider og medie filer';
 $lang['qb_bold']               = 'Fed';
 $lang['qb_italic']             = 'Kursiv';
 $lang['qb_underl']             = 'Understregning';
@@ -218,7 +239,7 @@ $lang['qb_h3']                 = 'Niveau 3 overskrift';
 $lang['qb_h4']                 = 'Niveau 4 overskrift';
 $lang['qb_h5']                 = 'Niveau 5 overskrift';
 $lang['qb_h']                  = 'Overskrift';
-$lang['qb_hs']                 = 'Vælg overskriften';
+$lang['qb_hs']                 = 'Vælg overskrift';
 $lang['qb_hplus']              = 'Højere overskriftsniveau';
 $lang['qb_hminus']             = 'Lavere overskriftsniveau';
 $lang['qb_hequal']             = 'Samme overskriftsniveau';
@@ -226,30 +247,27 @@ $lang['qb_link']               = 'Intern henvisning';
 $lang['qb_extlink']            = 'Ekstern henvisning';
 $lang['qb_hr']                 = 'Vandret linje';
 $lang['qb_ol']                 = 'Nummereret liste';
-$lang['qb_ul']                 = 'Unummereret liste';
+$lang['qb_ul']                 = 'Punktopstilling';
 $lang['qb_media']              = 'Tilføj billeder og andre filer';
 $lang['qb_sig']                = 'Indsæt signatur';
 $lang['qb_smileys']            = 'Smileys';
 $lang['qb_chars']              = 'Specialtegn';
 $lang['upperns']               = 'Gå til overordnet navnerum';
-$lang['admin_register']        = 'Tilføj ny bruger';
 $lang['metaedit']              = 'Rediger metadata';
-$lang['metasaveerr']           = 'Skrivning af metadata fejlede';
+$lang['metasaveerr']           = 'Fejl under skrivning af metadata';
 $lang['metasaveok']            = 'Metadata gemt';
-$lang['img_backto']            = 'Tilbage til';
-$lang['img_title']             = 'Titel';
-$lang['img_caption']           = 'Billedtekst';
-$lang['img_date']              = 'Dato';
-$lang['img_fname']             = 'Filnavn';
-$lang['img_fsize']             = 'Størrelse';
-$lang['img_artist']            = 'Fotograf';
-$lang['img_copyr']             = 'Ophavsret';
-$lang['img_format']            = 'Format';
-$lang['img_camera']            = 'Kamera';
-$lang['img_keywords']          = 'Emneord';
-$lang['img_width']             = 'Bredde';
-$lang['img_height']            = 'Højde';
-$lang['img_manager']           = 'Vis i Media Manager';
+$lang['img_title']             = 'Titel:';
+$lang['img_caption']           = 'Billedtekst:';
+$lang['img_date']              = 'Dato:';
+$lang['img_fname']             = 'Filnavn:';
+$lang['img_fsize']             = 'Størrelse:';
+$lang['img_artist']            = 'Fotograf:';
+$lang['img_copyr']             = 'Ophavsret:';
+$lang['img_format']            = 'Format:';
+$lang['img_camera']            = 'Kamera:';
+$lang['img_keywords']          = 'Emneord:';
+$lang['img_width']             = 'Bredde:';
+$lang['img_height']            = 'Højde:';
 $lang['subscr_subscribe_success'] = 'Tilføjede %s til abonnement listen for %s';
 $lang['subscr_subscribe_error'] = 'Fejl ved tilføjelse af %s til abonnement listen for %s';
 $lang['subscr_subscribe_noaddress'] = 'Der er ikke nogen addresse forbundet til din bruger, så du kan ikke blive tilføjet til abonnement listen';
@@ -266,9 +284,7 @@ $lang['subscr_m_receive']      = 'Modtag';
 $lang['subscr_style_every']    = 'email på hver ændring';
 $lang['subscr_style_digest']   = 'opsummeringsmail med ændringer for hver side (hver %.2f dage)';
 $lang['subscr_style_list']     = 'list af ændrede sider siden sidste email (hver %.2f dage)';
-$lang['authmodfailed']         = 'Fejl i brugervalideringens konfiguration. Kontakt venligst wikiens administrator.';
 $lang['authtempfail']          = 'Brugervalidering er midlertidigt ude af drift. Hvis dette er vedvarende, kontakt venligst wikiens administrator.';
-$lang['authpwdexpire']         = 'Din adgangskode vil udløbe om %d dage, du bør ændre det snart.';
 $lang['i_chooselang']          = 'Vælg dit sprog';
 $lang['i_installer']           = 'DokuWiki Installer';
 $lang['i_wikiname']            = 'Wiki Navn';
@@ -280,6 +296,7 @@ Du burde enten gen-udpakke filerne fra den hentede pakke eller tjekke den fuldst
 <a href="http://dokuwiki.org/install">DokuWiki installations instruktioner</a>';
 $lang['i_funcna']              = 'PHP funtionen <code>%s</code> er ikke tilgængelig. Måske har din udbyder slået det fra af en eller anden grund?';
 $lang['i_phpver']              = 'Din PHP version <code>%s</code> er mindre en den nødvendige <code>%s</code>. Du er nød til at opgradere din PHP installation.';
+$lang['i_mbfuncoverload']      = 'mbstring.func_overload skal være deaktiveret i php.ini for at køre DokuWiki.';
 $lang['i_permfail']            = 'DokuWiki kan ikke skrive til <code>%s</code>. Du er nød til at rette tilladelses indstillingerne for denne mappe!';
 $lang['i_confexists']          = '<code>%s</code> eksisterer allerede';
 $lang['i_writeerr']            = 'Kunne ikke oprette <code>%s</code>. Du bliver nød til at tjekke mappe/fil- tilladelserne og oprette filen manuelt.';
@@ -291,8 +308,12 @@ $lang['i_policy']              = 'Begyndende ACL politik';
 $lang['i_pol0']                = 'Åben Wiki (alle kan læse, skrive og uploade)';
 $lang['i_pol1']                = 'Offentlig Wiki (alle kan læse, kun registrerede brugere kan skrive og overføre)';
 $lang['i_pol2']                = 'Lukket Wiki (kun for registerede brugere kan læse, skrive og overføre)';
+$lang['i_allowreg']            = 'Tillad at brugere kan registrere sig selv';
 $lang['i_retry']               = 'Forsøg igen';
 $lang['i_license']             = 'Vælg venligst licensen du vil tilføje dit indhold under:';
+$lang['i_license_none']        = 'Vis ikke licensinformationer';
+$lang['i_pop_field']           = 'Hjælp os venligst med at forbedre oplevelsen af DokuWiki:';
+$lang['i_pop_label']           = 'Send anonymt brugsdata til DokuWikis udviklere, én gang om måneden';
 $lang['recent_global']         = 'Du ser lige nu ændringerne i <b>%s</b> navnerummet. Du kan også <a href="%s">se de sidste ændringer for hele wiki siden </a>';
 $lang['years']                 = '%d år siden';
 $lang['months']                = '%d måned siden';
@@ -325,3 +346,11 @@ $lang['media_perm_read']       = 'Du har ikke nok rettigheder til at læse filer
 $lang['media_perm_upload']     = 'Du har ikke nok rettigheder til at uploade filer.';
 $lang['media_update']          = 'Upload ny version';
 $lang['media_restore']         = 'Genskab denne version';
+$lang['media_acl_warning']     = 'Listen er måske ikke komplet pga. ACL restriktioner og skjulte sider.';
+$lang['currentns']             = 'Nuværende navnerum';
+$lang['searchresult']          = 'Søgsresultat';
+$lang['plainhtml']             = 'Ren HTML';
+$lang['wikimarkup']            = 'Wiki Opmærkning';
+$lang['page_nonexist_rev']     = 'Siden blev ikke fundet ved %s. Den blev efterfølgende oprettet ved <a href="%s">%s</a>.';
+$lang['email_signature_text']  = 'Denne e-mail blev genereret af DokuWiki på
+@DOKUWIKIURL@';
