@@ -1,15 +1,13 @@
 <?php
+
 /**
- * Esperanta dosiero
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
+ * @author Kristjan SCHMIDT <kristjan.schmidt@googlemail.com>
  * @author Antono Vasiljev <esperanto.minsk ĈE tut.by>
  * @author Felipe Castro <fefcas@yahoo.com.br>
- * @author Felipe Castro <fefcas@uol.com.br>
- * @author Felipe Castro <fefcas@gmail.com>
  * @author Robert Bogenschneider <robog@gmx.de>
  * @author Erik Pedersen <erik.pedersen@shaw.ca>
- * @author Robert Bogenschneider <bogi@uea.org>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -17,7 +15,7 @@ $lang['doublequoteopening']    = '“';
 $lang['doublequoteclosing']    = '”';
 $lang['singlequoteopening']    = '‘';
 $lang['singlequoteclosing']    = '’';
-$lang['apostrophe']            = '\'';
+$lang['apostrophe']            = '’';
 $lang['btn_edit']              = 'Redakti la paĝon';
 $lang['btn_source']            = 'Montri fontan tekston';
 $lang['btn_show']              = 'Montri paĝon';
@@ -37,13 +35,12 @@ $lang['btn_secedit']           = 'Redakti';
 $lang['btn_login']             = 'Ensaluti';
 $lang['btn_logout']            = 'Elsaluti';
 $lang['btn_admin']             = 'Administri';
-$lang['btn_update']            = 'Ĝisdatigi';
+$lang['btn_update']            = 'Aktualigi';
 $lang['btn_delete']            = 'Forigi';
 $lang['btn_back']              = 'Retroiri';
 $lang['btn_backlink']          = 'Retroligoj';
-$lang['btn_backtomedia']       = 'Retroiri al elekto de dosiero';
 $lang['btn_subscribe']         = 'Aliĝi al paĝaj modifoj';
-$lang['btn_profile']           = 'Ĝisdatigi profilon';
+$lang['btn_profile']           = 'Aktualigi profilon';
 $lang['btn_reset']             = 'Rekomenci';
 $lang['btn_resendpwd']         = 'Sendi novan pasvorton';
 $lang['btn_draft']             = 'Redakti skizon';
@@ -53,7 +50,10 @@ $lang['btn_revert']            = 'Restarigi';
 $lang['btn_register']          = 'Registriĝi';
 $lang['btn_apply']             = 'Apliki';
 $lang['btn_media']             = 'Medio-administrilo';
-$lang['loggedinas']            = 'Ensalutinta kiel';
+$lang['btn_deleteuser']        = 'Forigi mian konton';
+$lang['btn_img_backto']        = 'Iri reen al %s';
+$lang['btn_mediaManager']      = 'Rigardi en aŭdvidaĵ-administrilo';
+$lang['loggedinas']            = 'Ensalutinta kiel:';
 $lang['user']                  = 'Uzant-nomo';
 $lang['pass']                  = 'Pasvorto';
 $lang['newpass']               = 'Nova pasvorto';
@@ -64,6 +64,7 @@ $lang['fullname']              = 'Kompleta nomo';
 $lang['email']                 = 'Retpoŝto';
 $lang['profile']               = 'Uzanto-profilo';
 $lang['badlogin']              = 'Pardonu, uzant-nomo aŭ pasvorto estis erara.';
+$lang['badpassconfirm']        = 'Pardonu, la pasvorto malĝustis';
 $lang['minoredit']             = 'Etaj modifoj';
 $lang['draftdate']             = 'Lasta konservo de la skizo:';
 $lang['nosecedit']             = 'La paĝo ŝanĝiĝis intertempe, sekcio-informo estis malĝisdata, tial la tuta paĝo estas reŝargita.';
@@ -71,6 +72,7 @@ $lang['regmissing']            = 'Pardonu, vi devas plenigi ĉiujn kampojn.';
 $lang['reguexists']            = 'Pardonu, ĉi tiu uzanto-nomo jam ekzistas.';
 $lang['regsuccess']            = 'La uzanto kreiĝis kaj la pasvorto sendiĝis per retpoŝto.';
 $lang['regsuccess2']           = 'La uzanto kreiĝis.';
+$lang['regfail']               = 'Ne eblis krei uzanton.';
 $lang['regmailfail']           = 'Ŝajne okazis eraro dum elsendo de la pasvorto. Bonvolu informi administranton pri tio!';
 $lang['regbadmail']            = 'Entajpita retpoŝta adreso ŝajnas ne valida. Se vi pensas, ke tio estas eraro, kontaktu la administranton.';
 $lang['regbadpass']            = 'La du pasvortoj ne samas, bonvolu provi refoje.';
@@ -79,7 +81,13 @@ $lang['reghere']               = 'Se vi ne havas konton, vi povas akiri ĝin';
 $lang['profna']                = 'Tiu ĉi vikio ne ebligas modifon en la profiloj.';
 $lang['profnochange']          = 'Neniu ŝanĝo, nenio farinda.';
 $lang['profnoempty']           = 'Malplena nomo aŭ retadreso ne estas permesata.';
-$lang['profchanged']           = 'La profilo de la uzanto sukcese ĝisdatiĝis.';
+$lang['profchanged']           = 'La profilo de la uzanto sukcese aktualiĝis.';
+$lang['profnodelete']          = 'Tiu ĉi vikio ne subtenas forigo de uzantoj';
+$lang['profdeleteuser']        = 'Forigi aliĝon';
+$lang['profdeleted']           = 'Via uzant-aliĝo estis forigata de tiu ĉi vikio';
+$lang['profconfdelete']        = 'Mi deziras forigi mian aliĝon de tiu ĉi vikio. <br/> Tiu ĉi ago ne povos esti malfarata.';
+$lang['profconfdeletemissing'] = 'Konfirmilo ne estas markita';
+$lang['proffail']              = 'La uzantokonto ne estis aktualigita.';
 $lang['pwdforget']             = 'Ĉu vi forgesis vian pasvorton? Prenu novan';
 $lang['resendna']              = 'Tiu ĉi vikio ne ebligas resendon de la pasvortoj.';
 $lang['resendpwd']             = 'Sendi novan pasvorton al';
@@ -92,12 +100,12 @@ $lang['license']               = 'Krom kie rekte indikite, enhavo de tiu ĉi vik
 $lang['licenseok']             = 'Rimarku: redaktante tiun ĉi paĝon vi konsentas publikigi vian enhavon laŭ la jena permesilo:';
 $lang['searchmedia']           = 'Serĉi dosiernomon:';
 $lang['searchmedia_in']        = 'Serĉi en %s';
-$lang['txt_upload']            = 'Elektu dosieron por alŝuti';
-$lang['txt_filename']          = 'Alŝuti kiel (laŭvole)';
+$lang['txt_upload']            = 'Elektu dosieron por alŝuti:';
+$lang['txt_filename']          = 'Alŝuti kiel (laŭvole):';
 $lang['txt_overwrt']           = 'Anstataŭigi ekzistantan dosieron';
 $lang['maxuploadsize']         = 'Alŝuto maks. %s po dosiero.';
-$lang['lockedby']              = 'Nune ŝlosita de';
-$lang['lockexpire']            = 'Ŝlosado ĉesos en';
+$lang['lockedby']              = 'Nune ŝlosita de:';
+$lang['lockexpire']            = 'Ŝlosado ĉesos je:';
 $lang['js']['willexpire']      = 'Vi povos redakti ĉi tiun paĝon post unu minuto.\nSe vi volas nuligi tempokontrolon de la ŝlosado, premu la butonon "Antaŭrigardi".';
 $lang['js']['notsavedyet']     = 'Ne konservitaj modifoj perdiĝos.
 Ĉu vi certe volas daŭrigi la procezon?';
@@ -143,7 +151,6 @@ $lang['js']['media_overwrt']   = 'Anstataûi ekzistantajn dosierojn';
 $lang['rssfailed']             = 'Okazis eraro dum ricevado de la novaĵ-fluo: ';
 $lang['nothingfound']          = 'Ankoraŭ nenio troviĝas tie ĉi.';
 $lang['mediaselect']           = 'Elekto de aŭdvidaĵa dosiero';
-$lang['fileupload']            = 'Alŝuto de aŭdvidaĵa dosiero';
 $lang['uploadsucc']            = 'Alŝuto sukcesis';
 $lang['uploadfail']            = 'Alŝuto malsukcesis. Ĉu eble estas problemoj pro permes-atributoj?';
 $lang['uploadwrong']           = 'Rifuzita alŝuto. Tiu ĉi dosiersufikso estas malpermesata!';
@@ -177,10 +184,15 @@ $lang['difflink']              = 'Ligilo al kompara rigardo';
 $lang['diff_type']             = 'Rigardi malsamojn:';
 $lang['diff_inline']           = 'Samlinie';
 $lang['diff_side']             = 'Apude';
+$lang['diffprevrev']           = 'Antaŭa revizio';
+$lang['diffnextrev']           = 'Sekva revizio';
+$lang['difflastrev']           = 'Lasta revizio';
+$lang['diffbothprevrev']       = 'Sur ambaŭ flankoj antaŭa revizio';
+$lang['diffbothnextrev']       = 'Sur ambaŭ flankoj sekva revizio';
 $lang['line']                  = 'Linio';
-$lang['breadcrumb']            = 'Paŝoj';
-$lang['youarehere']            = 'Vi estas ĉi tie';
-$lang['lastmod']               = 'Lastaj ŝanĝoj';
+$lang['breadcrumb']            = 'Paŝoj:';
+$lang['youarehere']            = 'Vi estas ĉi tie:';
+$lang['lastmod']               = 'Lastaj ŝanĝoj:';
 $lang['by']                    = 'de';
 $lang['deleted']               = 'forigita';
 $lang['created']               = 'kreita';
@@ -229,24 +241,21 @@ $lang['qb_sig']                = 'Inkluzivi subskribon';
 $lang['qb_smileys']            = 'Ridetuloj';
 $lang['qb_chars']              = 'Specialaj signaĵoj';
 $lang['upperns']               = 'saltu al la parenca nomspaco';
-$lang['admin_register']        = 'Aldoni novan uzanton';
 $lang['metaedit']              = 'Redakti metadatumaron';
 $lang['metasaveerr']           = 'La konservo de metadatumaro malsukcesis';
 $lang['metasaveok']            = 'La metadatumaro konserviĝis';
-$lang['img_backto']            = 'Iri reen al';
-$lang['img_title']             = 'Titolo';
-$lang['img_caption']           = 'Priskribo';
-$lang['img_date']              = 'Dato';
-$lang['img_fname']             = 'Dosiernomo';
-$lang['img_fsize']             = 'Grandeco';
-$lang['img_artist']            = 'Fotisto';
-$lang['img_copyr']             = 'Kopirajtoj';
-$lang['img_format']            = 'Formato';
-$lang['img_camera']            = 'Kamerao';
-$lang['img_keywords']          = 'Ŝlosilvortoj';
-$lang['img_width']             = 'Larĝeco';
-$lang['img_height']            = 'Alteco';
-$lang['img_manager']           = 'Rigardi en aŭdvidaĵ-administrilo';
+$lang['img_title']             = 'Titolo:';
+$lang['img_caption']           = 'Priskribo:';
+$lang['img_date']              = 'Dato:';
+$lang['img_fname']             = 'Dosiernomo:';
+$lang['img_fsize']             = 'Grandeco:';
+$lang['img_artist']            = 'Fotisto:';
+$lang['img_copyr']             = 'Kopirajtoj:';
+$lang['img_format']            = 'Formato:';
+$lang['img_camera']            = 'Kamerao:';
+$lang['img_keywords']          = 'Ŝlosilvortoj:';
+$lang['img_width']             = 'Larĝeco:';
+$lang['img_height']            = 'Alteco:';
 $lang['subscr_subscribe_success'] = 'Aldonis %s al la abonlisto por %s';
 $lang['subscr_subscribe_error'] = 'Eraro dum aldono de %s al la abonlisto por %s';
 $lang['subscr_subscribe_noaddress'] = 'Ne estas adreso ligita al via ensaluto, ne eblas aldoni vin al la abonlisto';
@@ -263,9 +272,7 @@ $lang['subscr_m_receive']      = 'Ricevi';
 $lang['subscr_style_every']    = 'retpoŝtaĵo pro ĉiu ŝanĝo';
 $lang['subscr_style_digest']   = 'resuma retpoŝtaĵo de ŝanĝoj por ĉiu paĝo (je %.2f tagoj)';
 $lang['subscr_style_list']     = 'listo de ŝanĝitaj paĝoj ekde la lasta retpoŝtaĵo (je %.2f tagoj)';
-$lang['authmodfailed']         = 'Malbona agordo por identigi la uzanton. Bonvolu informi la administranton de la vikio.';
 $lang['authtempfail']          = 'La identigo de via uzantonomo estas intertempe maldisponebla. Se tiu ĉi situacio daŭros, bonvolu informi la adminstranton de la vikio.';
-$lang['authpwdexpire']         = 'Via pasvorto malvalidos post %d tagoj, prefere ŝanĝu ĝin baldaũ.';
 $lang['i_chooselang']          = 'Elektu vian lingvon';
 $lang['i_installer']           = 'Instalilo de DokuWiki';
 $lang['i_wikiname']            = 'Nomo de la vikio';
@@ -287,6 +294,7 @@ $lang['i_policy']              = 'Komenca ACL-a agordo';
 $lang['i_pol0']                = 'Malferma Vikio (legi, skribi, alŝuti povas ĉiuj)';
 $lang['i_pol1']                = 'Publika Vikio (legi povas ĉiuj, skribi kaj alŝuti povas registritaj uzantoj)';
 $lang['i_pol2']                = 'Ferma Vikio (legi, skribi, alŝuti nur povas registritaj uzantoj)';
+$lang['i_allowreg']            = 'Permesi al uzantoj registri sin mem';
 $lang['i_retry']               = 'Reprovi';
 $lang['i_license']             = 'Bonvolu elekti la permesilon, sub kiun vi volas meti vian enhavon:';
 $lang['i_license_none']        = 'Ne montri licencinformojn';
@@ -324,3 +332,9 @@ $lang['media_perm_read']       = 'Bedaûrinde viaj rajtoj ne sufiĉas por legi d
 $lang['media_perm_upload']     = 'Bedaûrinde viaj rajtoj ne sufiĉas por alŝuti dosierojn.';
 $lang['media_update']          = 'Alŝuti novan version';
 $lang['media_restore']         = 'Restarigi ĉi tiun version';
+$lang['currentns']             = 'Aktuala nomspaco';
+$lang['searchresult']          = 'Serĉrezulto';
+$lang['plainhtml']             = 'Plena HTML';
+$lang['wikimarkup']            = 'Vikiteksto';
+$lang['email_signature_text']  = 'Tiu ĉi mesaĝo kreiĝis de DokuWiki ĉe
+@DOKUWIKIURL@';
