@@ -1,18 +1,21 @@
 <?php
+
 /**
- * Indonesian language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
  * @author mubaidillah <mubaidillah@gmail.com>
  * @author Irwan Butar Butar <irwansah.putra@gmail.com>
  * @author Yustinus Waruwu <juswaruwu@gmail.com>
+ * @author zamroni <therons@ymail.com>
+ * @author umriya afini <bigdream.power@gmail.com>
+ * @author Arif Budiman <me@kangarif.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
-$lang['doublequoteopening']    = '"';
-$lang['doublequoteclosing']    = '"';
-$lang['singlequoteopening']    = '\'';
-$lang['singlequoteclosing']    = '\'';
+$lang['doublequoteopening']    = '“';
+$lang['doublequoteclosing']    = '”';
+$lang['singlequoteopening']    = '‘';
+$lang['singlequoteclosing']    = '’';
 $lang['apostrophe']            = '\'';
 $lang['btn_edit']              = 'Edit halaman ini';
 $lang['btn_source']            = 'Lihat sumber halaman';
@@ -20,7 +23,6 @@ $lang['btn_show']              = 'Tampilkan halaman';
 $lang['btn_create']            = 'Buat halaman baru';
 $lang['btn_search']            = 'Cari';
 $lang['btn_save']              = 'Simpan';
-$lang['btn_preview']           = 'Preview';
 $lang['btn_top']               = 'kembali ke atas';
 $lang['btn_newer']             = '<< lebih lanjut';
 $lang['btn_older']             = 'sebelumnya >>';
@@ -29,7 +31,6 @@ $lang['btn_recent']            = 'Perubahan terbaru';
 $lang['btn_upload']            = 'Upload';
 $lang['btn_cancel']            = 'Batal';
 $lang['btn_index']             = 'Indeks';
-$lang['btn_secedit']           = 'Edit';
 $lang['btn_login']             = 'Login';
 $lang['btn_logout']            = 'Keluar';
 $lang['btn_admin']             = 'Admin';
@@ -37,15 +38,19 @@ $lang['btn_update']            = 'Ubah';
 $lang['btn_delete']            = 'Hapus';
 $lang['btn_back']              = 'Kembali';
 $lang['btn_backlink']          = 'Backlinks';
-$lang['btn_backtomedia']       = 'Kembali ke Pilihan Mediafile';
 $lang['btn_subscribe']         = 'Ikuti Perubahan';
-$lang['btn_unsubscribe']       = 'Berhenti Ikuti Perubahan';
 $lang['btn_profile']           = 'Ubah Profil';
-$lang['btn_reset']             = 'Reset';
-$lang['btn_draft']             = 'Edit draft';
+$lang['btn_resendpwd']         = 'Atur password baru';
+$lang['btn_recover']           = 'Cadangkan draf';
 $lang['btn_draftdel']          = 'Hapus draft';
+$lang['btn_revert']            = 'Kembalikan';
 $lang['btn_register']          = 'Daftar';
-$lang['loggedinas']            = 'Login sebagai ';
+$lang['btn_apply']             = 'Terapkan';
+$lang['btn_media']             = 'Pengelola Media';
+$lang['btn_deleteuser']        = 'Hapus Akun Saya';
+$lang['btn_img_backto']        = 'Kembali ke %s';
+$lang['btn_mediaManager']      = 'Tampilkan di pengelola media';
+$lang['loggedinas']            = 'Login sebagai :';
 $lang['user']                  = 'Username';
 $lang['pass']                  = 'Password';
 $lang['newpass']               = 'Password baru';
@@ -56,6 +61,7 @@ $lang['fullname']              = 'Nama lengkap';
 $lang['email']                 = 'E-Mail';
 $lang['profile']               = 'Profil User';
 $lang['badlogin']              = 'Maaf, username atau password salah.';
+$lang['badpassconfirm']        = 'Maaf, password salah';
 $lang['minoredit']             = 'Perubahan Minor';
 $lang['draftdate']             = 'Simpan draft secara otomatis';
 $lang['regmissing']            = 'Maaf, Anda harus mengisi semua field.';
@@ -71,24 +77,74 @@ $lang['profna']                = 'Wiki ini tidak mengijinkan perubahan profil.';
 $lang['profnochange']          = 'Tidak ada perubahan.';
 $lang['profnoempty']           = 'Mohon mengisikan nama atau alamat email.';
 $lang['profchanged']           = 'Profil User berhasil diubah.';
+$lang['profnodelete']          = 'Wiki ini tidak mendukung penghapusan pengguna';
+$lang['profdeleteuser']        = 'Hapus Akun';
+$lang['profdeleted']           = 'Akun anda telah dihapus dari wiki ini';
+$lang['profconfdelete']        = 'Saya berharap menghapus akun saya dari wiki ini.
+Aksi ini tidak bisa diselesaikan.';
+$lang['profconfdeletemissing'] = 'Knfirmasi check box tidak tercentang';
 $lang['pwdforget']             = 'Lupa Password? Dapatkan yang baru';
 $lang['resendna']              = 'Wiki ini tidak mendukung pengiriman ulang password.';
+$lang['resendpwd']             = 'Atur password baru';
 $lang['resendpwdmissing']      = 'Maaf, Anda harus mengisikan semua field.';
 $lang['resendpwdnouser']       = 'Maaf, user ini tidak ditemukan.';
 $lang['resendpwdbadauth']      = 'Maaf, kode autentikasi tidak valid. Pastikan Anda menggunakan keseluruhan link konfirmasi.';
 $lang['resendpwdconfirm']      = 'Link konfirmasi telah dikirim melalui email.';
 $lang['resendpwdsuccess']      = 'Password baru Anda telah dikirim melalui email.';
-$lang['txt_upload']            = 'File yang akan diupload';
-$lang['txt_filename']          = 'Masukkan nama wiki (opsional)';
+$lang['license']               = 'Kecuali jika dinyatakan lain, konten pada wiki ini dilisensikan dibawah lisensi berikut:';
+$lang['licenseok']             = 'Catatan: Dengan menyunting halaman ini, Anda setuju untuk melisensikan konten Anda dibawah lisensi berikut:';
+$lang['searchmedia']           = 'Cari nama file:';
+$lang['searchmedia_in']        = 'Cari di %s';
+$lang['txt_upload']            = 'File yang akan diupload:';
+$lang['txt_filename']          = 'Masukkan nama wiki (opsional):';
 $lang['txt_overwrt']           = 'File yang telah ada akan ditindih';
-$lang['lockedby']              = 'Sedang dikunci oleh';
-$lang['lockexpire']            = 'Penguncian artikel sampai dengan';
-$lang['js']['willexpire']            = 'Halaman yang sedang Anda kunci akan berakhir dalam waktu kurang lebih satu menit.\nUntuk menghindari konflik, gunakan tombol Preview untuk me-reset timer pengunci.';
+$lang['maxuploadsize']         = 'Unggah maks. %s per berkas';
+$lang['lockedby']              = 'Sedang dikunci oleh:';
+$lang['lockexpire']            = 'Penguncian artikel sampai dengan:';
+$lang['js']['willexpire']      = 'Halaman yang sedang Anda kunci akan berakhir dalam waktu kurang lebih satu menit.\nUntuk menghindari konflik, gunakan tombol Preview untuk me-reset timer pengunci.';
 $lang['js']['notsavedyet']     = 'Perubahan yang belum disimpan akan hilang.\nYakin akan dilanjutkan?';
+$lang['js']['searchmedia']     = 'Cari file';
+$lang['js']['keepopen']        = 'Biarkan window terbuka dalam pemilihan';
+$lang['js']['hidedetails']     = 'Sembunyikan detil';
+$lang['js']['mediatitle']      = 'Pengaturan Link';
+$lang['js']['mediadisplay']    = 'Jenis tautan';
+$lang['js']['mediaalign']      = 'Perataan';
+$lang['js']['mediasize']       = 'Ukuran gambar';
+$lang['js']['mediatarget']     = 'Tautan tujuan';
+$lang['js']['mediaclose']      = 'Tutup';
+$lang['js']['mediainsert']     = 'Sisip';
+$lang['js']['mediadisplayimg'] = 'Lihat gambar';
+$lang['js']['mediadisplaylnk'] = 'Lihat hanya link';
+$lang['js']['mediasmall']      = 'Versi kecil';
+$lang['js']['mediamedium']     = 'Versi sedang';
+$lang['js']['medialarge']      = 'Versi besar';
+$lang['js']['mediaoriginal']   = 'Versi asli';
+$lang['js']['medialnk']        = 'Tautan ke halaman rincian';
+$lang['js']['mediadirect']     = 'Tautan langsung ke aslinya';
+$lang['js']['medianolnk']      = 'Tanpa tautan';
+$lang['js']['medianolink']     = 'Jangan tautkan gambar';
+$lang['js']['medialeft']       = 'Rata gambar sebelah kiri';
+$lang['js']['mediaright']      = 'Rata gambar sebelah kanan';
+$lang['js']['mediacenter']     = 'Rata gambar di tengah';
+$lang['js']['medianoalign']    = 'Jangan gunakan perataan';
+$lang['js']['nosmblinks']      = 'Link ke share Windows hanya bekerja di Microsoft Internet Explorer.
+Anda masih dapat mengcopy and paste linknya.';
+$lang['js']['linkwiz']         = 'Wizard Tautan';
+$lang['js']['linkto']          = 'Tautkan ke:';
+$lang['js']['del_confirm']     = 'Hapus tulisan ini?';
+$lang['js']['restore_confirm'] = 'Benar-benar ingin mengembalikan versi ini?';
+$lang['js']['media_diff']      = 'Lihat perbedaan:';
+$lang['js']['media_diff_both'] = 'Berdampingan';
+$lang['js']['media_diff_opacity'] = 'Mencolok';
+$lang['js']['media_select']    = 'Pilih file...';
+$lang['js']['media_upload_btn'] = 'Unggah';
+$lang['js']['media_done_btn']  = 'Selesai';
+$lang['js']['media_drop']      = 'Tarik file disini untuk mengunggah';
+$lang['js']['media_cancel']    = 'Buang';
+$lang['js']['media_overwrt']   = 'Timpa berkas yang ada';
 $lang['rssfailed']             = 'Error terjadi saat mengambil feed: ';
 $lang['nothingfound']          = 'Tidak menemukan samasekali.';
 $lang['mediaselect']           = 'Pilihan Mediafile';
-$lang['fileupload']            = 'Mediafile Upload';
 $lang['uploadsucc']            = 'Upload sukses';
 $lang['uploadfail']            = 'Upload gagal. Apakah hak ijinnya salah?';
 $lang['uploadwrong']           = 'Upload ditolak. Ekstensi file ini tidak diperbolehkan!';
@@ -96,13 +152,13 @@ $lang['uploadexist']           = 'File telah ada. Tidak mengerjakan apa-apa.';
 $lang['uploadbadcontent']      = 'Isi file yang diupload tidak cocok dengan ekstensi file %s.';
 $lang['uploadspam']            = 'File yang diupload diblok oleh spam blacklist.';
 $lang['uploadxss']             = 'File yang diupload diblok karena kemungkinan isi yang berbahaya.';
+$lang['uploadsize']            = 'File yang diupload terlalu besar. (max. %s)';
 $lang['deletesucc']            = 'File "%s" telah dihapus.';
 $lang['deletefail']            = '"%s" tidak dapat dihapus - cek hak aksesnya.';
 $lang['mediainuse']            = 'File "%s" belum dihapus - file ini sedang digunakan.';
 $lang['namespaces']            = 'Namespaces';
 $lang['mediafiles']            = 'File tersedia didalam';
-$lang['js']['keepopen']        = 'Biarkan window terbuka dalam pemilihan';
-$lang['js']['hidedetails']     = 'Sembunyikan detil';
+$lang['accessdenied']          = 'Anda tidak diperbolehkan melihat halaman ini';
 $lang['mediausage']            = 'Gunakan sintaks berikut untuk me-refer ke file ini';
 $lang['mediaview']             = 'Tampilkan file asli';
 $lang['mediaroot']             = 'root';
@@ -111,69 +167,89 @@ $lang['mediaextchange']        = 'Ektensi file berubah dari .%s ke .%s';
 $lang['reference']             = 'Referensi untuk';
 $lang['ref_inuse']             = 'File tidak dapat dihapus karena sedang digunakan oleh halaman:';
 $lang['ref_hidden']            = 'Beberapa referensi ada didalam halaman yang tidak diijinkan untuk Anda baca.';
-$lang['hits']                  = 'Hits';
 $lang['quickhits']             = 'Matching pagenames';
 $lang['toc']                   = 'Daftar isi';
 $lang['current']               = 'sekarang';
 $lang['yours']                 = 'Versi Anda';
 $lang['diff']                  = 'Tampilkan perbedaan dengan versi sekarang';
 $lang['diff2']                 = 'Tampilkan perbedaan diantara revisi terpilih';
+$lang['difflink']              = 'Tautan ke tampilan pembanding ini';
+$lang['diff_type']             = 'Tampilkan perbedaan:';
+$lang['diff_inline']           = 'Sebaris';
+$lang['diff_side']             = 'Berdampingan';
+$lang['diffprevrev']           = 'Revisi sebelumnya';
+$lang['diffnextrev']           = 'Revisi selanjutnya';
+$lang['difflastrev']           = 'Revisi terakhir';
 $lang['line']                  = 'Baris';
-$lang['breadcrumb']            = 'Jejak';
-$lang['youarehere']            = 'Anda disini';
-$lang['lastmod']               = 'Terakhir diubah';
+$lang['breadcrumb']            = 'Jejak:';
+$lang['youarehere']            = 'Anda disini:';
+$lang['lastmod']               = 'Terakhir diubah:';
 $lang['by']                    = 'oleh';
 $lang['deleted']               = 'terhapus';
 $lang['created']               = 'dibuat';
 $lang['restored']              = 'revisi lama ditampilkan kembali (%s)';
 $lang['external_edit']         = 'Perubahan eksternal';
-$lang['summary']               = 'Edit summary';
+$lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> diperlukan untuk menampilkan konten ini.';
+$lang['download']              = 'Unduh Cuplikan';
+$lang['tools']                 = 'Alat';
+$lang['user_tools']            = 'Alat Pengguna';
+$lang['site_tools']            = 'Alat Situs';
+$lang['page_tools']            = 'Alat Halaman';
+$lang['skip_to_content']       = 'lewati ke konten';
+$lang['sidebar']               = 'Bilah Sisi';
 $lang['mail_newpage']          = 'Halaman ditambahkan:';
 $lang['mail_changed']          = 'Halaman diubah:';
+$lang['mail_subscribe_list']   = 'halaman diubah dalam namespace:';
 $lang['mail_new_user']         = 'User baru:';
 $lang['mail_upload']           = 'Berkas di-upload:';
-$lang['js']['nosmblinks']            = "Link ke share Windows hanya bekerja di Microsoft Internet Explorer.\nAnda masih dapat mengcopy and paste linknya.";
+$lang['changes_type']          = 'Tampilkan perubahan';
+$lang['pages_changes']         = 'Halaman';
+$lang['media_changes']         = 'Berkas media';
+$lang['both_changes']          = 'Baik halaman dan berkas media';
 $lang['qb_bold']               = 'Tebal';
 $lang['qb_italic']             = 'Miring';
 $lang['qb_underl']             = 'Garis Bawah';
 $lang['qb_code']               = 'Kode';
 $lang['qb_strike']             = 'Text Tercoret';
-$lang['qb_h1']                 = 'Level 1 Headline';
-$lang['qb_h2']                 = 'Level 2 Headline';
-$lang['qb_h3']                 = 'Level 3 Headline';
-$lang['qb_h4']                 = 'Level 4 Headline';
-$lang['qb_h5']                 = 'Level 5 Headline';
-$lang['qb_link']               = 'Link Internal';
-$lang['qb_extlink']            = 'Link External';
+$lang['qb_hs']                 = 'Pilih Judul';
+$lang['qb_hplus']              = 'Judul Lebih Atas';
+$lang['qb_hminus']             = 'Judul Lebih Bawah';
+$lang['qb_hequal']             = 'Tingkat Judul yang Sama';
 $lang['qb_hr']                 = 'Garis Horisontal';
 $lang['qb_ol']                 = 'Item Berurutan';
 $lang['qb_ul']                 = 'Item Tidak Berurutan';
 $lang['qb_media']              = 'Tambahkan gambar atau file lain';
 $lang['qb_sig']                = 'Sisipkan tanda tangan';
-$lang['qb_smileys']            = 'Smileys';
 $lang['qb_chars']              = 'Karakter Khusus';
-$lang['js']['del_confirm']           = 'Hapus tulisan ini?';
-$lang['admin_register']        = 'Tambah user baru';
-$lang['metaedit']              = 'Edit Metadata';
+$lang['upperns']               = 'lompat ke namespace induk';
 $lang['metasaveerr']           = 'Gagal menulis metadata';
 $lang['metasaveok']            = 'Metadata tersimpan';
-$lang['img_backto']            = 'Kembali ke';
-$lang['img_title']             = 'Judul';
-$lang['img_caption']           = 'Label';
-$lang['img_date']              = 'Tanggal';
-$lang['img_fname']             = 'Nama file';
-$lang['img_fsize']             = 'Ukuran';
-$lang['img_artist']            = 'Tukang foto';
-$lang['img_copyr']             = 'Hakcipta';
-$lang['img_format']            = 'Format';
-$lang['img_camera']            = 'Kamera';
-$lang['img_keywords']          = 'Katakunci';
-$lang['subscribe_success']     = 'Penambahan %s ke data subsripsi untuk %s';
-$lang['subscribe_error']       = 'Gagal menambahkan %s ke data subsripsi untuk %s';
-$lang['subscribe_noaddress']   = 'Tidak ditemukan alamat yang berhubungan dengan login Anda, Anda tidak dapat menambahkan daftar subscription';
-$lang['unsubscribe_success']   = 'Menghapus %s dari daftar subscription untuk %s';
-$lang['unsubscribe_error']     = 'Gagal menghapus %s dari daftar subscription untuk %s';
-$lang['authmodfailed']         = 'Konfigurasi autentikasi user tidak valid. Harap informasikan admin Wiki Anda.';
+$lang['img_title']             = 'Judul:';
+$lang['img_caption']           = 'Label:';
+$lang['img_date']              = 'Tanggal:';
+$lang['img_fname']             = 'Nama file:';
+$lang['img_fsize']             = 'Ukuran:';
+$lang['img_artist']            = 'Tukang foto:';
+$lang['img_copyr']             = 'Hakcipta:';
+$lang['img_format']            = 'Format:';
+$lang['img_camera']            = 'Kamera:';
+$lang['img_keywords']          = 'Katakunci:';
+$lang['img_width']             = 'Lebar:';
+$lang['img_height']            = 'Tinggi:';
+$lang['subscr_subscribe_success'] = 'Menambah %s ke senarai langganan untuk %s';
+$lang['subscr_subscribe_error'] = 'Kesalahan menambahkan %s ke senarai langganan untuk %s';
+$lang['subscr_subscribe_noaddress'] = 'Tidak ada alamat yang terkait dengan login Anda, Anda tidak dapat ditambahkan ke senarai langganan';
+$lang['subscr_unsubscribe_success'] = 'Menghapus %s dari senarai langganan untuk %s';
+$lang['subscr_unsubscribe_error'] = 'Kesalahan menghapus %s dari senarai langganan untuk %s';
+$lang['subscr_already_subscribed'] = '%s sudah dilanggankan ke %s';
+$lang['subscr_not_subscribed'] = '%s tidak dilanggankan ke %s';
+$lang['subscr_m_not_subscribed'] = 'Saat ini Anda tidak berlangganan halaman dan namespace saat ini.';
+$lang['subscr_m_new_header']   = 'Tambahkan langganan';
+$lang['subscr_m_current_header'] = 'Langganan saat ini';
+$lang['subscr_m_unsubscribe']  = 'Berhenti berlangganan';
+$lang['subscr_m_subscribe']    = 'Berlangganan';
+$lang['subscr_m_receive']      = 'Menerima';
+$lang['subscr_style_every']    = 'email setiap diubah';
 $lang['authtempfail']          = 'Autentikasi user saat ini sedang tidak dapat digunakan. Jika kejadian ini berlanjut, Harap informasikan admin Wiki Anda.';
 $lang['i_chooselang']          = 'Pilih bahasa';
 $lang['i_installer']           = 'Instalasi DokuWiki';
@@ -194,4 +270,43 @@ $lang['i_policy']              = 'Policy ACL awal';
 $lang['i_pol0']                = 'Wiki Terbuka (baca, tulis, upload untuk semua orang)';
 $lang['i_pol1']                = 'Wiki Publik (baca untuk semua orang, tulis dan upload untuk pengguna terdaftar)';
 $lang['i_pol2']                = 'Wiki Privat (baca, tulis dan upload hanya untuk pengguna terdaftar)';
+$lang['i_allowreg']            = 'Ijinkan pengguna mendaftar sendiri';
 $lang['i_retry']               = 'Coba Lagi';
+$lang['i_license']             = 'Silakan pilih lisensi untuk konten Anda:';
+$lang['i_license_none']        = 'Jangan tampilkan semua informasi lisensi';
+$lang['i_pop_field']           = 'Tolong, bantu kami meningkatkan pengalaman DokuWiki:';
+$lang['i_pop_label']           = 'Setiap bulan mengirimkan penggunaan data anonim ke pengembang DokuWiki';
+$lang['years']                 = '%d tahun yang lalu';
+$lang['months']                = '%d bulan yang lalu';
+$lang['weeks']                 = '%d minggu yang lalu';
+$lang['days']                  = '%d hari yang lalu';
+$lang['hours']                 = '%d jam yang lalu';
+$lang['minutes']               = '%d menit yang lalu';
+$lang['seconds']               = '%d detik yang lalu';
+$lang['wordblock']             = 'Pengubahan Anda tidak disimpan karena berisi teks yang diblokir (spam).';
+$lang['media_uploadtab']       = 'Unggah';
+$lang['media_searchtab']       = 'Cari';
+$lang['media_file']            = 'Berkas';
+$lang['media_viewtab']         = 'Lihat';
+$lang['media_edittab']         = 'Sunting';
+$lang['media_historytab']      = 'Riwayat';
+$lang['media_list_rows']       = 'Kolom';
+$lang['media_sort_name']       = 'Nama';
+$lang['media_sort_date']       = 'Tanggal';
+$lang['media_namespaces']      = 'Pilih namespace';
+$lang['media_upload']          = 'Unggah ke %s';
+$lang['media_search']          = 'Cari di %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s di %s';
+$lang['media_edit']            = 'Sunting %s';
+$lang['media_history']         = 'Riwayat %s';
+$lang['media_meta_edited']     = 'metadata disunting';
+$lang['media_perm_read']       = 'Maaf, Anda tidak memiliki izin untuk membaca berkas.';
+$lang['media_perm_upload']     = 'Maaf, Anda tidak memiliki izin untuk mengunggah berkas.';
+$lang['media_update']          = 'Unggah versi baru';
+$lang['media_restore']         = 'Kembalikan versi ini';
+$lang['currentns']             = 'Namespace saat ini';
+$lang['searchresult']          = 'Hasil Pencarian';
+$lang['wikimarkup']            = 'Markah Wiki';
+$lang['email_signature_text'] = 'Email ini dibuat otomatis oleh DokuWiki
+@DOKUWIKIURL@';
