@@ -6,8 +6,8 @@
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
-$lang['doublequoteopening']    = '"';
-$lang['doublequoteclosing']    = '"';
+$lang['doublequoteopening']    = '&quot;';
+$lang['doublequoteclosing']    = '&quot;';
 $lang['singlequoteopening']    = '‘';
 $lang['singlequoteclosing']    = '’';
 $lang['apostrophe']            = '\'';
@@ -34,16 +34,17 @@ $lang['btn_update']            = 'Жаңарту';
 $lang['btn_delete']            = 'Жою';
 $lang['btn_back']              = 'Артқа';
 $lang['btn_backlink']          = 'Кері сілтемелері';
-$lang['btn_backtomedia']       = 'Медиафайлды таңдауға қайту';
 $lang['btn_subscribe']         = 'Жазылуларды басқару';
 $lang['btn_profile']           = 'Профильді жаңарту';
 $lang['btn_reset']             = 'Түсіру';
+$lang['btn_resendpwd']         = 'Шартты белгінi Өзгерту';
 $lang['btn_draft']             = 'Шимайды өңдеу';
 $lang['btn_recover']           = 'Шимайды қайтару';
 $lang['btn_draftdel']          = 'Шимайды өшіру';
 $lang['btn_revert']            = 'Қалпына келтіру';
 $lang['btn_register']          = 'Тіркеу';
-$lang['loggedinas']            = 'түпнұсқамен кірген';
+$lang['btn_apply']             = 'Қолдану/Енгізу';
+$lang['loggedinas']            = 'түпнұсқамен кірген:';
 $lang['user']                  = 'Түпнұсқа';
 $lang['pass']                  = 'Құпиясөз';
 $lang['newpass']               = 'Жаңа құпиясөз';
@@ -81,12 +82,12 @@ $lang['license']               = 'Басқаша көрсетілген болм
 $lang['licenseok']             = 'Ескерту: бұл бетті өңдеуіңізбен мазмұныңыз келесі лицензия бойынша беруге келесесіз:';
 $lang['searchmedia']           = 'Іздеу файлдың атауы:';
 $lang['searchmedia_in']        = '%s-мен іздеу:';
-$lang['txt_upload']            = 'Еңгізетін файлды таңдау';
-$lang['txt_filename']          = 'Келесідей еңгізу (қалауынша)';
+$lang['txt_upload']            = 'Еңгізетін файлды таңдау:';
+$lang['txt_filename']          = 'Келесідей еңгізу (қалауынша):';
 $lang['txt_overwrt']           = 'Бар файлды қайта жазу';
-$lang['lockedby']              = 'Осы уақытта тойтарылған';
-$lang['lockexpire']            = 'Тойтару келесі уақытта бітеді';
-$lang['js']['willexpire']            = 'Бұл бетті түзеу тойтаруыңыз бір минутта бітеді. Қақтығыс болмау және тойтару таймерді түсіру үшін қарап шығу пернені басыңыз.';
+$lang['lockedby']              = 'Осы уақытта тойтарылған:';
+$lang['lockexpire']            = 'Тойтару келесі уақытта бітеді:';
+$lang['js']['willexpire']      = 'Бұл бетті түзеу тойтаруыңыз бір минутта бітеді. Қақтығыс болмау және тойтару таймерді түсіру үшін қарап шығу пернені басыңыз.';
 $lang['js']['notsavedyet']     = 'Сақталмаған өзгерістер жоғалатын болады.';
 $lang['js']['searchmedia']     = 'Файлдарды іздеу';
 $lang['js']['keepopen']        = 'Таңдаған соң терезе жаппаңыз';
@@ -112,3 +113,17 @@ $lang['js']['medialeft']       = 'Сүретті сол жаққа тегіст
 $lang['js']['mediaright']      = 'Сүретті оң жаққа тегістеу';
 $lang['js']['mediacenter']     = 'Сүретті ортаға тегістеу';
 $lang['js']['medianoalign']    = 'Тегістеусіз';
+$lang['js']['linkwiz']         = 'Сілтеме көмекшіci';
+$lang['js']['media_diff']      = 'Өзгеліктердi Көрсету';
+$lang['js']['media_select']    = 'Файлды тандау';
+$lang['mediaselect']           = 'Медиа файлдар';
+$lang['mediaroot']             = 'root';
+$lang['yours']                 = 'Сендердің болжамыңыз';
+$lang['created']               = 'ЖасалFан';
+$lang['mail_new_user']         = 'Жаңа пайдаланушы';
+$lang['qb_chars']              = 'Арнайы белгiлер';
+$lang['btn_img_backto']            = 'Қайта оралу %s';
+$lang['img_format']            = 'Формат:';
+$lang['img_camera']            = 'Камера:';
+$lang['i_chooselang']          = 'Тіл таңдау';
+$lang['i_retry']               = 'Қайталау';
