@@ -1,50 +1,56 @@
 <?php
+
 /**
- * Portuguese language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
  * @author José Carlos Monteiro <jose.c.monteiro@netcabo.pt>
  * @author José Monteiro <Jose.Monteiro@DoWeDo-IT.com>
  * @author Enrico Nicoletto <liverig@gmail.com>
  * @author Fil <fil@meteopt.com>
  * @author André Neves <drakferion@gmail.com>
  * @author José Campos zecarlosdecampos@gmail.com
+ * @author Murilo <muriloricci@hotmail.com>
+ * @author Paulo Silva <paulotsilva@yahoo.com>
+ * @author Guido Salatino <guidorafael23@gmail.com>
+ * @author Romulo Pereira <romuloccomp@gmail.com>
+ * @author Paulo Carmino <contato@paulocarmino.com>
+ * @author Alfredo Silva <alfredo.silva@sky.com>
+ * @author Guilherme Sá <guilherme.sa@hotmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
-$lang['doublequoteopening']    = '“';//&ldquo;
-$lang['doublequoteclosing']    = '”';//&rdquo;
-$lang['singlequoteopening']    = '‘';//&lsquo;
-$lang['singlequoteclosing']    = '’';//&rsquo;
-$lang['apostrophe']            = '’';//&rsquo;
-
-$lang['btn_edit']              = 'Editar página';
-$lang['btn_source']            = 'Ver fonte';
-$lang['btn_show']              = 'Ver página';
-$lang['btn_create']            = 'Criar página';
+$lang['doublequoteopening']    = '“';
+$lang['doublequoteclosing']    = '”';
+$lang['singlequoteopening']    = '‘';
+$lang['singlequoteclosing']    = '’';
+$lang['apostrophe']            = '’';
+$lang['btn_edit']              = 'Editar esta página';
+$lang['btn_source']            = 'Mostrar página fonte ';
+$lang['btn_show']              = 'Mostrar página';
+$lang['btn_create']            = 'Criar esta página';
 $lang['btn_search']            = 'Pesquisar';
-$lang['btn_save']              = 'Gravar';
-$lang['btn_preview']           = 'Prever';
+$lang['btn_save']              = 'Guardar';
+$lang['btn_preview']           = 'Pré-visualizar';
 $lang['btn_top']               = 'Voltar ao topo';
 $lang['btn_newer']             = '<< mais recente';
 $lang['btn_older']             = 'menos recente >>';
-$lang['btn_revs']              = 'Revisões';
-$lang['btn_recent']            = 'Alt. Recentes';
-$lang['btn_upload']            = 'Carregar';
+$lang['btn_revs']              = 'Revisões antigas';
+$lang['btn_recent']            = 'Alterações Recentes';
+$lang['btn_upload']            = 'Enviar';
 $lang['btn_cancel']            = 'Cancelar';
 $lang['btn_index']             = 'Índice';
 $lang['btn_secedit']           = 'Editar';
-$lang['btn_login']             = 'Entrar';
-$lang['btn_logout']            = 'Sair';
+$lang['btn_login']             = 'Iniciar sessão';
+$lang['btn_logout']            = 'Terminar sessão';
 $lang['btn_admin']             = 'Administrar';
 $lang['btn_update']            = 'Actualizar';
 $lang['btn_delete']            = 'Apagar';
 $lang['btn_back']              = 'Voltar';
 $lang['btn_backlink']          = 'Backlinks';
-$lang['btn_backtomedia']       = 'Voltar à Selecção de Media';
 $lang['btn_subscribe']         = 'Subscrever Alterações';
 $lang['btn_profile']           = 'Actualizar Perfil';
 $lang['btn_reset']             = 'Limpar';
+$lang['btn_resendpwd']         = 'Definir nova senha';
 $lang['btn_draft']             = 'Editar rascunho';
 $lang['btn_recover']           = 'Recuperar rascunho';
 $lang['btn_draftdel']          = 'Apagar rascunho';
@@ -52,8 +58,10 @@ $lang['btn_revert']            = 'Restaurar';
 $lang['btn_register']          = 'Registar';
 $lang['btn_apply']             = 'Aplicar';
 $lang['btn_media']             = 'Gestor de Media';
-
-$lang['loggedinas']            = 'Está em sessão como';
+$lang['btn_deleteuser']        = 'Remover a Minha Conta';
+$lang['btn_img_backto']        = 'De volta a %s';
+$lang['btn_mediaManager']      = 'Ver em gestor de media';
+$lang['loggedinas']            = 'Está em sessão como:';
 $lang['user']                  = 'Utilizador';
 $lang['pass']                  = 'Senha';
 $lang['newpass']               = 'Nova senha';
@@ -64,47 +72,50 @@ $lang['fullname']              = 'Nome completo';
 $lang['email']                 = 'Email';
 $lang['profile']               = 'Perfil do Utilizador';
 $lang['badlogin']              = 'O utilizador inválido ou senha inválida.';
+$lang['badpassconfirm']        = 'Infelizmente a palavra-passe não é a correcta';
 $lang['minoredit']             = 'Alterações Menores';
 $lang['draftdate']             = 'Rascunho automaticamente gravado em';
 $lang['nosecedit']             = 'A página foi modificada entretanto. Como a informação da secção estava desactualizada, foi carregada a página inteira.';
-
 $lang['regmissing']            = 'Por favor, preencha todos os campos.';
 $lang['reguexists']            = 'Este utilizador já está inscrito. Por favor escolha outro nome de utilizador.';
 $lang['regsuccess']            = 'O utilizador foi criado e a senha foi enviada para o endereço de correio electrónico usado na inscrição.';
 $lang['regsuccess2']           = 'O utilizador foi criado.';
+$lang['regfail']               = 'O usuário não pode ser criado.';
 $lang['regmailfail']           = 'Houve um erro no envio da senha por e-mail. Por favor, contacte o administrador!';
 $lang['regbadmail']            = 'O endereço de correio electrónico é inválido. Se o endereço está correcto, e isto é um erro, por favor, contacte o administrador!';
 $lang['regbadpass']            = 'As duas senhas não são idênticas, por favor tente de novo.';
 $lang['regpwmail']             = 'A sua senha DokuWiki';
 $lang['reghere']               = 'Para se registar, clique em';
-
 $lang['profna']                = 'Este Wiki não suporta modificações aos perfis.';
 $lang['profnochange']          = 'Nada alteração, nada a fazer.';
 $lang['profnoempty']           = 'Não são permitidos nomes ou endereços em branco.';
 $lang['profchanged']           = 'Perfil do utilizador actualizado com sucesso.';
-
+$lang['profnodelete']          = 'Esta wiki não suporta remoção de utilizadores';
+$lang['profdeleteuser']        = 'Apagar Conta';
+$lang['profdeleted']           = 'A sua conta de utilizador foi removida desta wiki';
+$lang['profconfdelete']        = 'Quero remover a minha conta desta wiki. <br/> Esta acção não pode ser anulada.';
+$lang['profconfdeletemissing'] = 'A caixa de confirmação não foi marcada';
+$lang['proffail']              = 'O perfil do usuário não foi atualizado.';
 $lang['pwdforget']             = 'Esqueceu a sua senha? Pedir nova senha';
 $lang['resendna']              = 'Este wiki não suporta reenvio de senhas.';
+$lang['resendpwd']             = 'Definir nova senha para';
 $lang['resendpwdmissing']      = 'É preciso preencher todos os campos.';
 $lang['resendpwdnouser']       = 'Não foi possível encontrar este utilizador.';
 $lang['resendpwdbadauth']      = 'O código de autenticação não é válido. Por favor, assegure-se de que o link de confirmação está completo.';
 $lang['resendpwdconfirm']      = 'O link de confirmação foi enviado por e-mail.';
 $lang['resendpwdsuccess']      = 'A nova senha foi enviada por e-mail.';
-
 $lang['license']               = 'Excepto menção em contrário, o conteúdo neste wiki está sob a seguinte licença:';
 $lang['licenseok']             = 'Nota: Ao editar esta página você aceita disponibilizar o seu conteúdo sob a seguinte licença:';
-
 $lang['searchmedia']           = 'Procurar nome de ficheiro:';
 $lang['searchmedia_in']        = 'Procurar em %s';
-$lang['txt_upload']            = 'Escolha ficheiro para carregar';
-$lang['txt_filename']          = 'Carregar como (opcional)';
+$lang['txt_upload']            = 'Escolha ficheiro para carregar:';
+$lang['txt_filename']          = 'Carregar como (opcional):';
 $lang['txt_overwrt']           = 'Escrever por cima do ficheiro já existente';
-$lang['lockedby']              = 'Bloqueado por';
-$lang['lockexpire']            = 'Expira em';
+$lang['maxuploadsize']         = 'Publique max. %s por arquivo.';
+$lang['lockedby']              = 'Bloqueado por:';
+$lang['lockexpire']            = 'Expira em:';
 $lang['js']['willexpire']      = 'O bloqueio de edição para este documento irá expirar num minuto.\nPara evitar conflitos use o botão Prever para re-iniciar o temporizador de bloqueio.';
-
 $lang['js']['notsavedyet']     = 'Alterações não gravadas serão perdidas.';
-
 $lang['js']['searchmedia']     = 'Procurar por ficheiros';
 $lang['js']['keepopen']        = 'Mantenha a janela aberta durante a selecção';
 $lang['js']['hidedetails']     = 'Esconder Detalhes';
@@ -135,10 +146,19 @@ $lang['js']['linkwiz']         = 'Assistente de Criação de Ligação';
 $lang['js']['linkto']          = 'Ligação para:';
 $lang['js']['del_confirm']     = 'Remover o(s) item(s) selecionados?';
 $lang['js']['restore_confirm'] = 'Restaurar esta versão?';
+$lang['js']['media_diff']      = 'Ver diferenças:';
+$lang['js']['media_diff_both'] = 'Lado a Lado';
+$lang['js']['media_diff_opacity'] = 'Sobreposição';
+$lang['js']['media_diff_portions'] = 'Slider';
+$lang['js']['media_select']    = 'Selecione ficheiros…';
+$lang['js']['media_upload_btn'] = 'Enviar';
+$lang['js']['media_done_btn']  = 'Feito';
+$lang['js']['media_drop']      = 'Largue ficheiros aqui para enviar';
+$lang['js']['media_cancel']    = 'remover';
+$lang['js']['media_overwrt']   = 'Escrever por cima de ficheiros existentes';
 $lang['rssfailed']             = 'Ocorreu um erro neste canal RSS: ';
 $lang['nothingfound']          = 'Nada foi encontrado.';
 $lang['mediaselect']           = 'Selecção de ficheiros';
-$lang['fileupload']            = 'Carregamento de ficheiros';
 $lang['uploadsucc']            = 'Carregamento com sucesso';
 $lang['uploadfail']            = 'Falhou o carregamento. Talvez por não ter permissões?';
 $lang['uploadwrong']           = 'Carregamento negado. Esta extensão está proibida.';
@@ -172,10 +192,15 @@ $lang['difflink']              = 'Ligação para esta vista de comparação';
 $lang['diff_type']             = 'Ver diferenças';
 $lang['diff_inline']           = 'Embutido';
 $lang['diff_side']             = 'Lado a lado';
+$lang['diffprevrev']           = 'Revisão anterior';
+$lang['diffnextrev']           = 'Próxima revisão';
+$lang['difflastrev']           = 'Última revisão';
+$lang['diffbothprevrev']       = 'Ambos os lados da revisão anterior';
+$lang['diffbothnextrev']       = 'Ambos os lados da próxima revisão';
 $lang['line']                  = 'Linha';
-$lang['breadcrumb']            = 'Está em';
-$lang['youarehere']            = 'Está aqui';
-$lang['lastmod']               = 'Esta página foi modificada pela última vez em';
+$lang['breadcrumb']            = 'Está em:';
+$lang['youarehere']            = 'Está aqui:';
+$lang['lastmod']               = 'Esta página foi modificada pela última vez em:';
 $lang['by']                    = 'por';
 $lang['deleted']               = 'Documento automaticamente removido.';
 $lang['created']               = 'Criação deste novo documento.';
@@ -184,15 +209,21 @@ $lang['external_edit']         = 'Edição externa';
 $lang['summary']               = 'Sumário da Edição';
 $lang['noflash']               = 'O <a href="http://www.adobe.com/products/flashplayer/">Plugin Adobe Flash</a> é necessário para exibir este conteúdo.';
 $lang['download']              = 'Descarregar Snippet';
-$lang['changes_type']          = 'Ver alterações de';
-$lang['pages_changes']         = 'Páginas';
-$lang['media_changes']         = 'Ficheiros Media';
-$lang['both_changes']          = 'Tanto páginas como ficheiros media';
+$lang['tools']                 = 'Ferramentas';
+$lang['user_tools']            = 'Ferramentas de Utilizador';
+$lang['site_tools']            = 'Ferramentas de Site';
+$lang['page_tools']            = 'Ferramentas de Página';
+$lang['skip_to_content']       = 'saltar para conteúdo';
+$lang['sidebar']               = 'Barra Lateral';
 $lang['mail_newpage']          = 'documento adicionado:';
 $lang['mail_changed']          = 'documento modificado:';
 $lang['mail_subscribe_list']   = 'páginas alteradas no espaço de nome:';
 $lang['mail_new_user']         = 'Novo utilizador:';
 $lang['mail_upload']           = 'Ficheiro carregado:';
+$lang['changes_type']          = 'Ver alterações de';
+$lang['pages_changes']         = 'Páginas';
+$lang['media_changes']         = 'Ficheiros Media';
+$lang['both_changes']          = 'Tanto páginas como ficheiros media';
 $lang['qb_bold']               = 'Texto com Ênfase';
 $lang['qb_italic']             = 'Texto Itálico';
 $lang['qb_underl']             = 'Texto Sublinhado';
@@ -218,24 +249,21 @@ $lang['qb_sig']                = 'Inserir Assinatura';
 $lang['qb_smileys']            = 'Smileys';
 $lang['qb_chars']              = 'Caracteres Especiais';
 $lang['upperns']               = 'Ir para o espaço de nomes parente';
-$lang['admin_register']        = 'Registar Novo Utilizador';
 $lang['metaedit']              = 'Editar Metadata';
 $lang['metasaveerr']           = 'Falhou a escrita de Metadata';
 $lang['metasaveok']            = 'Metadata gravada';
-$lang['img_backto']            = 'De volta a';
-$lang['img_title']             = 'Título';
-$lang['img_caption']           = 'Legenda';
-$lang['img_date']              = 'Data';
-$lang['img_fname']             = 'Ficheiro';
-$lang['img_fsize']             = 'Tamanho';
-$lang['img_artist']            = 'Fotógrafo';
-$lang['img_copyr']             = 'Copyright';
-$lang['img_format']            = 'Formato';
-$lang['img_camera']            = 'Câmara';
-$lang['img_keywords']          = 'Palavras-Chave';
-$lang['img_width']             = 'Largura';
-$lang['img_height']            = 'Altura';
-$lang['img_manager']           = 'Ver em gestor de media';
+$lang['img_title']             = 'Título:';
+$lang['img_caption']           = 'Legenda:';
+$lang['img_date']              = 'Data:';
+$lang['img_fname']             = 'Ficheiro:';
+$lang['img_fsize']             = 'Tamanho:';
+$lang['img_artist']            = 'Fotógrafo:';
+$lang['img_copyr']             = 'Copyright:';
+$lang['img_format']            = 'Formato:';
+$lang['img_camera']            = 'Câmara:';
+$lang['img_keywords']          = 'Palavras-Chave:';
+$lang['img_width']             = 'Largura:';
+$lang['img_height']            = 'Altura:';
 $lang['subscr_subscribe_success'] = 'Adicionado %s à lista de subscrição para %s';
 $lang['subscr_subscribe_error'] = 'Erro ao adicionar %s à lista de subscrição para %s';
 $lang['subscr_subscribe_noaddress'] = 'Não existe endereço algum associado com o seu nome de utilizador, não pode ser adicionado à lista de subscrição';
@@ -252,7 +280,6 @@ $lang['subscr_m_receive']      = 'Receber';
 $lang['subscr_style_every']    = 'email em qualquer alteração';
 $lang['subscr_style_digest']   = '"digest email" de alterações em cada página (cada %.2f dias)';
 $lang['subscr_style_list']     = 'lista de páginas alteradas desde o último email (cada %.2f dias)';
-$lang['authmodfailed']         = 'Configuração de autenticação errada. Por favor, informe o Wiki Admin.';
 $lang['authtempfail']          = 'Autenticação temporariamente indisponível. Se a situação persistir, por favor informe o Wiki Admin.';
 $lang['i_chooselang']          = 'Escolha a linguagem';
 $lang['i_installer']           = 'Instalador do DokuWiki';
@@ -263,6 +290,7 @@ $lang['i_problems']            = 'O instalador encontrou alguns problemas, indic
 $lang['i_modified']            = 'Por razões de segurança, este script só funciona em novas e não-modificadas instalações do Dokuwiki. Deve por isso re-extrair os ficheiros do pacote que descarregou ou então deve consultar as completas <a href="http://dokuwiki.org/install">instruções de instalação do Dokuwiki installation instructions</a>';
 $lang['i_funcna']              = 'A função PHP <code>%s</code> não está disponível. Terá o serviço de alojamento desactivado-a por alguma razão?';
 $lang['i_phpver']              = 'A versão de PHP actual <code>%s</code> é inferior à versão mínima <code>%s</code>. É preciso actualizar a instalação PHP.';
+$lang['i_mbfuncoverload']      = 'mbstring.func_overload deve ser desabilitada no php.ini para executar DokuWiki.';
 $lang['i_permfail']            = '<code>%s</code> não permite que o DokuWiki escreva nela. É preciso corrigir as permissões desta pasta!';
 $lang['i_confexists']          = '<code>%s</code> já existe';
 $lang['i_writeerr']            = 'Não foi possível criar <code>%s</code>. É preciso verificar as permissões e criar o ficheiro manualmente.';
@@ -274,8 +302,12 @@ $lang['i_policy']              = 'Politica ACL inicial';
 $lang['i_pol0']                = 'Wiki Aberto (ler, escrever e carregar para todos)';
 $lang['i_pol1']                = 'Wiki Público (ler para todos, escrever e carregar para utilizadores inscritos)';
 $lang['i_pol2']                = 'Wiki Fechado (ler, escrever e carregar somente para utilizadores inscritos)';
+$lang['i_allowreg']            = 'Permitir aos utilizadores registarem-se por si próprios';
 $lang['i_retry']               = 'Repetir';
 $lang['i_license']             = 'Por favor escolha a licença sob a qual quer colocar o seu conteúdo:';
+$lang['i_license_none']        = 'Não mostrar nenhuma informação de licença';
+$lang['i_pop_field']           = 'Por favor ajude-nos a melhorar a experiência Dokuwiki:';
+$lang['i_pop_label']           = 'Uma vez por mês, enviar dados anónimos de uso para os desenvolvedores DokuWiki';
 $lang['recent_global']         = 'Você está a observar as alterações dentro do espaço de nomes <b>%s</b>. Também é possível ver as <a href="%s">modificações recentes no wiki inteiro</a>.';
 $lang['years']                 = '%d anos atrás';
 $lang['months']                = '%d meses atrás';
@@ -285,35 +317,34 @@ $lang['hours']                 = '%d horas atrás';
 $lang['minutes']               = '%d minutos atrás';
 $lang['seconds']               = '%d segundos atrás';
 $lang['wordblock']             = 'A sua alteração não foi guardada porque contém texto bloqueado (spam).';
-
-$lang['media_uploadtab']  = 'Enviar';
-$lang['media_searchtab']  = 'Procurar';
-$lang['media_viewtab']    = 'Ver';
-$lang['media_edittab']    = 'Editar';
-$lang['media_historytab'] = 'Histórico';
-$lang['media_sort']       = 'Ordenar';
-$lang['media_sort_name']  = 'Ordenar por nome';
-$lang['media_sort_date']  = 'Ordenar por data';
-$lang['media_upload']     = 'Enviar para o grupo <strong>%s</strong>.';
-$lang['media_search']     = 'Procurar no grupo <strong>%s</strong>.';
-$lang['media_view']       = '%s';
-$lang['media_edit']       = 'Editar %s';
-$lang['media_history']    = 'Histórico do %s';
-$lang['media_meta_edited']= 'metadata editada';
-$lang['media_perm_read']  = 'Perdão, não tem permissão para ler ficheiros.';
-$lang['media_perm_upload']= 'Perdão, não tem permissão para enviar ficheiros.';
-$lang['media_update']     = 'enviar nova versão';
-$lang['media_restore']    = 'Restaurar esta versão';
-
-$lang['js']['media_diff']          = 'Ver diferenças:';
-$lang['js']['media_diff_both']     = 'Lado a Lado';
-$lang['js']['media_diff_opacity']  = 'Sobreposição';
-$lang['js']['media_diff_portions'] = 'Slider'; // Needs translation. 'Deslizador' ?
-
-$lang['js']['media_select']     = 'Selecione ficheiros…';
-$lang['js']['media_upload_btn'] = 'Enviar';
-$lang['js']['media_done_btn']   = 'Feito';
-$lang['js']['media_drop']       = 'Largue ficheiros aqui para enviar';
-$lang['js']['media_cancel']     = 'remover';
-$lang['js']['media_overwrt']    = 'Escrever por cima de ficheiros existentes';
-
+$lang['media_uploadtab']       = 'Enviar';
+$lang['media_searchtab']       = 'Procurar';
+$lang['media_file']            = 'Ficheiro';
+$lang['media_viewtab']         = 'Ver';
+$lang['media_edittab']         = 'Editar';
+$lang['media_historytab']      = 'Histórico';
+$lang['media_list_thumbs']     = 'Miniaturas';
+$lang['media_list_rows']       = 'Linhas';
+$lang['media_sort_name']       = 'Ordenar por nome';
+$lang['media_sort_date']       = 'Ordenar por data';
+$lang['media_namespaces']      = 'Escolha o namespace';
+$lang['media_files']           = 'Ficheiros em %s';
+$lang['media_upload']          = 'Enviar para o grupo <strong>%s</strong>.';
+$lang['media_search']          = 'Procurar no grupo <strong>%s</strong>.';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s em %s';
+$lang['media_edit']            = 'Editar %s';
+$lang['media_history']         = 'Histórico do %s';
+$lang['media_meta_edited']     = 'metadata editada';
+$lang['media_perm_read']       = 'Perdão, não tem permissão para ler ficheiros.';
+$lang['media_perm_upload']     = 'Perdão, não tem permissão para enviar ficheiros.';
+$lang['media_update']          = 'enviar nova versão';
+$lang['media_restore']         = 'Restaurar esta versão';
+$lang['currentns']             = 'Namespace actual';
+$lang['searchresult']          = 'Resultado da pesquisa';
+$lang['plainhtml']             = 'HTML simples';
+$lang['wikimarkup']            = 'Markup de Wiki';
+$lang['page_nonexist_rev']     = 'Página não existia no %s. Posteriormente, foi criado em <a href="%s">%s</a>.';
+$lang['unable_to_parse_date']  = 'Não é possível analisar o parâmetro "%s".';
+$lang['email_signature_text']  = 'Este email foi gerado por DokuWiki em
+@DOKUWIKIURL@';
