@@ -1,11 +1,13 @@
 <?php
+
 /**
- * serbian language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
  * @author Filip Brcic <brcha@users.sourceforge.net>
  * @author Иван Петровић (Ivan Petrovic) <petrovicivan@ubuntusrbija.org>
  * @author Miroslav Šolti <solti.miroslav@gmail.com>
+ * @author Жељко Тодоровић <zeljko_todorovic@mail.com>
+ * @author Марко М. Костић <marko.m.kostic@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -40,41 +42,55 @@ $lang['btn_backlink']          = 'Повратне везе';
 $lang['btn_subscribe']         = 'Пријави се на измене';
 $lang['btn_profile']           = 'Ажурирај профил';
 $lang['btn_reset']             = 'Поништи';
+$lang['btn_resendpwd']         = 'Поставите нови лозинку';
 $lang['btn_draft']             = 'Измени нацрт';
 $lang['btn_recover']           = 'Опорави нацрт';
 $lang['btn_draftdel']          = 'Обриши нацрт';
 $lang['btn_revert']            = 'Врати на пређашњу верзију';
 $lang['btn_register']          = 'Региструј се';
+$lang['btn_apply']             = 'Примени';
+$lang['btn_media']             = 'Управник мултимедије';
+$lang['btn_deleteuser']        = 'Уклони мој налог';
+$lang['btn_img_backto']        = 'Натраг на %s';
+$lang['btn_mediaManager']      = 'Погледај у управнику мултимедије';
 $lang['loggedinas']            = 'Пријављен као:';
 $lang['user']                  = 'Корисничко име';
 $lang['pass']                  = 'Лозинка';
 $lang['newpass']               = 'Нова лозинка';
-$lang['oldpass']               = 'Потврди нову лозинку';
+$lang['oldpass']               = 'Унеси садашњу лозинку';
 $lang['passchk']               = 'поново';
 $lang['remember']              = 'Запамти ме';
 $lang['fullname']              = 'Име и презиме';
 $lang['email']                 = 'Е-адреса';
 $lang['profile']               = 'Кориснички профил';
-$lang['badlogin']              = 'Извините, није добро корисничко име или шифра.';
+$lang['badlogin']              = 'Нажалост, није добро корисничко име или лозинка.';
+$lang['badpassconfirm']        = 'Нажалост, лозинка је била погрешна';
 $lang['minoredit']             = 'Мала измена';
 $lang['draftdate']             = 'Нацрт је аутоматски сачуван';
 $lang['nosecedit']             = 'Страна је у међувремену промењена, поглавље је застарело и поново се учитава цела страна.';
-$lang['searchcreatepage']      = "Ако нисте нашли то што сте тражили, можете да направите нову страницу названу по Вашем упиту користећи дугме ''Измени ову страницу''.";
 $lang['regmissing']            = 'Извините, морате да попуните сва поља.';
 $lang['reguexists']            = 'Извините, корисник са истим именом већ постоји.';
 $lang['regsuccess']            = 'Корисник је направљен и лозинка је послата путем е-поште.';
 $lang['regsuccess2']           = 'Корисник је направљен.';
-$lang['regmailfail']           = 'Изгледа да је дошло до грешке приликом слања лозинке е-поштом. Молим Вас, контактирајте администратора!';
+$lang['regfail']               = 'Нисам могао да направим корисника.';
+$lang['regmailfail']           = 'Изгледа да је дошло до грешке приликом слања лозинке е-поштом. Контактирајте администратора!';
 $lang['regbadmail']            = 'Дата е-адреса није у реду - ако мислите да је ово грешка, контактирајте администратора';
-$lang['regbadpass']            = 'Две задате лозинке нису исте. Молим Вас, пробајте поново.';
+$lang['regbadpass']            = 'Две унете лозинке нису исте. Пробајте поново.';
 $lang['regpwmail']             = 'Ваша DokuWiki лозинка';
 $lang['reghere']               = 'Још увек немате налог? Само направите један';
 $lang['profna']                = 'Овај вики не дозвољава измену профила';
 $lang['profnochange']          = 'Нема промена.';
 $lang['profnoempty']           = 'Није дозвољено оставити празно поље имена или е-адресе.';
 $lang['profchanged']           = 'Кориснички профил је ажуриран.';
+$lang['profnodelete']          = 'Овај вики не подржава брисање корисника';
+$lang['profdeleteuser']        = 'Избриши налог';
+$lang['profdeleted']           = 'Ваш кориснички налог је избрисан са овог викија';
+$lang['profconfdelete']        = 'Желим да уклоним свој налог са овог викија. <br/> Ова радња се не може опозвати.';
+$lang['profconfdeletemissing'] = 'Није штиклирано поље за потврду';
+$lang['proffail']              = 'Кориснички профил није ажуриран.';
 $lang['pwdforget']             = 'Заборавили сте лозинку? Направите нову';
 $lang['resendna']              = 'Овај вики не дозвољава слање лозинки.';
+$lang['resendpwd']             = 'Поставите нову лозинку за';
 $lang['resendpwdmissing']      = 'Жао ми је, сва поља морају бити попуњена.';
 $lang['resendpwdnouser']       = 'Жао ми је, овај корисник не постоји у нашој бази.';
 $lang['resendpwdbadauth']      = 'Жао ми је, потврдни код није исправан. Проверите да ли сте користили комплетан потврдни линк.';
@@ -87,9 +103,10 @@ $lang['searchmedia_in']        = 'Претражи у %s';
 $lang['txt_upload']            = 'Изаберите датотеку за слање:';
 $lang['txt_filename']          = 'Унесите вики-име (опционо):';
 $lang['txt_overwrt']           = 'Препишите тренутни фајл';
+$lang['maxuploadsize']         = 'Отпреми највише %s по датотеци.';
 $lang['lockedby']              = 'Тренутно закључано од стране:';
 $lang['lockexpire']            = 'Закључавање истиче:';
-$lang['js']['willexpire']            = 'Ваше закључавање за измену ове странице ће да истекне за један минут.\nДа би сте избегли конфликте, искористите дугме за преглед како би сте ресетовали тајмер закључавања.';
+$lang['js']['willexpire']      = 'Ваше закључавање за измену ове странице ће да истекне за један минут.\nДа би сте избегли конфликте, искористите дугме за преглед како би сте ресетовали тајмер закључавања.';
 $lang['js']['notsavedyet']     = 'Несачуване измене ће бити изгубљене.
 Да ли стварно желите да наставите?';
 $lang['js']['searchmedia']     = 'Потражи фајлове';
@@ -121,6 +138,15 @@ $lang['js']['nosmblinks']      = 'Повезивање са Windows дељени
 $lang['js']['linkwiz']         = 'Чаробњак за стварање везе';
 $lang['js']['linkto']          = 'Повежи ка:';
 $lang['js']['del_confirm']     = 'Обриши овај унос?';
+$lang['js']['restore_confirm'] = 'Заиста желите да вратите ово издање?';
+$lang['js']['media_diff']      = 'Погледај разлике:';
+$lang['js']['media_diff_both'] = 'Једно до другог';
+$lang['js']['media_select']    = 'Изабери датотеке…';
+$lang['js']['media_upload_btn'] = 'Отпреми';
+$lang['js']['media_done_btn']  = 'Готово';
+$lang['js']['media_drop']      = 'Превуците датотеке овде да бисте их отпремили';
+$lang['js']['media_cancel']    = 'уклони';
+$lang['js']['media_overwrt']   = 'Препиши постојеће датотеке';
 $lang['rssfailed']             = 'Дошло је до грешке приликом преузимања овог довода: ';
 $lang['nothingfound']          = 'Ништа није нађено.';
 $lang['mediaselect']           = 'Избор медијске датотеке';
@@ -154,6 +180,14 @@ $lang['yours']                 = 'Ваша верзија';
 $lang['diff']                  = 'прикажи разлике до тренутне верзије';
 $lang['diff2']                 = 'Прикажи разлике између одабраних ревизија';
 $lang['difflink']              = 'Постави везу ка овом компаративном приказу';
+$lang['diff_type']             = 'Погледај разлике:';
+$lang['diff_inline']           = 'У линији';
+$lang['diff_side']             = 'Једно до другог';
+$lang['diffprevrev']           = 'Претходна ревизија';
+$lang['diffnextrev']           = 'Следећа ревизија';
+$lang['difflastrev']           = 'Последња ревизија';
+$lang['diffbothprevrev']       = 'Обе стране последње ревизије';
+$lang['diffbothnextrev']       = 'Обе стране следеће ревизије';
 $lang['line']                  = 'Линија';
 $lang['breadcrumb']            = 'Траг:';
 $lang['youarehere']            = 'Сада сте овде:';
@@ -166,11 +200,21 @@ $lang['external_edit']         = 'спољна измена';
 $lang['summary']               = 'Сажетак измене';
 $lang['noflash']               = 'За приказивање ове врсте материјала потребан вам је <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
 $lang['download']              = 'Преузми снипет';
+$lang['tools']                 = 'Алатке';
+$lang['user_tools']            = 'Корисничке алатке';
+$lang['site_tools']            = 'Алатке сајта';
+$lang['page_tools']            = 'Алатке странице';
+$lang['skip_to_content']       = 'скочи на садржај';
+$lang['sidebar']               = 'Страничник';
 $lang['mail_newpage']          = 'страница додата:';
 $lang['mail_changed']          = 'страница измењена:';
 $lang['mail_subscribe_list']   = 'Странице промењене у именском простору:';
 $lang['mail_new_user']         = 'нови корисник:';
 $lang['mail_upload']           = 'послата датотека:';
+$lang['changes_type']          = 'Прикажи измене';
+$lang['pages_changes']         = 'Странице';
+$lang['media_changes']         = 'датотека';
+$lang['both_changes']          = 'И страница и датотека';
 $lang['qb_bold']               = 'Мастан текст';
 $lang['qb_italic']             = 'Курзивни текст';
 $lang['qb_underl']             = 'Подвучени текст';
@@ -199,7 +243,6 @@ $lang['upperns']               = 'Скочи на виши именски про
 $lang['metaedit']              = 'Измени мета-податке';
 $lang['metasaveerr']           = 'Записивање мета-података није било успешно';
 $lang['metasaveok']            = 'Мета-подаци су сачувани';
-$lang['btn_img_backto']            = 'Натраг на %s';
 $lang['img_title']             = 'Наслов:';
 $lang['img_caption']           = 'Назив:';
 $lang['img_date']              = 'Датум:';
@@ -210,6 +253,8 @@ $lang['img_copyr']             = 'Права копирања:';
 $lang['img_format']            = 'Формат:';
 $lang['img_camera']            = 'Камера:';
 $lang['img_keywords']          = 'Кључне речи:';
+$lang['img_width']             = 'Ширина:';
+$lang['img_height']            = 'Висина:';
 $lang['subscr_subscribe_success'] = '%s је додат на списак претплатника %s';
 $lang['subscr_subscribe_error'] = 'Грешка приликом додавања %s на списак претплатника %s';
 $lang['subscr_subscribe_noaddress'] = 'Не постоји адреса повезана са вашим подацима, стога вас не можемо додати на списак претплатника.';
@@ -236,6 +281,7 @@ $lang['i_problems']            = 'Инсталација је наишла на
 $lang['i_modified']            = 'Из сигурносних разлога ова скрипта ради само са новом Dokuwiki инсталацијом. Требало би или да опет распакујете архиву преузету са сајта или да погледате <a href="http://dokuwiki.org/install">Dokuwiki инструкције за инсталацију</a>';
 $lang['i_funcna']              = 'ПХП функција <code>%s</code> није доступна. Можда је Ваш хостинг провајдер забранио из неког разлога?';
 $lang['i_phpver']              = '<code>%s</code> Верзија Вашег ПХПа је нижа од неопходне <code>%s</code>. Требало би да надоградите ПХП инсталацију.';
+$lang['i_mbfuncoverload']      = 'mbstring.func_overload мора бити искључен у датотеци php.ini да бисте користили Докувики.';
 $lang['i_permfail']            = 'DokuWiki нема дозволу писања у <code>%s</code>. Потребно је да поправите дозволе за ову фасциклу!';
 $lang['i_confexists']          = '<code>%s</code> већ постоји';
 $lang['i_writeerr']            = 'Не могу да направим <code>%s</code>. Проверите дозволе а затим ручно направите ову датотеку.';
@@ -247,8 +293,12 @@ $lang['i_policy']              = 'Иницијалне корисничке до
 $lang['i_pol0']                = 'Отворени вики (читање, писање, слање датотека за све)';
 $lang['i_pol1']                = 'Јавни вики (читање за све, писање и слање датотека само за регистроване кориснике)';
 $lang['i_pol2']                = 'Затворени вики (читање, писање и слање датотека само за регистроване кориснике)';
+$lang['i_allowreg']            = 'Дозволи корисницима да се региструју';
 $lang['i_retry']               = 'Понови';
 $lang['i_license']             = 'Молимо вас, одаберите лиценцу под коју желите да ставите свој садржај:';
+$lang['i_license_none']        = 'Не приказуј податке о лиценци';
+$lang['i_pop_field']           = 'Помозите нам да побољшамо Докувики:';
+$lang['i_pop_label']           = 'Једном месечно шаљи анонимне податке о коришћењу програмерима Докувикија';
 $lang['recent_global']         = 'Тренутно пратите промене у именском простору <b>%s</b>. Такође, можете пратити <a href="%s">прмене на целом викију</a>.';
 $lang['years']                 = 'Пре %d година';
 $lang['months']                = 'Пре %d месеци';
@@ -258,3 +308,35 @@ $lang['hours']                 = 'Пре %d сати';
 $lang['minutes']               = 'Пре %d минута';
 $lang['seconds']               = 'Пре %d секунди';
 $lang['wordblock']             = 'Ваше измене нису сачуване јер садрже забрањен текст (спам)';
+$lang['media_uploadtab']       = 'Отпреми';
+$lang['media_searchtab']       = 'Претрага';
+$lang['media_file']            = 'Датотека';
+$lang['media_viewtab']         = 'Погледај';
+$lang['media_edittab']         = 'Уреди';
+$lang['media_historytab']      = 'Историјат';
+$lang['media_list_thumbs']     = 'Сличице';
+$lang['media_list_rows']       = 'Редови';
+$lang['media_sort_name']       = 'Име';
+$lang['media_sort_date']       = 'Датум';
+$lang['media_namespaces']      = 'Изабери именски простор';
+$lang['media_files']           = 'Датотеке у %s';
+$lang['media_upload']          = 'Отпреми на %s';
+$lang['media_search']          = 'Претражи у %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s у %s';
+$lang['media_edit']            = 'Уреди %s';
+$lang['media_history']         = 'Историјат од %s';
+$lang['media_meta_edited']     = 'промењени мета-подаци';
+$lang['media_perm_read']       = 'Нажалост, немате довољно овлашћења за читање датотека.';
+$lang['media_perm_upload']     = 'Нажалост, немате довољно овлашћења за отпремање датотека.';
+$lang['media_update']          = 'Отпреми ново издање';
+$lang['media_restore']         = 'Поврати ово издање';
+$lang['media_acl_warning']     = 'Овај списак је можда непотпун због забрана на списку контроле приступа и скривених страница.';
+$lang['currentns']             = 'Тренутни именски простор';
+$lang['searchresult']          = 'Резултати претраге';
+$lang['plainhtml']             = 'Обичан HTML';
+$lang['wikimarkup']            = 'Вики маркап';
+$lang['page_nonexist_rev']     = 'Страница не постоји у %s. Касније је направљена у <a href="%s">%s</a>.';
+$lang['unable_to_parse_date']  = 'Не могу да обрадим код параметра "%s".';
+$lang['email_signature_text']  = 'Ову поруку је генерисао DokuWiki sa
+@DOKUWIKIURL@';
