@@ -17,10 +17,15 @@ class Doku_Handler {
 
     var $rewriteBlocks = true;
 
-    function Doku_Handler() {
+    function __construct() {
         $this->CallWriter = new Doku_Handler_CallWriter($this);
     }
 
+    /**
+     * @param string $handler
+     * @param mixed $args
+     * @param integer|string $pos
+     */
     function _addCall($handler, $args, $pos) {
         $call = array($handler,$args, $pos);
         $this->CallWriter->writeCall($call);
@@ -52,10 +57,16 @@ class Doku_Handler {
         array_push($this->calls,array('document_end',array(),$last_call[2]));
     }
 
+    /**
+     * fetch the current call and advance the pointer to the next one
+     *
+     * @return bool|mixed
+     */
     function fetch() {
-        $call = each($this->calls);
-        if ( $call ) {
-            return $call['value'];
+        $call = current($this->calls);
+        if($call !== false) {
+            next($this->calls); //advance the pointer
+            return $call;
         }
         return false;
     }
@@ -68,9 +79,17 @@ class Doku_Handler {
      * An additional parameter with the plugin name is passed
      *
      * @author Andreas Gohr <andi@splitbrain.org>
+     *
+     * @param string|integer $match
+     * @param string|integer $state
+     * @param integer $pos
+     * @param $pluginname
+     *
+     * @return bool
      */
     function plugin($match, $state, $pos, $pluginname){
         $data = array($match);
+        /** @var DokuWiki_Syntax_Plugin $plugin */
         $plugin = plugin_load('syntax',$pluginname);
         if($plugin != null){
             $data = $plugin->handle($match, $state, $pos, $this);
@@ -132,6 +151,12 @@ class Doku_Handler {
         return true;
     }
 
+    /**
+     * @param string|integer $match
+     * @param string|integer $state
+     * @param integer $pos
+     * @param string $name
+     */
     function _nestingTag($match, $state, $pos, $name) {
         switch ( $state ) {
             case DOKU_LEXER_ENTER:
@@ -288,7 +313,7 @@ class Doku_Handler {
         switch ( $state ) {
             case DOKU_LEXER_ENTER:
                 $ReWriter = new Doku_Handler_Preformatted($this->CallWriter);
-                $this->CallWriter = & $ReWriter;
+                $this->CallWriter = $ReWriter;
                 $this->_addCall('preformatted_start',array(), $pos);
             break;
             case DOKU_LEXER_EXIT:
@@ -338,6 +363,77 @@ class Doku_Handler {
         return true;
     }
 
+    /**
+     * Internal function for parsing highlight options.
+     * $options is parsed for key value pairs separated by commas.
+     * A value might also be missing in which case the value will simple
+     * be set to true. Commas in strings are ignored, e.g. option="4,56"
+     * will work as expected and will only create one entry.
+     *
+     * @param string $options space separated list of key-value pairs,
+     *                        e.g. option1=123, option2="456"
+     * @return array|null     Array of key-value pairs $array['key'] = 'value';
+     *                        or null if no entries found
+     */
+    protected function parse_highlight_options ($options) {
+        $result = array();
+        preg_match_all('/(\w+(?:="[^"]*"))|(\w+(?:=[^\s]*))|(\w+[^=\s\]])(?:\s*)/', $options, $matches, PREG_SET_ORDER);
+        foreach ($matches as $match) {
+            $equal_sign = strpos($match [0], '=');
+            if ($equal_sign === false) {
+                $key = trim($match[0]);
+                $result [$key] = 1;
+            } else {
+                $key = substr($match[0], 0, $equal_sign);
+                $value = substr($match[0], $equal_sign+1);
+                $value = trim($value, '"');
+                if (strlen($value) > 0) {
+                    $result [$key] = $value;
+                } else {
+                    $result [$key] = 1;
+                }
+            }
+        }
+
+        // Check for supported options
+        $result = array_intersect_key(
+            $result,
+            array_flip(array(
+                'enable_line_numbers',
+                'start_line_numbers_at',
+                'highlight_lines_extra',
+                'enable_keyword_links')
+            )
+        );
+
+        // Sanitize values
+        if(isset($result['enable_line_numbers'])) {
+            if($result['enable_line_numbers'] === 'false') {
+                $result['enable_line_numbers'] = false;
+            }
+            $result['enable_line_numbers'] = (bool) $result['enable_line_numbers'];
+        }
+        if(isset($result['highlight_lines_extra'])) {
+            $result['highlight_lines_extra'] = array_map('intval', explode(',', $result['highlight_lines_extra']));
+            $result['highlight_lines_extra'] = array_filter($result['highlight_lines_extra']);
+            $result['highlight_lines_extra'] = array_unique($result['highlight_lines_extra']);
+        }
+        if(isset($result['start_line_numbers_at'])) {
+            $result['start_line_numbers_at'] = (int) $result['start_line_numbers_at'];
+        }
+        if(isset($result['enable_keyword_links'])) {
+            if($result['enable_keyword_links'] === 'false') {
+                $result['enable_keyword_links'] = false;
+            }
+            $result['enable_keyword_links'] = (bool) $result['enable_keyword_links'];
+        }
+        if (count($result) == 0) {
+            return null;
+        }
+
+        return $result;
+    }
+
     function file($match, $state, $pos) {
         return $this->code($match, $state, $pos, 'file');
     }
@@ -345,15 +441,20 @@ class Doku_Handler {
     function code($match, $state, $pos, $type='code') {
         if ( $state == DOKU_LEXER_UNMATCHED ) {
             $matches = explode('>',$match,2);
-
+            // Cut out variable options enclosed in []
+            preg_match('/\[.*\]/', $matches[0], $options);
+            if (!empty($options[0])) {
+                $matches[0] = str_replace($options[0], '', $matches[0]);
+            }
             $param = preg_split('/\s+/', $matches[0], 2, PREG_SPLIT_NO_EMPTY);
             while(count($param) < 2) array_push($param, null);
-
             // We shortcut html here.
             if ($param[0] == 'html') $param[0] = 'html4strict';
             if ($param[0] == '-') $param[0] = null;
             array_unshift($param, $matches[1]);
-
+            if (!empty($options[0])) {
+                $param [] = $this->parse_highlight_options ($options[0]);
+            }
             $this->_addCall($type, $param, $pos);
         }
         return true;
@@ -439,7 +540,7 @@ class Doku_Handler {
 
         //decide which kind of link it is
 
-        if ( preg_match('/^[a-zA-Z0-9\.]+>{1}.*$/u',$link[0]) ) {
+        if ( link_isinterwiki($link[0]) ) {
             // Interwiki
             $interwiki = explode('>',$link[0],2);
             $this->_addCall(
@@ -525,6 +626,7 @@ class Doku_Handler {
         $p['author']  = (preg_match('/\b(by|author)/',$params));
         $p['date']    = (preg_match('/\b(date)/',$params));
         $p['details'] = (preg_match('/\b(desc|detail)/',$params));
+        $p['nosort']  = (preg_match('/\b(nosort)\b/',$params));
 
         if (preg_match('/\b(\d+)([dhm])\b/',$params,$match)) {
             $period = array('d' => 86400, 'h' => 3600, 'm' => 60);
@@ -685,8 +787,8 @@ function Doku_Handler_Parse_Media($match) {
         $cache = 'cache';
     }
 
-    // Check whether this is a local or remote image
-    if ( media_isexternal($src) ) {
+    // Check whether this is a local or remote image or interwiki
+    if (media_isexternal($src) || link_isinterwiki($src)){
         $call = 'externalmedia';
     } else {
         $call = 'internalmedia';
@@ -707,12 +809,21 @@ function Doku_Handler_Parse_Media($match) {
 }
 
 //------------------------------------------------------------------------
-class Doku_Handler_CallWriter {
+interface Doku_Handler_CallWriter_Interface {
+    public function writeCall($call);
+    public function writeCalls($calls);
+    public function finalise();
+}
+
+class Doku_Handler_CallWriter implements Doku_Handler_CallWriter_Interface {
 
     var $Handler;
 
-    function Doku_Handler_CallWriter(& $Handler) {
-        $this->Handler = & $Handler;
+    /**
+     * @param Doku_Handler $Handler
+     */
+    function __construct(Doku_Handler $Handler) {
+        $this->Handler = $Handler;
     }
 
     function writeCall($call) {
@@ -737,7 +848,7 @@ class Doku_Handler_CallWriter {
  *
  * @author    Chris Smith <chris@jalakai.co.uk>
  */
-class Doku_Handler_Nest {
+class Doku_Handler_Nest implements Doku_Handler_CallWriter_Interface {
 
     var $CallWriter;
     var $calls = array();
@@ -747,12 +858,12 @@ class Doku_Handler_Nest {
     /**
      * constructor
      *
-     * @param  object     $CallWriter     the renderers current call writer
+     * @param  Doku_Handler_CallWriter $CallWriter     the renderers current call writer
      * @param  string     $close          closing instruction name, this is required to properly terminate the
      *                                    syntax mode if the document ends without a closing pattern
      */
-    function Doku_Handler_Nest(& $CallWriter, $close="nest_close") {
-        $this->CallWriter = & $CallWriter;
+    function __construct(Doku_Handler_CallWriter_Interface $CallWriter, $close="nest_close") {
+        $this->CallWriter = $CallWriter;
 
         $this->closingInstruction = $close;
     }
@@ -797,7 +908,7 @@ class Doku_Handler_Nest {
     }
 }
 
-class Doku_Handler_List {
+class Doku_Handler_List implements Doku_Handler_CallWriter_Interface {
 
     var $CallWriter;
 
@@ -805,8 +916,10 @@ class Doku_Handler_List {
     var $listCalls = array();
     var $listStack = array();
 
-    function Doku_Handler_List(& $CallWriter) {
-        $this->CallWriter = & $CallWriter;
+    const NODE = 1;
+
+    function __construct(Doku_Handler_CallWriter_Interface $CallWriter) {
+        $this->CallWriter = $CallWriter;
     }
 
     function writeCall($call) {
@@ -856,7 +969,8 @@ class Doku_Handler_List {
         $depth = $this->interpretSyntax($call[1][0], $listType);
 
         $this->initialDepth = $depth;
-        $this->listStack[] = array($listType, $depth);
+        //                   array(list type, current depth, index of current listitem_open)
+        $this->listStack[] = array($listType, $depth, 1);
 
         $this->listCalls[] = array('list'.$listType.'_open',array(),$call[2]);
         $this->listCalls[] = array('listitem_open',array(1),$call[2]);
@@ -881,6 +995,7 @@ class Doku_Handler_List {
     function listOpen($call) {
         $depth = $this->interpretSyntax($call[1][0], $listType);
         $end = end($this->listStack);
+        $key = key($this->listStack);
 
         // Not allowed to be shallower than initialDepth
         if ( $depth < $this->initialDepth ) {
@@ -897,6 +1012,9 @@ class Doku_Handler_List {
                 $this->listCalls[] = array('listitem_open',array($depth-1),$call[2]);
                 $this->listCalls[] = array('listcontent_open',array(),$call[2]);
 
+                // new list item, update list stack's index into current listitem_open
+                $this->listStack[$key][2] = count($this->listCalls) - 2;
+
             // Switched list type...
             } else {
 
@@ -908,7 +1026,7 @@ class Doku_Handler_List {
                 $this->listCalls[] = array('listcontent_open',array(),$call[2]);
 
                 array_pop($this->listStack);
-                $this->listStack[] = array($listType, $depth);
+                $this->listStack[] = array($listType, $depth, count($this->listCalls) - 2);
             }
 
         //------------------------------------------------------------------------
@@ -920,7 +1038,10 @@ class Doku_Handler_List {
             $this->listCalls[] = array('listitem_open', array($depth-1), $call[2]);
             $this->listCalls[] = array('listcontent_open',array(),$call[2]);
 
-            $this->listStack[] = array($listType, $depth);
+            // set the node/leaf state of this item's parent listitem_open to NODE
+            $this->listCalls[$this->listStack[$key][2]][1][1] = self::NODE;
+
+            $this->listStack[] = array($listType, $depth, count($this->listCalls) - 2);
 
         //------------------------------------------------------------------------
         // Getting shallower ( $depth < $end[1] )
@@ -934,6 +1055,7 @@ class Doku_Handler_List {
 
             while (1) {
                 $end = end($this->listStack);
+                $key = key($this->listStack);
 
                 if ( $end[1] <= $depth ) {
 
@@ -946,6 +1068,9 @@ class Doku_Handler_List {
                         $this->listCalls[] = array('listitem_open',array($depth-1),$call[2]);
                         $this->listCalls[] = array('listcontent_open',array(),$call[2]);
 
+                        // new list item, update list stack's index into current listitem_open
+                        $this->listStack[$key][2] = count($this->listCalls) - 2;
+
                     } else {
                         // Switching list type...
                         $this->listCalls[] = array('list'.$end[0].'_close', array(), $call[2]);
@@ -954,7 +1079,7 @@ class Doku_Handler_List {
                         $this->listCalls[] = array('listcontent_open',array(),$call[2]);
 
                         array_pop($this->listStack);
-                        $this->listStack[] = array($listType, $depth);
+                        $this->listStack[] = array($listType, $depth, count($this->listCalls) - 2);
                     }
 
                     break;
@@ -993,7 +1118,7 @@ class Doku_Handler_List {
 }
 
 //------------------------------------------------------------------------
-class Doku_Handler_Preformatted {
+class Doku_Handler_Preformatted implements Doku_Handler_CallWriter_Interface {
 
     var $CallWriter;
 
@@ -1003,8 +1128,8 @@ class Doku_Handler_Preformatted {
 
 
 
-    function Doku_Handler_Preformatted(& $CallWriter) {
-        $this->CallWriter = & $CallWriter;
+    function __construct(Doku_Handler_CallWriter_Interface $CallWriter) {
+        $this->CallWriter = $CallWriter;
     }
 
     function writeCall($call) {
@@ -1053,7 +1178,7 @@ class Doku_Handler_Preformatted {
 }
 
 //------------------------------------------------------------------------
-class Doku_Handler_Quote {
+class Doku_Handler_Quote implements Doku_Handler_CallWriter_Interface {
 
     var $CallWriter;
 
@@ -1061,8 +1186,8 @@ class Doku_Handler_Quote {
 
     var $quoteCalls = array();
 
-    function Doku_Handler_Quote(& $CallWriter) {
-        $this->CallWriter = & $CallWriter;
+    function __construct(Doku_Handler_CallWriter_Interface $CallWriter) {
+        $this->CallWriter = $CallWriter;
     }
 
     function writeCall($call) {
@@ -1145,7 +1270,7 @@ class Doku_Handler_Quote {
 }
 
 //------------------------------------------------------------------------
-class Doku_Handler_Table {
+class Doku_Handler_Table implements Doku_Handler_CallWriter_Interface {
 
     var $CallWriter;
 
@@ -1160,8 +1285,8 @@ class Doku_Handler_Table {
     var $currentRow = array('tableheader' => 0, 'tablecell' => 0);
     var $countTableHeadRows = 0;
 
-    function Doku_Handler_Table(& $CallWriter) {
-        $this->CallWriter = & $CallWriter;
+    function __construct(Doku_Handler_CallWriter_Interface $CallWriter) {
+        $this->CallWriter = $CallWriter;
     }
 
     function writeCall($call) {
@@ -1439,12 +1564,16 @@ class Doku_Handler_Table {
                 case 'tablerow_close':
 
                     // Fix broken tables by adding missing cells
+                    $moreCalls = array();
                     while (++$lastCell < $this->maxCols) {
-                        array_splice($this->tableCalls, $key, 0, array(
-                               array('tablecell_open', array(1, null, 1), $call[2]),
-                               array('cdata', array(''), $call[2]),
-                               array('tablecell_close', array(), $call[2])));
-                        $key += 3;
+                        $moreCalls[] = array('tablecell_open', array(1, null, 1), $call[2]);
+                        $moreCalls[] = array('cdata', array(''), $call[2]);
+                        $moreCalls[] = array('tablecell_close', array(), $call[2]);
+                    }
+                    $moreCallsLength = count($moreCalls);
+                    if($moreCallsLength) {
+                        array_splice($this->tableCalls, $key, 0, $moreCalls);
+                        $key += $moreCallsLength;
                     }
 
                     if($this->countTableHeadRows == $lastRow) {
@@ -1526,7 +1655,7 @@ class Doku_Handler_Block {
      *
      * @author Andreas Gohr <andi@splitbrain.org>
      */
-    function Doku_Handler_Block(){
+    function __construct(){
         global $DOKU_PLUGINS;
         //check if syntax plugins were loaded
         if(empty($DOKU_PLUGINS['syntax'])) return;
@@ -1555,6 +1684,8 @@ class Doku_Handler_Block {
      * This function makes sure there are no empty paragraphs on the stack
      *
      * @author Andreas Gohr <andi@splitbrain.org>
+     *
+     * @param string|integer $pos
      */
     function closeParagraph($pos){
         if (!$this->inParagraph) return;
@@ -1606,6 +1737,10 @@ class Doku_Handler_Block {
      *
      * @author Harry Fuecks <hfuecks@gmail.com>
      * @author Andreas Gohr <andi@splitbrain.org>
+     *
+     * @param array $calls
+     *
+     * @return array
      */
     function process($calls) {
         // open first paragraph
