@@ -31,8 +31,6 @@ $lang['_media']                = 'اعدادات الوسائط';
 $lang['_notifications']        = 'اعدادات التنبيه';
 $lang['_advanced']             = 'اعدادات متقدمة';
 $lang['_network']              = 'اعدادات الشبكة';
-$lang['_plugin_sufix']         = 'اعدادات الملحقات';
-$lang['_template_sufix']       = 'اعدادات القوالب';
 $lang['_msg_setting_undefined'] = 'لا بيانات إعدادات.';
 $lang['_msg_setting_no_class'] = 'لا صنف إعدادات.';
 $lang['_msg_setting_no_default'] = 'لا قيمة افتراضية.';
@@ -57,7 +55,7 @@ $lang['breadcrumbs']           = 'عدد العناقيد للزيارات';
 $lang['youarehere']            = 'عناقيد هرمية';
 $lang['fullpath']              = 'اظهر المحتوى الكامل للصفحات في ';
 $lang['typography']            = 'اعمل استبدالات طبوغرافية';
-$lang['dformat']               = 'تنسيق التاريخ (انظر وظيفة PHP,s <a href="http://www.php.net/strftime">strftime</a>)';
+$lang['dformat']               = 'تنسيق التاريخ (انظر وظيفة PHP,s <a href="http://php.net/strftime">strftime</a>)';
 $lang['signature']             = 'التوقيع';
 $lang['showuseras']            = 'الذي يعرض لاظهار المستخدم الذي قام بآخر تحرير لصفحة';
 $lang['toptoclevel']           = 'المستوى الأعلى لمحتويات الجدول';
@@ -104,7 +102,6 @@ $lang['target____media']       = 'النافذة الهدف لروابط الو
 $lang['target____windows']     = 'النافذة الهدف لروابط النوافذ';
 $lang['mediarevisions']        = 'تفعيل إصدارات الوسائط؟';
 $lang['refcheck']              = 'التحقق من مرجع الوسائط';
-$lang['refshow']               = 'عدد مراجع الوسائط لتعرض';
 $lang['gdlib']                 = 'اصدار مكتبة GD';
 $lang['im_convert']            = 'المسار إلى اداة تحويل ImageMagick';
 $lang['jpg_quality']           = 'دقة ضغط JPG (0-100)';
@@ -132,7 +129,7 @@ $lang['autoplural']            = 'تحقق من صيغ الجمع في الرو
 $lang['compression']           = 'طريقة الغضط لملفات attic';
 $lang['gzip_output']           = 'استخدم ترميز-محتوى gzip ل xhtml';
 $lang['compress']              = 'رُص مخرجات CSS و جافا سكربت';
-$lang['cssdatauri']            = 'الحجم بالبايتات للصور المذكورة في CSS التي ستُضمن في صفحة-التنسيق لخفض طلبات HTTP. لن تعمل هذه التقنية في IE 7 أو أقل! <code>400</code> إلى <code>600</code> بايت تعد قيمة جيدة. اضبط إلى <code>0</code> لتعطلها.';
+$lang['cssdatauri']            = 'الحجم بالبايتات للصور المذكورة في CSS التي ستُضمن في صفحة-التنسيق لخفض طلبات HTTP. <code>400</code> إلى <code>600</code> بايت تعد قيمة جيدة. اضبط إلى <code>0</code> لتعطلها.';
 $lang['send404']               = 'ارسل "HTTP 404/Page Not Found" للصفحات غير الموجودة';
 $lang['broken_iua']            = 'هل الوظيفة ignore_user_abort معطلة على جهازك؟ قد يؤدي ذلك لتعطيل فهرسة البحث. IIS+PHP/CGI تعرف بأنها لاتعمل. أنظر <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">العلة 852</a> لمزيد من المعلومات.';
 $lang['xsendfile']             = 'استخدم ترويسة X-Sendfile لتمكين خادم الوب من تقديم ملفات ثابتة؟ يجب أن يكون خادم الوب داعما له.';
