@@ -10,7 +10,9 @@
 if(!defined('CM_KEYMARKER')) define('CM_KEYMARKER','____');
 
 if (!class_exists('configuration')) {
-
+    /**
+     * Class configuration
+     */
     class configuration {
 
         var $_name = 'conf';           // name of the config variable found in the files (overridden by $config['varname'])
@@ -35,10 +37,10 @@ if (!class_exists('configuration')) {
          *
          * @param string $datafile path to config metadata file
          */
-        public function configuration($datafile) {
+        public function __construct($datafile) {
             global $conf, $config_cascade;
 
-            if (!@file_exists($datafile)) {
+            if (!file_exists($datafile)) {
                 msg('No configuration metadata found at - '.htmlspecialchars($datafile),-1);
                 return;
             }
@@ -99,7 +101,12 @@ if (!class_exists('configuration')) {
                     }
 
                     $this->setting[$key] = new $class($key,$param);
-                    $this->setting[$key]->initialize($default[$key],$local[$key],$protected[$key]);
+
+                    $d = array_key_exists($key, $default) ? $default[$key] : null;
+                    $l = array_key_exists($key, $local) ? $local[$key] : null;
+                    $p = array_key_exists($key, $protected) ? $protected[$key] : null;
+
+                    $this->setting[$key]->initialize($d,$l,$p);
                 }
 
                 $this->_loaded = true;
@@ -123,8 +130,8 @@ if (!class_exists('configuration')) {
             $file = end($this->_local_files);
 
             // backup current file (remove any existing backup)
-            if (@file_exists($file) && $backup) {
-                if (@file_exists($file.'.bak')) @unlink($file.'.bak');
+            if (file_exists($file) && $backup) {
+                if (file_exists($file.'.bak')) @unlink($file.'.bak');
                 if (!io_rename($file, $file.'.bak')) return false;
             }
 
@@ -151,6 +158,8 @@ if (!class_exists('configuration')) {
 
         /**
          * Update last modified time stamp of the config file
+         *
+         * @return bool
          */
         public function touch_settings(){
             if ($this->locked) return false;
@@ -187,7 +196,7 @@ if (!class_exists('configuration')) {
 
             if ($this->_format == 'php') {
 
-                if(@file_exists($file)){
+                if(file_exists($file)){
                     $contents = @php_strip_whitespace($file);
                 }else{
                     $contents = '';
@@ -211,15 +220,12 @@ if (!class_exists('configuration')) {
                         $len = count($arr);
                         for($j=0; $j<$len; $j++){
                             $arr[$j] = trim($arr[$j]);
-                            $arr[$j] = preg_replace('/^(\'|")(.*)(?<!\\\\)\1$/s','$2',$arr[$j]);
-                            $arr[$j] = strtr($arr[$j], array('\\\\'=>'\\','\\\''=>'\'','\\"'=>'"'));
+                            $arr[$j] = $this->_readValue($arr[$j]);
                         }
 
                         $value = $arr;
                     }else{
-                        // remove quotes from quoted strings & unescape escaped data
-                        $value = preg_replace('/^(\'|")(.*)(?<!\\\\)\1$/s','$2',$value);
-                        $value = strtr($value, array('\\\\'=>'\\','\\\''=>'\'','\\"'=>'"'));
+                        $value = $this->_readValue($value);
                     }
 
                     $config[$key] = $value;
@@ -229,6 +235,32 @@ if (!class_exists('configuration')) {
             return $config;
         }
 
+        /**
+         * Convert php string into value
+         *
+         * @param string $value
+         * @return bool|string
+         */
+        protected function _readValue($value) {
+            $removequotes_pattern = '/^(\'|")(.*)(?<!\\\\)\1$/s';
+            $unescape_pairs = array(
+                '\\\\' => '\\',
+                '\\\'' => '\'',
+                '\\"' => '"'
+            );
+
+            if($value == 'true') {
+                $value = true;
+            } elseif($value == 'false') {
+                $value = false;
+            } else {
+                // remove quotes from quoted strings & unescape escaped data
+                $value = preg_replace($removequotes_pattern,'$2',$value);
+                $value = strtr($value, $unescape_pairs);
+            }
+            return $value;
+        }
+
         /**
          * Returns header of rewritten settings file
          *
@@ -277,7 +309,7 @@ if (!class_exists('configuration')) {
             $local = $this->_local_files[0];
 
             if (!is_writable(dirname($local))) return true;
-            if (@file_exists($local) && !is_writable($local)) return true;
+            if (file_exists($local) && !is_writable($local)) return true;
 
             return false;
         }
@@ -285,6 +317,10 @@ if (!class_exists('configuration')) {
         /**
          * not used ... conf's contents are an array!
          * reduce any multidimensional settings to one dimension using CM_KEYMARKER
+         *
+         * @param $conf
+         * @param string $prefix
+         * @return array
          */
         protected function _flatten($conf,$prefix='') {
 
@@ -337,7 +373,7 @@ if (!class_exists('configuration')) {
 
             foreach ($this->get_plugin_list() as $plugin) {
                 $plugin_dir = plugin_directory($plugin);
-                if (@file_exists(DOKU_PLUGIN.$plugin_dir.$file)){
+                if (file_exists(DOKU_PLUGIN.$plugin_dir.$file)){
                     $meta = array();
                     @include(DOKU_PLUGIN.$plugin_dir.$file);
                     @include(DOKU_PLUGIN.$plugin_dir.$class);
@@ -352,7 +388,7 @@ if (!class_exists('configuration')) {
             }
 
             // the same for the active template
-            if (@file_exists(tpl_incdir().$file)){
+            if (file_exists(tpl_incdir().$file)){
                 $meta = array();
                 @include(tpl_incdir().$file);
                 @include(tpl_incdir().$class);
@@ -380,7 +416,7 @@ if (!class_exists('configuration')) {
 
             foreach ($this->get_plugin_list() as $plugin) {
                 $plugin_dir = plugin_directory($plugin);
-                if (@file_exists(DOKU_PLUGIN.$plugin_dir.$file)){
+                if (file_exists(DOKU_PLUGIN.$plugin_dir.$file)){
                     $conf = $this->_read_config(DOKU_PLUGIN.$plugin_dir.$file);
                     foreach ($conf as $key => $value){
                         $default['plugin'.CM_KEYMARKER.$plugin.CM_KEYMARKER.$key] = $value;
@@ -389,7 +425,7 @@ if (!class_exists('configuration')) {
             }
 
             // the same for the active template
-            if (@file_exists(tpl_incdir().$file)){
+            if (file_exists(tpl_incdir().$file)){
                 $conf = $this->_read_config(tpl_incdir().$file);
                 foreach ($conf as $key => $value){
                     $default['tpl'.CM_KEYMARKER.$tpl.CM_KEYMARKER.$key] = $value;
@@ -403,6 +439,9 @@ if (!class_exists('configuration')) {
 }
 
 if (!class_exists('setting')) {
+    /**
+     * Class setting
+     */
     class setting {
 
         var $_key = '';
@@ -423,7 +462,7 @@ if (!class_exists('setting')) {
          * @param string $key
          * @param array|null $params array with metadata of setting
          */
-        public function setting($key, $params=null) {
+        public function __construct($key, $params=null) {
             $this->_key = $key;
 
             if (is_array($params)) {
@@ -452,7 +491,7 @@ if (!class_exists('setting')) {
          * - if changed value passes error check, set $this->_local to the new value
          *
          * @param  mixed   $input   the new value
-         * @return boolean          true if changed, false otherwise (incl. on error)
+         * @return boolean          true if changed, false otherwise (also on error)
          */
         public function update($input) {
             if (is_null($input)) return false;
@@ -474,12 +513,11 @@ if (!class_exists('setting')) {
         /**
          * Build html for label and input of setting
          *
-         * @param DokuWiki_Plugin $plugin object of config plugin
-         * @param bool            $echo   true: show inputted value, when error occurred, otherwise the stored setting
-         * @return array(string $label_html, string $input_html)
+         * @param admin_plugin_config $plugin object of config plugin
+         * @param bool $echo true: show inputted value, when error occurred, otherwise the stored setting
+         * @return string[] with content array(string $label_html, string $input_html)
          */
-        public function html(&$plugin, $echo=false) {
-            $value = '';
+        public function html(admin_plugin_config $plugin, $echo=false) {
             $disable = '';
 
             if ($this->is_protected()) {
@@ -503,6 +541,10 @@ if (!class_exists('setting')) {
 
         /**
          * Generate string to save setting value to file according to $fmt
+         *
+         * @param string $var name of variable
+         * @param string $fmt save format
+         * @return string
          */
         public function out($var, $fmt='php') {
 
@@ -523,10 +565,10 @@ if (!class_exists('setting')) {
         /**
          * Returns the localized prompt
          *
-         * @param DokuWiki_Plugin $plugin object of config plugin
+         * @param admin_plugin_config $plugin object of config plugin
          * @return string text
          */
-        public function prompt(&$plugin) {
+        public function prompt(admin_plugin_config $plugin) {
             $prompt = $plugin->getLang($this->_key);
             if (!$prompt) $prompt = htmlspecialchars(str_replace(array('____','_'),' ',$this->_key));
             return $prompt;
@@ -556,7 +598,7 @@ if (!class_exists('setting')) {
         /**
          * Returns caution
          *
-         * @return bool|string caution string, otherwise false for invalid caution
+         * @return false|string caution string, otherwise false for invalid caution
          */
         public function caution() {
             if (!empty($this->_caution)) {
@@ -603,12 +645,15 @@ if (!class_exists('setting')) {
 
 
 if (!class_exists('setting_array')) {
+    /**
+     * Class setting_array
+     */
     class setting_array extends setting {
 
         /**
          * Create an array from a string
          *
-         * @param $string
+         * @param string $string
          * @return array
          */
         protected function _from_string($string){
@@ -622,7 +667,7 @@ if (!class_exists('setting_array')) {
         /**
          * Create a string from an array
          *
-         * @param $array
+         * @param array $array
          * @return string
          */
         protected function _from_array($array){
@@ -657,13 +702,23 @@ if (!class_exists('setting_array')) {
             return true;
         }
 
+        /**
+         * Escaping
+         *
+         * @param string $string
+         * @return string
+         */
         protected function _escape($string) {
             $tr = array("\\" => '\\\\', "'" => '\\\'');
             return "'".strtr( cleanText($string), $tr)."'";
         }
 
         /**
-         * generate string to save setting value to file according to $fmt
+         * Generate string to save setting value to file according to $fmt
+         *
+         * @param string $var name of variable
+         * @param string $fmt save format
+         * @return string
          */
         function out($var, $fmt='php') {
 
@@ -680,8 +735,14 @@ if (!class_exists('setting_array')) {
             return $out;
         }
 
-        function html(&$plugin, $echo=false) {
-            $value = '';
+        /**
+         * Build html for label and input of setting
+         *
+         * @param admin_plugin_config $plugin object of config plugin
+         * @param bool            $echo   true: show inputted value, when error occurred, otherwise the stored setting
+         * @return string[] with content array(string $label_html, string $input_html)
+         */
+        function html(admin_plugin_config $plugin, $echo=false) {
             $disable = '';
 
             if ($this->is_protected()) {
@@ -706,9 +767,18 @@ if (!class_exists('setting_array')) {
 }
 
 if (!class_exists('setting_string')) {
+    /**
+     * Class setting_string
+     */
     class setting_string extends setting {
-        function html(&$plugin, $echo=false) {
-            $value = '';
+        /**
+         * Build html for label and input of setting
+         *
+         * @param admin_plugin_config $plugin object of config plugin
+         * @param bool            $echo   true: show inputted value, when error occurred, otherwise the stored setting
+         * @return string[] with content array(string $label_html, string $input_html)
+         */
+        function html(admin_plugin_config $plugin, $echo=false) {
             $disable = '';
 
             if ($this->is_protected()) {
@@ -733,10 +803,21 @@ if (!class_exists('setting_string')) {
 }
 
 if (!class_exists('setting_password')) {
+    /**
+     * Class setting_password
+     */
     class setting_password extends setting_string {
 
         var $_code = 'plain';  // mechanism to be used to obscure passwords
 
+        /**
+         * update changed setting with user provided value $input
+         * - if changed value fails error check, save it to $this->_input (to allow echoing later)
+         * - if changed value passes error check, set $this->_local to the new value
+         *
+         * @param  mixed   $input   the new value
+         * @return boolean          true if changed, false otherwise (also on error)
+         */
         function update($input) {
             if ($this->is_protected()) return false;
             if (!$input) return false;
@@ -751,9 +832,15 @@ if (!class_exists('setting_password')) {
             return true;
         }
 
-        function html(&$plugin, $echo=false) {
+        /**
+         * Build html for label and input of setting
+         *
+         * @param admin_plugin_config $plugin object of config plugin
+         * @param bool            $echo   true: show inputted value, when error occurred, otherwise the stored setting
+         * @return string[] with content array(string $label_html, string $input_html)
+         */
+        function html(admin_plugin_config $plugin, $echo=false) {
 
-            $value = '';
             $disable = $this->is_protected() ? 'disabled="disabled"' : '';
 
             $key = htmlspecialchars($this->_key);
@@ -766,7 +853,9 @@ if (!class_exists('setting_password')) {
 }
 
 if (!class_exists('setting_email')) {
-
+    /**
+     * Class setting_email
+     */
     class setting_email extends setting_string {
         var $_multiple = false;
         var $_placeholders = false;
@@ -775,6 +864,7 @@ if (!class_exists('setting_email')) {
          * update setting with user provided value $input
          * if value fails error check, save it
          *
+         * @param mixed $input
          * @return boolean true if changed, false otherwise (incl. on error)
          */
         function update($input) {
@@ -825,20 +915,10 @@ if (!class_exists('setting_email')) {
     }
 }
 
-/**
- * @deprecated 2013-02-16
- */
-if (!class_exists('setting_richemail')) {
-    class setting_richemail extends setting_email {
-        function update($input) {
-            $this->_placeholders = true;
-            return parent::update($input);
-        }
-    }
-}
-
-
 if (!class_exists('setting_numeric')) {
+    /**
+     * Class setting_numeric
+     */
     class setting_numeric extends setting_string {
         // This allows for many PHP syntax errors...
         // var $_pattern = '/^[-+\/*0-9 ]*$/';
@@ -847,6 +927,14 @@ if (!class_exists('setting_numeric')) {
         var $_min = null;
         var $_max = null;
 
+        /**
+         * update changed setting with user provided value $input
+         * - if changed value fails error check, save it to $this->_input (to allow echoing later)
+         * - if changed value passes error check, set $this->_local to the new value
+         *
+         * @param  mixed   $input   the new value
+         * @return boolean          true if changed, false otherwise (also on error)
+         */
         function update($input) {
             $local = $this->_local;
             $valid = parent::update($input);
@@ -863,6 +951,13 @@ if (!class_exists('setting_numeric')) {
             return $valid;
         }
 
+        /**
+         * Generate string to save setting value to file according to $fmt
+         *
+         * @param string $var name of variable
+         * @param string $fmt save format
+         * @return string
+         */
         function out($var, $fmt='php') {
 
             if ($this->is_protected()) return '';
@@ -881,17 +976,44 @@ if (!class_exists('setting_numeric')) {
 }
 
 if (!class_exists('setting_numericopt')) {
+    /**
+     * Class setting_numericopt
+     */
     class setting_numericopt extends setting_numeric {
         // just allow an empty config
         var $_pattern = '/^(|[-]?[0-9]+(?:[-+*][0-9]+)*)$/';
+
+
+        /**
+         * Empty string is valid for numericopt
+         *
+         * @param mixed $input
+         *
+         * @return bool
+         */
+        function update($input) {
+            if ($input === '') {
+                return true;
+            }
+
+            return parent::update($input);
+        }
     }
 }
 
 if (!class_exists('setting_onoff')) {
+    /**
+     * Class setting_onoff
+     */
     class setting_onoff extends setting_numeric {
-
-        function html(&$plugin, $echo = false) {
-            $value = '';
+        /**
+         * Build html for label and input of setting
+         *
+         * @param admin_plugin_config $plugin object of config plugin
+         * @param bool            $echo   true: show inputted value, when error occurred, otherwise the stored setting
+         * @return string[] with content array(string $label_html, string $input_html)
+         */
+        function html(admin_plugin_config $plugin, $echo = false) {
             $disable = '';
 
             if ($this->is_protected()) {
@@ -909,6 +1031,14 @@ if (!class_exists('setting_onoff')) {
             return array($label,$input);
         }
 
+        /**
+         * update changed setting with user provided value $input
+         * - if changed value fails error check, save it to $this->_input (to allow echoing later)
+         * - if changed value passes error check, set $this->_local to the new value
+         *
+         * @param  mixed   $input   the new value
+         * @return boolean          true if changed, false otherwise (also on error)
+         */
         function update($input) {
             if ($this->is_protected()) return false;
 
@@ -923,11 +1053,21 @@ if (!class_exists('setting_onoff')) {
 }
 
 if (!class_exists('setting_multichoice')) {
+    /**
+     * Class setting_multichoice
+     */
     class setting_multichoice extends setting_string {
         var $_choices = array();
+        var $lang; //some custom language strings are stored in setting
 
-        function html(&$plugin, $echo = false) {
-            $value = '';
+        /**
+         * Build html for label and input of setting
+         *
+         * @param admin_plugin_config $plugin object of config plugin
+         * @param bool            $echo   true: show inputted value, when error occurred, otherwise the stored setting
+         * @return string[] with content array(string $label_html, string $input_html)
+         */
+        function html(admin_plugin_config $plugin, $echo = false) {
             $disable = '';
             $nochoice = '';
 
@@ -970,6 +1110,14 @@ if (!class_exists('setting_multichoice')) {
             return array($label,$input);
         }
 
+        /**
+         * update changed setting with user provided value $input
+         * - if changed value fails error check, save it to $this->_input (to allow echoing later)
+         * - if changed value passes error check, set $this->_local to the new value
+         *
+         * @param  mixed   $input   the new value
+         * @return boolean          true if changed, false otherwise (also on error)
+         */
         function update($input) {
             if (is_null($input)) return false;
             if ($this->is_protected()) return false;
@@ -987,10 +1135,20 @@ if (!class_exists('setting_multichoice')) {
 
 
 if (!class_exists('setting_dirchoice')) {
+    /**
+     * Class setting_dirchoice
+     */
     class setting_dirchoice extends setting_multichoice {
 
         var $_dir = '';
 
+        /**
+         * Receives current values for the setting $key
+         *
+         * @param mixed $default   default setting value
+         * @param mixed $local     local setting value
+         * @param mixed $protected protected setting value
+         */
         function initialize($default,$local,$protected) {
 
             // populate $this->_choices with a list of directories
@@ -1016,12 +1174,18 @@ if (!class_exists('setting_dirchoice')) {
 
 
 if (!class_exists('setting_hidden')) {
+    /**
+     * Class setting_hidden
+     */
     class setting_hidden extends setting {
         // Used to explicitly ignore a setting in the configuration manager.
     }
 }
 
 if (!class_exists('setting_fieldset')) {
+    /**
+     * Class setting_fieldset
+     */
     class setting_fieldset extends setting {
         // A do-nothing class used to detect the 'fieldset' type.
         // Used to start a new settings "display-group".
@@ -1029,6 +1193,9 @@ if (!class_exists('setting_fieldset')) {
 }
 
 if (!class_exists('setting_undefined')) {
+    /**
+     * Class setting_undefined
+     */
     class setting_undefined extends setting_hidden {
         // A do-nothing class used to detect settings with no metadata entry.
         // Used internaly to hide undefined settings, and generate the undefined settings list.
@@ -1036,6 +1203,9 @@ if (!class_exists('setting_undefined')) {
 }
 
 if (!class_exists('setting_no_class')) {
+    /**
+     * Class setting_no_class
+     */
     class setting_no_class extends setting_undefined {
         // A do-nothing class used to detect settings with a missing setting class.
         // Used internaly to hide undefined settings, and generate the undefined settings list.
@@ -1043,6 +1213,9 @@ if (!class_exists('setting_no_class')) {
 }
 
 if (!class_exists('setting_no_default')) {
+    /**
+     * Class setting_no_default
+     */
     class setting_no_default extends setting_undefined {
         // A do-nothing class used to detect settings with no default value.
         // Used internaly to hide undefined settings, and generate the undefined settings list.
@@ -1050,11 +1223,23 @@ if (!class_exists('setting_no_default')) {
 }
 
 if (!class_exists('setting_multicheckbox')) {
+    /**
+     * Class setting_multicheckbox
+     */
     class setting_multicheckbox extends setting_string {
 
         var $_choices = array();
         var $_combine = array();
+        var $_other = 'always';
 
+        /**
+         * update changed setting with user provided value $input
+         * - if changed value fails error check, save it to $this->_input (to allow echoing later)
+         * - if changed value passes error check, set $this->_local to the new value
+         *
+         * @param  mixed   $input   the new value
+         * @return boolean          true if changed, false otherwise (also on error)
+         */
         function update($input) {
             if ($this->is_protected()) return false;
 
@@ -1075,9 +1260,15 @@ if (!class_exists('setting_multicheckbox')) {
             return true;
         }
 
-        function html(&$plugin, $echo=false) {
+        /**
+         * Build html for label and input of setting
+         *
+         * @param admin_plugin_config $plugin object of config plugin
+         * @param bool            $echo   true: show input value, when error occurred, otherwise the stored setting
+         * @return string[] with content array(string $label_html, string $input_html)
+         */
+        function html(admin_plugin_config $plugin, $echo=false) {
 
-            $value = '';
             $disable = '';
 
             if ($this->is_protected()) {
@@ -1104,9 +1295,7 @@ if (!class_exists('setting_multicheckbox')) {
 
                 $checked = ($idx !== false) ? 'checked="checked"' : '';
 
-                // ideally this would be handled using a second class of "default", however IE6 does not
-                // correctly support CSS selectors referencing multiple class names on the same element
-                // (e.g. .default.selection).
+                // @todo ideally this would be handled using a second class of "default"
                 $class = (($idx !== false) == (false !== $idx_default)) ? " selectiondefault" : "";
 
                 $prompt = ($plugin->getLang($this->_key.'_'.$choice) ?
@@ -1123,22 +1312,30 @@ if (!class_exists('setting_multicheckbox')) {
             }
 
             // handle any remaining values
-            $other = join(',',$value);
+            if ($this->_other != 'never'){
+                $other = join(',',$value);
+                // test equivalent to ($this->_other == 'always' || ($other && $this->_other == 'exists')
+                // use != 'exists' rather than == 'always' to ensure invalid values default to 'always'
+                if ($this->_other != 'exists' || $other) {
 
-            $class = (count($default == count($value)) && (count($value) == count(array_intersect($value,$default)))) ?
-                            " selectiondefault" : "";
-
-            $input .= '<div class="other'.$class.'">'."\n";
-            $input .= '<label for="config___'.$key.'_other">'.$plugin->getLang($key.'_other')."</label>\n";
-            $input .= '<input id="config___'.$key.'_other" name="config['.$key.'][other]" type="text" class="edit" value="'.htmlspecialchars($other).'" '.$disable." />\n";
-            $input .= "</div>\n";
+                    $class = ((count($default) == count($value)) && (count($value) == count(array_intersect($value,$default)))) ?
+                                    " selectiondefault" : "";
 
+                    $input .= '<div class="other'.$class.'">'."\n";
+                    $input .= '<label for="config___'.$key.'_other">'.$plugin->getLang($key.'_other')."</label>\n";
+                    $input .= '<input id="config___'.$key.'_other" name="config['.$key.'][other]" type="text" class="edit" value="'.htmlspecialchars($other).'" '.$disable." />\n";
+                    $input .= "</div>\n";
+                }
+            }
             $label = '<label>'.$this->prompt($plugin).'</label>';
             return array($label,$input);
         }
 
         /**
          * convert comma separated list to an array and combine any complimentary values
+         *
+         * @param string $str
+         * @return array
          */
         function _str2array($str) {
             $array = explode(',',$str);
@@ -1162,6 +1359,9 @@ if (!class_exists('setting_multicheckbox')) {
 
         /**
          * convert array of values + other back to a comma separated list, incl. splitting any combined values
+         *
+         * @param array $input
+         * @return string
          */
         function _array2str($input) {
 
@@ -1190,6 +1390,9 @@ if (!class_exists('setting_multicheckbox')) {
 }
 
 if (!class_exists('setting_regex')){
+    /**
+     * Class setting_regex
+     */
     class setting_regex extends setting_string {
 
         var $_delimiter = '/';    // regex delimiter to be used in testing input
@@ -1213,7 +1416,7 @@ if (!class_exists('setting_regex')){
             // see if the regex compiles and runs (we don't check for effectiveness)
             $regex = $this->_delimiter . $input . $this->_delimiter . $this->_pregflags;
             $lastError = error_get_last();
-            $ok = @preg_match($regex,'testdata');
+            @preg_match($regex,'testdata');
             if (preg_last_error() != PREG_NO_ERROR || error_get_last() != $lastError) {
                 $this->_input = $input;
                 $this->_error = true;
