@@ -3,10 +3,10 @@
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
+ * @author Martin Michalek <michalek.dev@gmail.com>
  * @author Ondrej Végh <ov@vsieti.sk>
  * @author Michal Mesko <michal.mesko@gmail.com>
- * @author exusik@gmail.com
- * @author Martin Michalek <michalek.dev@gmail.com>
+ * @author exusik <exusik@gmail.com>
  */
 $lang['menu']                  = 'Správa používateľov';
 $lang['noauth']                = '(autentifikácia užívateľov nie je dostupná)';
@@ -67,3 +67,8 @@ $lang['import_error_readfail'] = 'Import neúspešný. Nie je možné prečíta
 $lang['import_error_create']   = 'Nie je možné vytvoriť pouzívateľa';
 $lang['import_notify_fail']    = 'Správa nemohla byť zaslaná importovanému používatelovi, %s s emailom %s.';
 $lang['import_downloadfailures'] = 'Stiahnuť chyby vo formáte CSV za účelom opravy';
+$lang['addUser_error_modPass_disabled'] = 'Zmena hesla nie je momentálne povolená';
+$lang['addUser_error_name_missing'] = 'Prosím zadajte meno nového používateľa.';
+$lang['addUser_error_modName_disabled'] = 'Zmena mena nie je momentálne povolená.';
+$lang['addUser_error_mail_missing'] = 'Prosím zadajte emailovú adresu nového používateľa.';
+$lang['addUser_error_modMail_disabled'] = 'Zmena emailovej adresy nie je momentálne povolená.';
