@@ -30,8 +30,8 @@ var dw_mediamanager = {
     init: function () {
         var $content, $tree;
         $content = jQuery('#media__content');
-        $tree    = jQuery('#media__tree');
-        if(!$tree.length) return;
+        $tree = jQuery('#media__tree');
+        if (!$tree.length) return;
 
         dw_mediamanager.prepare_content($content);
 
@@ -39,33 +39,33 @@ var dw_mediamanager = {
         dw_mediamanager.initpopup();
 
         // add the action to autofill the "upload as" field
-        $content.delegate('#upload__file', 'change', dw_mediamanager.suggest)
-                // Attach the image selector action to all links
-                .delegate('a.select', 'click', dw_mediamanager.select)
-                // Attach deletion confirmation dialog to the delete buttons
-                .delegate('#media__content a.btn_media_delete', 'click',
-                          dw_mediamanager.confirmattach)
-                .delegate('#mediamanager__done_form', 'submit', dw_mediamanager.list);
+        $content
+            .on('change', '#upload__file', dw_mediamanager.suggest)
+            // Attach the image selector action to all links
+            .on('click', 'a.select', dw_mediamanager.select)
+            // Attach deletion confirmation dialog to the delete buttons
+            .on('click', '#media__content a.btn_media_delete', dw_mediamanager.confirmattach)
+            .on('submit', '#mediamanager__done_form', dw_mediamanager.list);
 
-        $tree.dw_tree({toggle_selector: 'img',
-                       load_data: function (show_sublist, $clicky) {
-                           // get the enclosed link (is always the first one)
-                           var $link = $clicky.parent().find('div.li a.idx_dir');
+        $tree.dw_tree({
+            toggle_selector: 'img',
+            load_data: function (show_sublist, $clicky) {
+                // get the enclosed link (is always the first one)
+                var $link = $clicky.parent().find('div.li a.idx_dir');
 
-                           jQuery.post(
-                               DOKU_BASE + 'lib/exe/ajax.php',
-                               $link[0].search.substr(1) + '&call=medians',
-                               show_sublist,
-                               'html'
-                           );
-                       },
+                jQuery.post(
+                    DOKU_BASE + 'lib/exe/ajax.php',
+                    $link[0].search.substr(1) + '&call=medians',
+                    show_sublist,
+                    'html'
+                );
+            },
 
-                       toggle_display: function ($clicky, opening) {
-                           $clicky.attr('src',
-                                        DOKU_BASE + 'lib/images/' +
-                                        (opening ? 'minus' : 'plus') + '.gif');
-                       }});
-        $tree.delegate('a', 'click', dw_mediamanager.list);
+            toggle_display: function ($clicky, opening) {
+                $clicky.attr('src', DOKU_BASE + 'lib/images/' + (opening ? 'minus' : 'plus') + '.gif');
+            }
+        });
+        $tree.on('click', 'a', dw_mediamanager.list);
 
         // Init view property
         dw_mediamanager.set_fileview_list();
@@ -76,34 +76,37 @@ var dw_mediamanager = {
         dw_mediamanager.init_ajax_uploader();
 
         // changing opened tab in the file list panel
-        jQuery('#mediamanager__page div.filelist').delegate('ul.tabs a', 'click', dw_mediamanager.list)
+        var $page = jQuery('#mediamanager__page');
+        $page.find('div.filelist')
+            .on('click', 'ul.tabs a', dw_mediamanager.list)
             // loading file details
-            .delegate('div.panelContent a', 'click', dw_mediamanager.details)
+            .on('click', 'div.panelContent a', dw_mediamanager.details)
             // search form
-            .delegate('#dw__mediasearch', 'submit', dw_mediamanager.list)
+            .on('submit', '#dw__mediasearch', dw_mediamanager.list)
             // "upload as" field autofill
-            .delegate('#upload__file', 'change', dw_mediamanager.suggest)
+            .on('change', '#upload__file', dw_mediamanager.suggest)
             // uploaded images
-            .delegate('.qq-upload-file a', 'click', dw_mediamanager.details);
+            .on('click', '.qq-upload-file a', dw_mediamanager.details);
 
         // changing opened tab in the file details panel
-        jQuery('#mediamanager__page div.file').delegate('ul.tabs a', 'click', dw_mediamanager.details)
+        $page.find('div.file')
+            .on('click', 'ul.tabs a', dw_mediamanager.details)
             // "update new version" button
-            .delegate('#mediamanager__btn_update', 'submit', dw_mediamanager.list)
+            .on('submit', '#mediamanager__btn_update', dw_mediamanager.list)
             // revisions form
-            .delegate('#page__revisions', 'submit', dw_mediamanager.details)
-            .delegate('#page__revisions a', 'click', dw_mediamanager.details)
+            .on('submit', '#page__revisions', dw_mediamanager.details)
+            .on('click', '#page__revisions a', dw_mediamanager.details)
             // meta edit form
-            .delegate('#mediamanager__save_meta', 'submit', dw_mediamanager.details)
+            .on('submit', '#mediamanager__save_meta', dw_mediamanager.details)
             // delete button
-            .delegate('#mediamanager__btn_delete', 'submit', dw_mediamanager.details)
+            .on('submit', '#mediamanager__btn_delete', dw_mediamanager.details)
             // "restore this version" button
-            .delegate('#mediamanager__btn_restore', 'submit', dw_mediamanager.details)
+            .on('submit', '#mediamanager__btn_restore', dw_mediamanager.details)
             // less/more recent buttons in media revisions form
-            .delegate('.btn_newer, .btn_older', 'submit', dw_mediamanager.details);
+            .on('submit', '.btn_newer, .btn_older', dw_mediamanager.details);
 
         dw_mediamanager.update_resizable();
-        dw_mediamanager.layout_width = jQuery("#mediamanager__page").width();
+        dw_mediamanager.layout_width = $page.width();
         jQuery(window).resize(dw_mediamanager.window_resize);
     },
 
@@ -119,7 +122,7 @@ var dw_mediamanager = {
         $both = $listType.add($sortBy);
 
         // Remove the submit button
-        $options.find('input[type=submit]').parent().hide();
+        $options.find('button[type=submit]').parent().hide();
 
         // Prepare HTML for jQuery UI buttonset
         $both.find('label').each(function () {
@@ -128,10 +131,11 @@ var dw_mediamanager = {
         });
 
         // Init buttonset
-        $both.buttonset();
+        $both.find("input[type='radio']").checkboxradio({icon: false});
+        $both.controlgroup();
 
         // Change handlers
-        $listType.children('input').change(function (event) {
+        $listType.children('input').change(function () {
             dw_mediamanager.set_fileview_list();
         });
         $sortBy.children('input').change(function (event) {
@@ -149,43 +153,51 @@ var dw_mediamanager = {
         var opts, $insp, $insbtn;
 
         dw_mediamanager.$popup = jQuery(document.createElement('div'))
-                 .attr('id', 'media__popup_content')
-                 .dialog({autoOpen: false, width: 280, modal: true,
-                          draggable: true, title: LANG.mediatitle,
-                          resizable: false});
+            .attr('id', 'media__popup_content')
+            .dialog({
+                autoOpen: false, width: 280, modal: true,
+                draggable: true, title: LANG.mediatitle,
+                resizable: false
+            });
 
-        opts = [{id: 'link', label: LANG.mediatarget,
-                 btns: ['lnk', 'direct', 'nolnk', 'displaylnk']},
-                {id: 'align', label: LANG.mediaalign,
-                 btns: ['noalign', 'left', 'center', 'right']},
-                {id: 'size', label: LANG.mediasize,
-                 btns: ['small', 'medium', 'large', 'original']}
-               ];
+        opts = [
+            {
+                id: 'link', label: LANG.mediatarget,
+                btns: ['lnk', 'direct', 'nolnk', 'displaylnk']
+            },
+            {
+                id: 'align', label: LANG.mediaalign,
+                btns: ['noalign', 'left', 'center', 'right']
+            },
+            {
+                id: 'size', label: LANG.mediasize,
+                btns: ['small', 'medium', 'large', 'original']
+            }
+        ];
 
         jQuery.each(opts, function (_, opt) {
             var $p, $l;
             $p = jQuery(document.createElement('p'))
-                 .attr('id', 'media__' + opt.id);
+                .attr('id', 'media__' + opt.id);
 
             if (dw_mediamanager.display === "2") {
                 $p.hide();
             }
 
             $l = jQuery(document.createElement('label'))
-                 .text(opt.label);
+                .text(opt.label);
             $p.append($l);
 
             jQuery.each(opt.btns, function (i, text) {
                 var $btn, $img;
                 $btn = jQuery(document.createElement('button'))
-                       .addClass('button')
-                       .attr('id', "media__" + opt.id + "btn" + (i + 1))
-                       .attr('title', LANG['media' + text])
-                       .click(bind(dw_mediamanager.setOpt, opt.id));
+                    .addClass('button')
+                    .attr('id', "media__" + opt.id + "btn" + (i + 1))
+                    .attr('title', LANG['media' + text])
+                    .click(bind(dw_mediamanager.setOpt, opt.id));
 
                 $img = jQuery(document.createElement('img'))
-                       .attr('src', DOKU_BASE + 'lib/images/media_' +
-                                    opt.id + '_' + text + '.png');
+                    .attr('src', DOKU_BASE + 'lib/images/media_' + opt.id + '_' + text + '.png');
 
                 $btn.append($img);
                 $p.append($btn);
@@ -199,10 +211,10 @@ var dw_mediamanager = {
         dw_mediamanager.$popup.append($insp);
 
         $insbtn = jQuery(document.createElement('input'))
-                  .attr('id', 'media__sendbtn')
-                  .attr('type', 'button')
-                  .addClass('button')
-                  .val(LANG.mediainsert);
+            .attr('id', 'media__sendbtn')
+            .attr('type', 'button')
+            .addClass('button')
+            .val(LANG.mediainsert);
         $insp.append($insbtn);
     },
 
@@ -214,19 +226,17 @@ var dw_mediamanager = {
      * @author Pierre Spring <pierre.spring@caillou.ch>
      */
     insert: function (id) {
-        var opts, alignleft, alignright, edid, s;
+        var opts, cb, edid, s;
 
         // set syntax options
         dw_mediamanager.$popup.dialog('close');
 
         opts = '';
-        alignleft = '';
-        alignright = '';
 
         if ({img: 1, swf: 1}[dw_mediamanager.ext] === 1) {
 
             if (dw_mediamanager.link === '4') {
-                    opts = '?linkonly';
+                opts = '?linkonly';
             } else {
 
                 if (dw_mediamanager.link === "3" && dw_mediamanager.ext === 'img') {
@@ -236,47 +246,48 @@ var dw_mediamanager = {
                 }
 
                 s = parseInt(dw_mediamanager.size, 10);
+                var size = s * 200;
 
                 if (s && s >= 1 && s < 4) {
-                    opts += (opts.length)?'&':'?';
-                    opts += dw_mediamanager.size + '00';
+                    opts += (opts.length) ? '&' : '?';
+                    opts += size;
                     if (dw_mediamanager.ext === 'swf') {
                         switch (s) {
-                        case 1:
-                            opts += 'x62';
-                            break;
-                        case 2:
-                            opts += 'x123';
-                            break;
-                        case 3:
-                            opts += 'x185';
-                            break;
+                            case 1:
+                                opts += 'x62';
+                                break;
+                            case 2:
+                                opts += 'x123';
+                                break;
+                            case 3:
+                                opts += 'x185';
+                                break;
                         }
                     }
                 }
-                if (dw_mediamanager.align !== '1') {
-                    alignleft = dw_mediamanager.align === '2' ? '' : ' ';
-                    alignright = dw_mediamanager.align === '4' ? '' : ' ';
-                }
             }
         }
         edid = String.prototype.match.call(document.location, /&edid=([^&]+)/);
-        opener.insertTags(edid ? edid[1] : 'wiki__text',
-                          '{{'+alignleft+id+opts+alignright+'|','}}','');
+        edid = edid ? edid[1] : 'wiki__text';
+        cb = String.prototype.match.call(document.location, /&onselect=([^&]+)/);
+        cb = cb ? cb[1].replace(/[^\w]+/, '') : 'dw_mediamanager_item_select';
 
-        if(!dw_mediamanager.keepopen) {
+        // arguments here only match the dw_mediamanager_item_select function, these will need to change if you override cb with onselect GET param
+        opener[cb](edid, id, opts, dw_mediamanager.align, dw_mediamanager.keepopen);
+        if (!dw_mediamanager.keepopen) {
             window.close();
         }
         opener.focus();
         return false;
     },
 
+
     /**
      * Prefills the wikiname.
      *
      * @author Andreas Gohr <andi@splitbrain.org>
      */
-    suggest: function(){
+    suggest: function () {
         var $file, $name, text;
 
         $file = jQuery(this);
@@ -284,13 +295,13 @@ var dw_mediamanager = {
 
         if ($name.val() != '') return;
 
-        if(!$file.length || !$name.length) {
+        if (!$file.length || !$name.length) {
             return;
         }
 
         text = $file.val();
-        text = text.substr(text.lastIndexOf('/')+1);
-        text = text.substr(text.lastIndexOf('\\')+1);
+        text = text.substr(text.lastIndexOf('/') + 1);
+        text = text.substr(text.lastIndexOf('\\') + 1);
         $name.val(text);
     },
 
@@ -340,24 +351,27 @@ var dw_mediamanager = {
         dw_mediamanager.update_content($content, params);
     },
 
-     /**
+    /**
      * Returns form parameters
      *
      * @author Kate Arzamastseva <pshns@ukr.net>
      */
     form_params: function ($form) {
         if (!$form.length) return;
+
         var action = '';
         var i = $form[0].action.indexOf('?');
-        if (i >= 0) action = $form[0].action.substr(i+1);
-        return action+'&'+$form.serialize();
+        if (i >= 0) {
+            action = $form[0].action.substr(i + 1);
+        }
+        return action + '&' + $form.serialize();
     },
 
     set_fileview_list: function (new_type) {
         dw_mediamanager.set_fileview_opt(['list', 'listType', function (new_type) {
             jQuery('div.filelist div.panelContent ul')
-               .toggleClass('rows', new_type === 'rows')
-               .toggleClass('thumbs', new_type === 'thumbs');
+                .toggleClass('rows', new_type === 'rows')
+                .toggleClass('thumbs', new_type === 'thumbs');
         }], new_type);
 
         // FIXME: Move to onchange handler (opt[2])?
@@ -373,7 +387,7 @@ var dw_mediamanager = {
     set_fileview_opt: function (opt, new_val) {
         if (typeof new_val === 'undefined') {
             new_val = jQuery('form.options li.' + opt[1] + ' input')
-                        .filter(':checked').val();
+                .filter(':checked').val();
             // if new_val is still undefined (because form.options is not in active tab), set to most spacious option
             if (typeof new_val === 'undefined') {
                 new_val = 'thumbs';
@@ -389,7 +403,7 @@ var dw_mediamanager = {
         }
     },
 
-     /**
+    /**
      * Lists the content of the right column (image details) using AJAX
      *
      * @author Kate Arzamastseva <pshns@ukr.net>
@@ -420,7 +434,7 @@ var dw_mediamanager = {
         }
 
         update_list = ($link[0].id == 'mediamanager__btn_delete' ||
-                       $link[0].id == 'mediamanager__btn_restore');
+        $link[0].id == 'mediamanager__btn_restore');
 
         dw_mediamanager.update_content($content, params, update_list);
     },
@@ -435,7 +449,7 @@ var dw_mediamanager = {
                 dw_mediamanager.$resizables().resizable('destroy');
 
                 if (update_list) {
-                    dw_mediamanager.list.call(jQuery('#mediamanager__page form.options input[type="submit"]')[0]);
+                    dw_mediamanager.list.call(jQuery('#mediamanager__page').find('form.options button[type="submit"]')[0]);
                 }
 
                 $content.html(data);
@@ -480,39 +494,30 @@ var dw_mediamanager = {
      * @author Kate Arzamastseva <pshns@ukr.net>
      */
     update_resizable: function () {
-        $resizables = dw_mediamanager.$resizables();
+        var $resizables = dw_mediamanager.$resizables();
 
         $resizables.resizable({
-            handles: 'e',
-            resize: function(event, ui){
-                var widthFull = jQuery('#mediamanager__page').width();
+            handles: (jQuery('html[dir=rtl]').length ? 'w' : 'e'),
+            resize: function (event, ui) {
+                var $page = jQuery('#mediamanager__page');
+                var widthFull = $page.width();
                 var widthResizables = 0;
-                $resizables.each(function() {
+                $resizables.each(function () {
                     widthResizables += jQuery(this).width();
                 });
-                var $filePanel = jQuery('#mediamanager__page div.panel.file');
+                var $filePanel = $page.find('div.panel.file');
 
                 // set max width of resizable column
                 var widthOtherResizable = widthResizables - jQuery(this).width();
                 var minWidthNonResizable = parseFloat($filePanel.css("min-width"));
                 var maxWidth = widthFull - (widthOtherResizable + minWidthNonResizable) - 1;
-                $resizables.resizable( "option", "maxWidth", maxWidth );
+                $resizables.resizable("option", "maxWidth", maxWidth);
 
                 // width of file panel in % = 100% - width of resizables in %
                 // this calculates with 99.9 and not 100 to overcome rounding errors
                 var relWidthNonResizable = 99.9 - (100 * widthResizables / widthFull);
                 // set width of file panel
-                $filePanel.width(relWidthNonResizable+'%');
-
-                // FIXME: please fix without browser sniffing
-                if (!jQuery.browser.webkit) {
-                    $resizables.each(function() {
-                        w = jQuery(this).width();
-                        w = (99.99 * w / widthFull);
-                        w += "%";
-                        jQuery(this).width(w);
-                    });
-                }
+                $filePanel.width(relWidthNonResizable + '%');
 
                 dw_mediamanager.resize();
 
@@ -525,11 +530,11 @@ var dw_mediamanager = {
     },
 
     resize: function () {
-        var $contents = jQuery('#mediamanager__page div.panelContent'),
+        var $contents = jQuery('#mediamanager__page').find('div.panelContent'),
             height = jQuery(window).height() - jQuery(document.body).height() +
-                      Math.max.apply(null, jQuery.map($contents, function (v) {
-            return jQuery(v).height();
-        }));
+                Math.max.apply(null, jQuery.map($contents, function (v) {
+                    return jQuery(v).height();
+                }));
 
         // If the screen is too small, don’t try to resize
         if (height < dw_mediamanager.minHeights[dw_mediamanager.view_opts.list]) {
@@ -538,13 +543,12 @@ var dw_mediamanager = {
             $contents.height(height);
             dw_mediamanager.$resizables().each(function () {
                 var $this = jQuery(this);
-                $this.height(height + $this.find('div.panelContent').offset().top -
-                             $this.offset().top);
+                $this.height(height + $this.find('div.panelContent').offset().top - $this.offset().top);
             });
         }
     },
 
-     /**
+    /**
      * Prints 'select' for image difference representation type
      *
      * @author Kate Arzamastseva <pshns@ukr.net>
@@ -552,15 +556,15 @@ var dw_mediamanager = {
     image_diff: function () {
         if (jQuery('#mediamanager__difftype').length) return;
 
-        $form = jQuery('#mediamanager__form_diffview');
+        var $form = jQuery('#mediamanager__form_diffview');
         if (!$form.length) return;
 
-        $label = jQuery(document.createElement('label'));
-        $label.append('<span>'+LANG.media_diff+'</span> ');
-        $select = jQuery(document.createElement('select'))
-         .attr('id', 'mediamanager__difftype')
-         .attr('name', 'difftype')
-         .change(dw_mediamanager.change_diff_type);
+        var $label = jQuery(document.createElement('label'));
+        $label.append('<span>' + LANG.media_diff + '</span> ');
+        var $select = jQuery(document.createElement('select'))
+            .attr('id', 'mediamanager__difftype')
+            .attr('name', 'difftype')
+            .change(dw_mediamanager.change_diff_type);
         $select.append(new Option(LANG.media_diff_both, "both"));
         $select.append(new Option(LANG.media_diff_opacity, "opacity"));
         $select.append(new Option(LANG.media_diff_portions, "portions"));
@@ -580,10 +584,10 @@ var dw_mediamanager = {
      * @author Kate Arzamastseva <pshns@ukr.net>
      */
     change_diff_type: function () {
-        $select = jQuery('#mediamanager__difftype');
-        $content = jQuery('#mediamanager__diff');
+        var $select = jQuery('#mediamanager__difftype');
+        var $content = jQuery('#mediamanager__diff');
 
-        params = dw_mediamanager.form_params($select.closest('form'))+'&call=mediadiff';
+        var params = dw_mediamanager.form_params($select.closest('form')) + '&call=mediadiff';
         jQuery.post(
             DOKU_BASE + 'lib/exe/ajax.php',
             params,
@@ -602,60 +606,61 @@ var dw_mediamanager = {
      * @author Kate Arzamastseva <pshns@ukr.net>
      */
     opacity_slider: function () {
-        var $slider = jQuery( "#mediamanager__diff div.slider" );
+        var $diff = jQuery("#mediamanager__diff");
+        var $slider = $diff.find("div.slider");
         if (!$slider.length) return;
 
-        var $image = jQuery('#mediamanager__diff div.imageDiff.opacity div.image1 img');
+        var $image = $diff.find('div.imageDiff.opacity div.image1 img');
         if (!$image.length) return;
-        $slider.width($image.width()-20);
+        $slider.width($image.width() - 20);
 
         $slider.slider();
         $slider.slider("option", "min", 0);
         $slider.slider("option", "max", 0.999);
         $slider.slider("option", "step", 0.001);
         $slider.slider("option", "value", 0.5);
-        $slider.bind("slide", function(event, ui) {
-            jQuery('#mediamanager__diff div.imageDiff.opacity div.image2 img').css({ opacity: $slider.slider("option", "value")});
+        $slider.on("slide", function (event, ui) {
+            jQuery('#mediamanager__diff').find('div.imageDiff.opacity div.image2 img').css({opacity: $slider.slider("option", "value")});
         });
     },
 
-     /**
+    /**
      * Sets options for red line diff slider
      *
      * @author Kate Arzamastseva <pshns@ukr.net>
      */
     portions_slider: function () {
-        var $image1 = jQuery('#mediamanager__diff div.imageDiff.portions div.image1 img');
-        var $image2 = jQuery('#mediamanager__diff div.imageDiff.portions div.image2 img');
+        var $diff = jQuery("#mediamanager__diff");
+        if (!$diff.length) return;
+
+        var $image1 = $diff.find('div.imageDiff.portions div.image1 img');
+        var $image2 = $diff.find('div.imageDiff.portions div.image2 img');
         if (!$image1.length || !$image2.length) return;
 
-        var $div = jQuery("#mediamanager__diff");
-        if (!$div.length) return;
-
-        $div.width('100%');
+        $diff.width('100%');
         $image2.parent().width('97%');
         $image1.width('100%');
         $image2.width('100%');
 
-        if ($image1.width() < $div.width()) {
-            $div.width($image1.width());
+        if ($image1.width() < $diff.width()) {
+            $diff.width($image1.width());
         }
 
         $image2.parent().width('50%');
         $image2.width($image1.width());
         $image1.width($image1.width());
 
-        var $slider = jQuery("#mediamanager__diff div.slider");
+        var $slider = $diff.find("div.slider");
         if (!$slider.length) return;
-        $slider.width($image1.width()-20);
+        $slider.width($image1.width() - 20);
 
         $slider.slider();
         $slider.slider("option", "min", 0);
         $slider.slider("option", "max", 97);
         $slider.slider("option", "step", 1);
         $slider.slider("option", "value", 50);
-        $slider.bind("slide", function(event, ui) {
-            jQuery('#mediamanager__diff div.imageDiff.portions div.image2').css({ width: $slider.slider("option", "value")+'%'});
+        $slider.on("slide", function (event, ui) {
+            jQuery('#mediamanager__diff').find('div.imageDiff.portions div.image2').css({width: $slider.slider("option", "value") + '%'});
         });
     },
 
@@ -667,7 +672,7 @@ var dw_mediamanager = {
     params_toarray: function (str) {
         var vars = [], hash;
         var hashes = str.split('&');
-        for(var i = 0; i < hashes.length; i++) {
+        for (var i = 0; i < hashes.length; i++) {
             hash = hashes[i].split('=');
             vars[decodeURIComponent(hash[0])] = decodeURIComponent(hash[1]);
         }
@@ -678,7 +683,7 @@ var dw_mediamanager = {
         if (!jQuery('#mediamanager__uploader').length) return;
         if (jQuery('.qq-upload-list').length) return;
 
-        var params = dw_mediamanager.form_params(jQuery('#dw__upload'))+'&call=mediaupload';
+        var params = dw_mediamanager.form_params(jQuery('#dw__upload')) + '&call=mediaupload';
         params = dw_mediamanager.params_toarray(params);
 
         var uploader = new qq.FileUploaderExtended({
@@ -696,7 +701,7 @@ var dw_mediamanager = {
     /**
      * shows the popup for a image link
      */
-    select: function(event){
+    select: function (event) {
         var $link, id, dot, ext;
 
         event.preventDefault();
@@ -704,12 +709,12 @@ var dw_mediamanager = {
         $link = jQuery(this);
         id = $link.attr('id').substr(2);
 
-        if(!opener){
+        if (!opener) {
             // if we don't run in popup display example
             // the id's are a bit wierd and jQuery('#ex_wiki_dokuwiki-128.png')
             // will not be found by Sizzle (the CSS Selector Engine
             // used by jQuery), hence the document.getElementById() call
-            jQuery(document.getElementById('ex_'+id.replace(/:/g,'_').replace(/^_/,''))).dw_toggle();
+            jQuery(document.getElementById('ex_' + id.replace(/:/g, '_').replace(/^_/, ''))).dw_toggle();
             return;
         }
 
@@ -723,19 +728,22 @@ var dw_mediamanager = {
 
         ext = id.substr(dot);
 
-        if ({'.jpg':1, '.jpeg':1, '.png':1, '.gif':1, '.swf':1}[ext] !== 1) {
+        if ({'.jpg': 1, '.jpeg': 1, '.png': 1, '.gif': 1, '.swf': 1}[ext] !== 1) {
             dw_mediamanager.insert(id);
             return;
         }
 
         // remove old callback from the insert button and set the new one.
-        jQuery('#media__sendbtn').unbind().click(bind(dw_mediamanager.insert, id));
+        var $sendbtn = jQuery('#media__sendbtn');
+        $sendbtn.off().click(bind(dw_mediamanager.insert, id));
 
         dw_mediamanager.unforbid('ext');
         if (ext === '.swf') {
             dw_mediamanager.ext = 'swf';
-            dw_mediamanager.forbid('ext', {link: ['1', '2'],
-                                           size: ['4']});
+            dw_mediamanager.forbid('ext', {
+                link: ['1', '2'],
+                size: ['4']
+            });
         } else {
             dw_mediamanager.ext = 'img';
         }
@@ -751,7 +759,7 @@ var dw_mediamanager = {
 
         dw_mediamanager.$popup.dialog('open');
 
-        jQuery('#media__sendbtn').focus();
+        $sendbtn.focus();
     },
 
     /**
@@ -760,8 +768,8 @@ var dw_mediamanager = {
      * @author Michael Klier <chi@chimeric.de>
      * @author Pierre Spring <pierre.spring@caillou.ch>
      */
-    confirmattach: function(e){
-        if(!confirm(LANG.del_confirm + "\n" + jQuery(this).attr('title'))) {
+    confirmattach: function (e) {
+        if (!confirm(LANG.del_confirm + "\n" + jQuery(this).attr('title'))) {
             e.preventDefault();
         }
     },
@@ -772,41 +780,40 @@ var dw_mediamanager = {
      * @author Andreas Gohr <andi@splitbrain.org>
      * @author Pierre Spring <pierre.spring@caillou.ch>
      */
-    attachoptions: function(){
+    attachoptions: function () {
         var $obj, opts;
 
         $obj = jQuery('#media__opts');
-        if($obj.length === 0) {
+        if ($obj.length === 0) {
             return;
         }
 
         opts = [];
         // keep open
-        if(opener){
+        if (opener) {
             opts.push(['keepopen', 'keepopen']);
         }
         opts.push(['hide', 'hidedetails']);
 
         jQuery.each(opts,
-                    function(_, opt) {
-                        var $box, $lbl;
-                        $box = jQuery(document.createElement('input'))
-                                 .attr('type', 'checkbox')
-                                 .attr('id', 'media__' + opt[0])
-                                 .click(bind(dw_mediamanager.toggleOption,
-                                             opt[0]));
+            function (_, opt) {
+                var $box, $lbl;
+                $box = jQuery(document.createElement('input'))
+                    .attr('type', 'checkbox')
+                    .attr('id', 'media__' + opt[0])
+                    .click(bind(dw_mediamanager.toggleOption, opt[0]));
 
-                        if(DokuCookie.getValue(opt[0])){
-                            $box.prop('checked', true);
-                            dw_mediamanager[opt[0]] = true;
-                        }
+                if (DokuCookie.getValue(opt[0])) {
+                    $box.prop('checked', true);
+                    dw_mediamanager[opt[0]] = true;
+                }
 
-                        $lbl = jQuery(document.createElement('label'))
-                                 .attr('for', 'media__' + opt[0])
-                                 .text(LANG[opt[1]]);
+                $lbl = jQuery(document.createElement('label'))
+                    .attr('for', 'media__' + opt[0])
+                    .text(LANG[opt[1]]);
 
-                        $obj.append($box, $lbl, document.createElement('br'));
-                    });
+                $obj.append($box, $lbl, document.createElement('br'));
+            });
 
         dw_mediamanager.updatehide();
     },
@@ -835,8 +842,8 @@ var dw_mediamanager = {
      *
      * @author Andreas Gohr <andi@splitbrain.org>
      */
-    updatehide: function(){
-        jQuery('#media__content div.detail').dw_toggle(!dw_mediamanager.hide);
+    updatehide: function () {
+        jQuery('#media__content').find('div.detail').dw_toggle(!dw_mediamanager.hide);
     },
 
     /**
@@ -844,7 +851,7 @@ var dw_mediamanager = {
      *
      * @author Dominik Eckelmann <eckelmann@cosmocode.de>
      */
-    setOpt: function(opt, e){
+    setOpt: function (opt, e) {
         var val, i;
         if (typeof e !== 'undefined') {
             val = this.id.substring(this.id.length - 1);
@@ -853,7 +860,7 @@ var dw_mediamanager = {
         }
 
         if (val === false) {
-            DokuCookie.setValue(opt,'');
+            DokuCookie.setValue(opt, '');
             dw_mediamanager[opt] = false;
             return;
         }
@@ -890,11 +897,11 @@ var dw_mediamanager = {
     allowedOpt: function (opt, val) {
         var ret = true;
         jQuery.each(dw_mediamanager.forbidden_opts,
-                    function (_, forbids) {
-                        ret = forbids[opt] !== false &&
-                              jQuery.inArray(val, forbids[opt]) === -1;
-                        return ret;
-                    });
+            function (_, forbids) {
+                ret = forbids[opt] !== false &&
+                    jQuery.inArray(val, forbids[opt]) === -1;
+                return ret;
+            });
         return ret;
     },
 
@@ -921,23 +928,39 @@ var dw_mediamanager = {
     }
 };
 
-// moved from helpers.js temporarily here
 /**
- * Very simplistic Flash plugin check, probably works for Flash 8 and higher only
+ * Default implementation for the media manager's select action
  *
+ * Can be overriden with the onselect URL parameter. Is called on the opener context
+ *
+ * @param {string} edid
+ * @param {string} mediaid
+ * @param {string} opts
+ * @param {string} align [none, left, center, right]
  */
-function hasFlash(version){
-    var ver = 0, axo;
-    try{
-        if(navigator.plugins !== null && navigator.plugins.length > 0){
-           ver = navigator.plugins["Shockwave Flash"].description.split(' ')[2].split('.')[0];
-        }else{
-           axo = new ActiveXObject("ShockwaveFlash.ShockwaveFlash");
-           ver = axo.GetVariable("$version").split(' ')[1].split(',')[0];
-        }
-    }catch(e){ }
+function dw_mediamanager_item_select(edid, mediaid, opts, align, keepopen) {
+    var alignleft = '';
+    var alignright = '';
 
-    return ver >= version;
+    // Get the 2 characters after the cursor to check if we're currently inside an image tag
+    var cursorInImageTag = false;
+    var textArea = jQuery('#' + edid)[0];
+    var selection = DWgetSelection(textArea);
+    selection.end = selection.end + 2;
+    var charsAfterCursor = selection.getText();
+    if (charsAfterCursor === '}}') {
+        cursorInImageTag = true;
+    }
+
+    if (align !== '1') {
+        alignleft = align === '2' ? '' : ' ';
+        alignright = align === '4' ? '' : ' ';
+    }
+    if (keepopen && cursorInImageTag) {
+        selection.start = selection.start + 2;
+        DWsetSelection(selection);
+    }
+    insertTags(edid, '{{' + alignleft + mediaid + opts + alignright + '|', '}}', '');
 }
 
 jQuery(dw_mediamanager.init);
